// {{MadCap}} //////////////////////////////////////////////////////////////////
// Copyright: MadCap Software, Inc - www.madcapsoftware.com ////////////////////
////////////////////////////////////////////////////////////////////////////////
// <version>15.0.7081.30245</version>
////////////////////////////////////////////////////////////////////////////////

//    Syntax:
//    function FMCOpenHelp( id, skinName, searchQuery, firstPick )
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    FMCOpenHelp( 'FILE_NEW', null, null, null );
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    FMCOpenHelp( 'FILE_NEW', 'BlueSkin', null, null );
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    FMCOpenHelp( 1, null, null, null );
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    FMCOpenHelp( 1, 'BlueSkin', null, null );
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    FMCOpenHelp( 'Company/Employees.htm', null, null, null );
//
//    In the following example, both the default topic and skin will be used:
//    FMCOpenHelp( null, null, null, null );
//
//    In the following example, the default topic will be used with "BlueSkin":
//    FMCOpenHelp( null, 'BlueSkin', null, null );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    FMCOpenHelp( null, null, 'quarterly report', false );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    FMCOpenHelp( null, null, 'quarterly report', true );

function FMCOpenHelp( id, skinName, searchQuery, firstPick, pathToHelpSystem )
{
    MadCap.OpenHelp(id, skinName, searchQuery, firstPick, pathToHelpSystem);
}

/*!
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v15.0.7081.30245
*/

/*
 RequireJS 2.1.11 Copyright (c) 2010-2014, The Dojo Foundation All Rights Reserved.
 Available via the MIT or new BSD license.
 see: http://github.com/jrburke/requirejs for details
*/
var requirejs, require, define;
(function (ca) {
    function G(b) { return "[object Function]" === M.call(b) } function H(b) { return "[object Array]" === M.call(b) } function v(b, c) { if (b) { var d; for (d = 0; d < b.length && (!b[d] || !c(b[d], d, b)) ; d += 1); } } function U(b, c) { if (b) { var d; for (d = b.length - 1; -1 < d && (!b[d] || !c(b[d], d, b)) ; d -= 1); } } function s(b, c) { return ga.call(b, c) } function j(b, c) { return s(b, c) && b[c] } function B(b, c) { for (var d in b) if (s(b, d) && c(b[d], d)) break } function V(b, c, d, g) {
        c && B(c, function (c, h) {
            if (d || !s(b, h)) g && "object" === typeof c && c && !H(c) && !G(c) && !(c instanceof
            RegExp) ? (b[h] || (b[h] = {}), V(b[h], c, d, g)) : b[h] = c
        }); return b
    } function t(b, c) { return function () { return c.apply(b, arguments) } } function da(b) { throw b; } function ea(b) { if (!b) return b; var c = ca; v(b.split("."), function (b) { c = c[b] }); return c } function C(b, c, d, g) { c = Error(c + "\nhttp://requirejs.org/docs/errors.html#" + b); c.requireType = b; c.requireModules = g; d && (c.originalError = d); return c } function ha(b) {
        function c(a, e, b) {
            var f, n, c, d, g, h, i, I = e && e.split("/"); n = I; var m = l.map, k = m && m["*"]; if (a && "." === a.charAt(0)) if (e) {
                n =
                I.slice(0, I.length - 1); a = a.split("/"); e = a.length - 1; l.nodeIdCompat && R.test(a[e]) && (a[e] = a[e].replace(R, "")); n = a = n.concat(a); d = n.length; for (e = 0; e < d; e++) if (c = n[e], "." === c) n.splice(e, 1), e -= 1; else if (".." === c) if (1 === e && (".." === n[2] || ".." === n[0])) break; else 0 < e && (n.splice(e - 1, 2), e -= 2); a = a.join("/")
            } else 0 === a.indexOf("./") && (a = a.substring(2)); if (b && m && (I || k)) {
                n = a.split("/"); e = n.length; a: for (; 0 < e; e -= 1) {
                    d = n.slice(0, e).join("/"); if (I) for (c = I.length; 0 < c; c -= 1) if (b = j(m, I.slice(0, c).join("/"))) if (b = j(b, d)) {
                        f = b;
                        g = e; break a
                    } !h && (k && j(k, d)) && (h = j(k, d), i = e)
                } !f && h && (f = h, g = i); f && (n.splice(0, g, f), a = n.join("/"))
            } return (f = j(l.pkgs, a)) ? f : a
        } function d(a) { z && v(document.getElementsByTagName("script"), function (e) { if (e.getAttribute("data-requiremodule") === a && e.getAttribute("data-requirecontext") === i.contextName) return e.parentNode.removeChild(e), !0 }) } function g(a) { var e = j(l.paths, a); if (e && H(e) && 1 < e.length) return e.shift(), i.require.undef(a), i.require([a]), !0 } function u(a) {
            var e; return [e, a];
        } function m(a, e, b, f) { var n, d, g = null, h = e ? e.name : null, l = a, m = !0, k = ""; a || (m = !1, a = "_@r" + (M += 1)); a = u(a); g = a[0]; a = a[1]; g && (g = c(g, h, f), d = j(p, g)); a && (g ? k = d && d.normalize ? d.normalize(a, function (a) { return c(a, h, f) }) : c(a, h, f) : (k = c(a, h, f), a = u(k), g = a[0], k = a[1], b = !0, n = i.nameToUrl(k))); b = g && !d && !b ? "_unnormalized" + (Q += 1) : ""; return { prefix: g, name: k, parentMap: e, unnormalized: !!b, url: n, originalName: l, isDefine: m, id: (g ? g + "!" + k : k) + b } } function q(a) {
            var e = a.id, b = j(k, e); b || (b = k[e] = new i.Module(a));
            return b
        } function r(a, e, b) { var f = a.id, n = j(k, f); if (s(p, f) && (!n || n.defineEmitComplete)) "defined" === e && b(p[f]); else if (n = q(a), n.error && "error" === e) b(n.error); else n.on(e, b) } function w(a, e) { var b = a.requireModules, f = !1; if (e) e(a); else if (v(b, function (e) { if (e = j(k, e)) e.error = a, e.events.error && (f = !0, e.emit("error", a)) }), !f) h.onError(a) } function x() { S.length && (ia.apply(A, [A.length, 0].concat(S)), S = []) } function y(a) { delete k[a]; delete W[a] } function F(a, e, b) {
            var f = a.map.id; a.error ? a.emit("error", a.error) : (e[f] =
            !0, v(a.depMaps, function (f, c) { var d = f.id, g = j(k, d); g && (!a.depMatched[c] && !b[d]) && (j(e, d) ? (a.defineDep(c, p[d]), a.check()) : F(g, e, b)) }), b[f] = !0)
        } function D() {
            var a, e, b = (a = 1E3 * l.waitSeconds) && i.startTime + a < (new Date).getTime(), f = [], c = [], h = !1, k = !0; if (!X) {
                X = !0; B(W, function (a) { var i = a.map, m = i.id; if (a.enabled && (i.isDefine || c.push(a), !a.error)) if (!a.inited && b) g(m) ? h = e = !0 : (f.push(m), d(m)); else if (!a.inited && (a.fetched && i.isDefine) && (h = !0, !i.prefix)) return k = !1 }); if (b && f.length) return a = C("timeout", "Load timeout for modules: " +
                f, null, f), a.contextName = i.contextName, w(a); k && v(c, function (a) { F(a, {}, {}) }); if ((!b || e) && h) if ((z || fa) && !Y) Y = setTimeout(function () { Y = 0; D() }, 50); X = !1
            }
        } function E(a) { s(p, a[0]) || q(m(a[0], null, !0)).init(a[1], a[2]) } function K(a) { var a = a.currentTarget || a.srcElement, e = i.onScriptLoad; a.detachEvent && !Z ? a.detachEvent("onreadystatechange", e) : a.removeEventListener("load", e, !1); e = i.onScriptError; (!a.detachEvent || Z) && a.removeEventListener("error", e, !1); return { node: a, id: a && a.getAttribute("data-requiremodule") } } function L() {
            var a;
            for (x() ; A.length;) { a = A.shift(); if (null === a[0]) return w(C("mismatch", "Mismatched anonymous define() module: " + a[a.length - 1])); E(a) }
        } var X, $, i, N, Y, l = { waitSeconds: 7, baseUrl: "./", paths: {}, bundles: {}, pkgs: {}, shim: {}, config: {} }, k = {}, W = {}, aa = {}, A = [], p = {}, T = {}, ba = {}, M = 1, Q = 1; N = {
            require: function (a) { return a.require ? a.require : a.require = i.makeRequire(a.map) }, exports: function (a) { a.usingExports = !0; if (a.map.isDefine) return a.exports ? p[a.map.id] = a.exports : a.exports = p[a.map.id] = {} }, module: function (a) {
                return a.module ?
                a.module : a.module = { id: a.map.id, uri: a.map.url, config: function () { return j(l.config, a.map.id) || {} }, exports: a.exports || (a.exports = {}) }
            }
        }; $ = function (a) { this.events = j(aa, a.id) || {}; this.map = a; this.shim = j(l.shim, a.id); this.depExports = []; this.depMaps = []; this.depMatched = []; this.pluginMaps = {}; this.depCount = 0 }; $.prototype = {
            init: function (a, e, b, f) {
                f = f || {}; if (!this.inited) {
                    this.factory = e; if (b) this.on("error", b); else this.events.error && (b = t(this, function (a) { this.emit("error", a) })); this.depMaps = a && a.slice(0); this.errback =
                    b; this.inited = !0; this.ignore = f.ignore; f.enabled || this.enabled ? this.enable() : this.check()
                }
            }, defineDep: function (a, e) { this.depMatched[a] || (this.depMatched[a] = !0, this.depCount -= 1, this.depExports[a] = e) }, fetch: function () { if (!this.fetched) { this.fetched = !0; i.startTime = (new Date).getTime(); var a = this.map; if (this.shim) i.makeRequire(this.map, { enableBuildCallback: !0 })(this.shim.deps || [], t(this, function () { return a.prefix ? this.callPlugin() : this.load() })); else return a.prefix ? this.callPlugin() : this.load() } }, load: function () {
                var a =
                this.map.url; T[a] || (T[a] = !0, i.load(this.map.id, a))
            }, check: function () {
                if (this.enabled && !this.enabling) {
                    var a, e, b = this.map.id; e = this.depExports; var f = this.exports, c = this.factory; if (this.inited) if (this.error) this.emit("error", this.error); else {
                        if (!this.defining) {
                            this.defining = !0; if (1 > this.depCount && !this.defined) {
                                if (G(c)) {
                                    if (this.events.error && this.map.isDefine || h.onError !== da) try { f = i.execCb(b, c, e, f) } catch (d) { a = d } else f = i.execCb(b, c, e, f); this.map.isDefine && void 0 === f && ((e = this.module) ? f = e.exports : this.usingExports &&
                                    (f = this.exports)); if (a) return a.requireMap = this.map, a.requireModules = this.map.isDefine ? [this.map.id] : null, a.requireType = this.map.isDefine ? "define" : "require", w(this.error = a)
                                } else f = c; this.exports = f; if (this.map.isDefine && !this.ignore && (p[b] = f, h.onResourceLoad)) h.onResourceLoad(i, this.map, this.depMaps); y(b); this.defined = !0
                            } this.defining = !1; this.defined && !this.defineEmitted && (this.defineEmitted = !0, this.emit("defined", this.exports), this.defineEmitComplete = !0)
                        }
                    } else this.fetch()
                }
            }, callPlugin: function () {
                var a =
                this.map, b = a.id, d = m(a.prefix); this.depMaps.push(d); r(d, "defined", t(this, function (f) {
                    var d, g; g = j(ba, this.map.id); var J = this.map.name, u = this.map.parentMap ? this.map.parentMap.name : null, p = i.makeRequire(a.parentMap, { enableBuildCallback: !0 }); if (this.map.unnormalized) {
                        if (f.normalize && (J = f.normalize(J, function (a) { return c(a, u, !0) }) || ""), f = m(a.prefix + "!" + J, this.map.parentMap), r(f, "defined", t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0, ignore: !0 }) })), g = j(k, f.id)) {
                            this.depMaps.push(f);
                            if (this.events.error) g.on("error", t(this, function (a) { this.emit("error", a) })); g.enable()
                        }
                    } else g ? (this.map.url = i.nameToUrl(g), this.load()) : (d = t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0 }) }), d.error = t(this, function (a) { this.inited = !0; this.error = a; a.requireModules = [b]; B(k, function (a) { 0 === a.map.id.indexOf(b + "_unnormalized") && y(a.map.id) }); w(a) }), d.fromText = t(this, function (f, c) {
                        var g = a.name, J = m(g), k = O; c && (f = c); k && (O = !1); q(J); s(l.config, b) && (l.config[g] = l.config[b]); try { h.exec(f) } catch (j) {
                            return w(C("fromtexteval",
                            "fromText eval for " + b + " failed: " + j, j, [b]))
                        } k && (O = !0); this.depMaps.push(J); i.completeLoad(g); p([g], d)
                    }), f.load(a.name, p, d, l))
                })); i.enable(d, this); this.pluginMaps[d.id] = d
            }, enable: function () {
                W[this.map.id] = this; this.enabling = this.enabled = !0; v(this.depMaps, t(this, function (a, b) {
                    var c, f; if ("string" === typeof a) {
                        a = m(a, this.map.isDefine ? this.map : this.map.parentMap, !1, !this.skipMap); this.depMaps[b] = a; if (c = j(N, a.id)) { this.depExports[b] = c(this); return } this.depCount += 1; r(a, "defined", t(this, function (a) {
                            this.defineDep(b,
                            a); this.check()
                        })); this.errback && r(a, "error", t(this, this.errback))
                    } c = a.id; f = k[c]; !s(N, c) && (f && !f.enabled) && i.enable(a, this)
                })); B(this.pluginMaps, t(this, function (a) { var b = j(k, a.id); b && !b.enabled && i.enable(a, this) })); this.enabling = !1; this.check()
            }, on: function (a, b) { var c = this.events[a]; c || (c = this.events[a] = []); c.push(b) }, emit: function (a, b) { v(this.events[a], function (a) { a(b) }); "error" === a && delete this.events[a] }
        }; i = {
            config: l, contextName: b, registry: k, defined: p, urlFetched: T, defQueue: A, Module: $, makeModuleMap: m,
            nextTick: h.nextTick, onError: w, configure: function (a) {
                a.baseUrl && "/" !== a.baseUrl.charAt(a.baseUrl.length - 1) && (a.baseUrl += "/"); var b = l.shim, c = { paths: !0, bundles: !0, config: !0, map: !0 }; B(a, function (a, b) { c[b] ? (l[b] || (l[b] = {}), V(l[b], a, !0, !0)) : l[b] = a }); a.bundles && B(a.bundles, function (a, b) { v(a, function (a) { a !== b && (ba[a] = b) }) }); a.shim && (B(a.shim, function (a, c) { H(a) && (a = { deps: a }); if ((a.exports || a.init) && !a.exportsFn) a.exportsFn = i.makeShimExports(a); b[c] = a }), l.shim = b); a.packages && v(a.packages, function (a) {
                    var b,
                    a = "string" === typeof a ? { name: a } : a; b = a.name; a.location && (l.paths[b] = a.location); l.pkgs[b] = a.name + "/" + (a.main || "main").replace(ja, "").replace(R, "")
                }); B(k, function (a, b) { !a.inited && !a.map.unnormalized && (a.map = m(b)) }); if (a.deps || a.callback) i.require(a.deps || [], a.callback)
            }, makeShimExports: function (a) { return function () { var b; a.init && (b = a.init.apply(ca, arguments)); return b || a.exports && ea(a.exports) } }, makeRequire: function (a, e) {
                function g(f, c, d) {
                    var j, l; e.enableBuildCallback && (c && G(c)) && (c.__requireJsBuild =
                    !0); if ("string" === typeof f) { if (G(c)) return w(C("requireargs", "Invalid require call"), d); if (a && s(N, f)) return N[f](k[a.id]); if (h.get) return h.get(i, f, a, g); j = m(f, a, !1, !0); j = j.id; return !s(p, j) ? w(C("notloaded", 'Module name "' + j + '" has not been loaded yet for context: ' + b + (a ? "" : ". Use require([])"))) : p[j] } L(); i.nextTick(function () { L(); l = q(m(null, a)); l.skipMap = e.skipMap; l.init(f, c, d, { enabled: !0 }); D() }); return g
                } e = e || {}; V(g, {
                    isBrowser: z, toUrl: function (b) {
                        var e, d = b.lastIndexOf("."), g = b.split("/")[0]; if (-1 !==
                        d && (!("." === g || ".." === g) || 1 < d)) e = b.substring(d, b.length), b = b.substring(0, d); return i.nameToUrl(c(b, a && a.id, !0), e, !0)
                    }, defined: function (b) { return s(p, m(b, a, !1, !0).id) }, specified: function (b) { b = m(b, a, !1, !0).id; return s(p, b) || s(k, b) }
                }); a || (g.undef = function (b) { x(); var c = m(b, a, !0), e = j(k, b); d(b); delete p[b]; delete T[c.url]; delete aa[b]; U(A, function (a, c) { a[0] === b && A.splice(c, 1) }); e && (e.events.defined && (aa[b] = e.events), y(b)) }); return g
            }, enable: function (a) { j(k, a.id) && q(a).enable() }, completeLoad: function (a) {
                var b,
                c, f = j(l.shim, a) || {}, d = f.exports; for (x() ; A.length;) { c = A.shift(); if (null === c[0]) { c[0] = a; if (b) break; b = !0 } else c[0] === a && (b = !0); E(c) } c = j(k, a); if (!b && !s(p, a) && c && !c.inited) { if (l.enforceDefine && (!d || !ea(d))) return g(a) ? void 0 : w(C("nodefine", "No define call for " + a, null, [a])); E([a, f.deps || [], f.exportsFn]) } D()
            }, nameToUrl: function (a, b, c) {
                var f, d, g; (f = j(l.pkgs, a)) && (a = f); if (f = j(ba, a)) return i.nameToUrl(f, b, c); if (h.jsExtRegExp.test(a)) f = a + (b || ""); else {
                    f = l.paths; a = a.split("/"); for (d = a.length; 0 < d; d -= 1) if (g = a.slice(0,
                    d).join("/"), g = j(f, g)) { H(g) && (g = g[0]); a.splice(0, d, g); break } f = a.join("/"); f += b || (/^data\:|\?/.test(f) || c ? "" : ".js"); f = ("/" === f.charAt(0) || f.match(/^[\w\+\.\-]+:/) ? "" : l.baseUrl) + f
                } return l.urlArgs ? f + ((-1 === f.indexOf("?") ? "?" : "&") + l.urlArgs) : f
            }, load: function (a, b) { h.load(i, a, b) }, execCb: function (a, b, c, d) { return b.apply(d, c) }, onScriptLoad: function (a) { if ("load" === a.type || ka.test((a.currentTarget || a.srcElement).readyState)) P = null, a = K(a), i.completeLoad(a.id) }, onScriptError: function (a) {
                var b = K(a); if (!g(b.id)) return w(C("scripterror",
                "Script error for: " + b.id, a, [b.id]))
            }
        }; i.require = i.makeRequire(); return i
    } var h, x, y, D, K, E, P, L, q, Q, la = /(\/\*([\s\S]*?)\*\/|([^:]|^)\/\/(.*)$)/mg, ma = /[^.]\s*require\s*\(\s*["']([^'"\s]+)["']\s*\)/g, R = /\.js$/, ja = /^\.\//; x = Object.prototype; var M = x.toString, ga = x.hasOwnProperty, ia = Array.prototype.splice, z = !!("undefined" !== typeof window && "undefined" !== typeof navigator && window.document), fa = !z && "undefined" !== typeof importScripts, ka = z && "PLAYSTATION 3" === navigator.platform ? /^complete$/ : /^(complete|loaded)$/,
    Z = "undefined" !== typeof opera && "[object Opera]" === opera.toString(), F = {}, r = {}, S = [], O = !1; if ("undefined" === typeof define) {
        if ("undefined" !== typeof requirejs) { if (G(requirejs)) return; r = requirejs; requirejs = void 0 } "undefined" !== typeof require && !G(require) && (r = require, require = void 0); h = requirejs = function (b, c, d, g) { var u, m = "_"; !H(b) && "string" !== typeof b && (u = b, H(c) ? (b = c, c = d, d = g) : b = []); u && u.context && (m = u.context); (g = j(F, m)) || (g = F[m] = h.s.newContext(m)); u && g.configure(u); return g.require(b, c, d) }; h.config = function (b) { return h(b) };
        h.nextTick = "undefined" !== typeof setTimeout ? function (b) { setTimeout(b, 4) } : function (b) { b() }; require || (require = h); h.version = "2.1.11"; h.jsExtRegExp = /^\/|:|\?|\.js$/; h.isBrowser = z; x = h.s = { contexts: F, newContext: ha }; h({}); v(["toUrl", "undef", "defined", "specified"], function (b) { h[b] = function () { var c = F._; return c.require[b].apply(c, arguments) } }); if (z && (y = x.head = document.getElementsByTagName("head")[0], D = document.getElementsByTagName("base")[0])) y = x.head = D.parentNode; h.onError = da; h.createNode = function (b) {
            var c =
            b.xhtml ? document.createElementNS("http://www.w3.org/1999/xhtml", "html:script") : document.createElement("script"); c.type = b.scriptType || "text/javascript"; c.charset = "utf-8"; c.async = !0; return c
        }; h.load = function (b, c, d) {
            var g = b && b.config || {}; if (z) return g = h.createNode(g, c, d), g.setAttribute("data-requirecontext", b.contextName), g.setAttribute("data-requiremodule", c), g.attachEvent && !(g.attachEvent.toString && 0 > g.attachEvent.toString().indexOf("[native code")) && !Z ? (O = !0, g.attachEvent("onreadystatechange", b.onScriptLoad)) :
            (g.addEventListener("load", b.onScriptLoad, !1), g.addEventListener("error", b.onScriptError, !1)), g.src = d, L = g, D ? y.insertBefore(g, D) : y.appendChild(g), L = null, g; if (fa) try { importScripts(d), b.completeLoad(c) } catch (j) { b.onError(C("importscripts", "importScripts failed for " + c + " at " + d, j, [c])) }
        }; z && !r.skipDataMain && U(document.getElementsByTagName("script"), function (b) {
            y || (y = b.parentNode); if (K = b.getAttribute("data-main")) return q = K, r.baseUrl || (E = q.split("/"), q = E.pop(), Q = E.length ? E.join("/") + "/" : "./", r.baseUrl =
            Q), q = q.replace(R, ""), h.jsExtRegExp.test(q) && (q = K), r.deps = r.deps ? r.deps.concat(q) : [q], !0
        }); define = function (b, c, d) {
            var g, h; "string" !== typeof b && (d = c, c = b, b = null); H(c) || (d = c, c = null); !c && G(d) && (c = [], d.length && (d.toString().replace(la, "").replace(ma, function (b, d) { c.push(d) }), c = (1 === d.length ? ["require"] : ["require", "exports", "module"]).concat(c))); if (O) {
                if (!(g = L)) P && "interactive" === P.readyState || U(document.getElementsByTagName("script"), function (b) { if ("interactive" === b.readyState) return P = b }), g = P; g && (b ||
                (b = g.getAttribute("data-requiremodule")), h = F[g.getAttribute("data-requirecontext")])
            } (h ? h.defQueue : S).push([b, c, d])
        }; define.amd = { jQuery: !0 }; h.exec = function (b) { return eval(b) }; h(r)
    }
})(this);/* require end */

/* jQuery begin */
/*! jQuery v3.3.1 | (c) JS Foundation and other contributors | jquery.org/license */
!function (e, t) { "use strict"; "object" == typeof module && "object" == typeof module.exports ? module.exports = e.document ? t(e, !0) : function (e) { if (!e.document) throw new Error("jQuery requires a window with a document"); return t(e) } : t(e) }("undefined" != typeof window ? window : this, function (e, t) { "use strict"; var n = [], r = e.document, i = Object.getPrototypeOf, o = n.slice, a = n.concat, s = n.push, u = n.indexOf, l = {}, c = l.toString, f = l.hasOwnProperty, p = f.toString, d = p.call(Object), h = {}, g = function e(t) { return "function" == typeof t && "number" != typeof t.nodeType }, y = function e(t) { return null != t && t === t.window }, v = { type: !0, src: !0, noModule: !0 }; function m(e, t, n) { var i, o = (t = t || r).createElement("script"); if (o.text = e, n) for (i in v) n[i] && (o[i] = n[i]); t.head.appendChild(o).parentNode.removeChild(o) } function x(e) { return null == e ? e + "" : "object" == typeof e || "function" == typeof e ? l[c.call(e)] || "object" : typeof e } var b = "3.3.1", w = function (e, t) { return new w.fn.init(e, t) }, T = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g; w.fn = w.prototype = { jquery: "3.3.1", constructor: w, length: 0, toArray: function () { return o.call(this) }, get: function (e) { return null == e ? o.call(this) : e < 0 ? this[e + this.length] : this[e] }, pushStack: function (e) { var t = w.merge(this.constructor(), e); return t.prevObject = this, t }, each: function (e) { return w.each(this, e) }, map: function (e) { return this.pushStack(w.map(this, function (t, n) { return e.call(t, n, t) })) }, slice: function () { return this.pushStack(o.apply(this, arguments)) }, first: function () { return this.eq(0) }, last: function () { return this.eq(-1) }, eq: function (e) { var t = this.length, n = +e + (e < 0 ? t : 0); return this.pushStack(n >= 0 && n < t ? [this[n]] : []) }, end: function () { return this.prevObject || this.constructor() }, push: s, sort: n.sort, splice: n.splice }, w.extend = w.fn.extend = function () { var e, t, n, r, i, o, a = arguments[0] || {}, s = 1, u = arguments.length, l = !1; for ("boolean" == typeof a && (l = a, a = arguments[s] || {}, s++), "object" == typeof a || g(a) || (a = {}), s === u && (a = this, s--); s < u; s++)if (null != (e = arguments[s])) for (t in e) n = a[t], a !== (r = e[t]) && (l && r && (w.isPlainObject(r) || (i = Array.isArray(r))) ? (i ? (i = !1, o = n && Array.isArray(n) ? n : []) : o = n && w.isPlainObject(n) ? n : {}, a[t] = w.extend(l, o, r)) : void 0 !== r && (a[t] = r)); return a }, w.extend({ expando: "jQuery" + ("3.3.1" + Math.random()).replace(/\D/g, ""), isReady: !0, error: function (e) { throw new Error(e) }, noop: function () { }, isPlainObject: function (e) { var t, n; return !(!e || "[object Object]" !== c.call(e)) && (!(t = i(e)) || "function" == typeof (n = f.call(t, "constructor") && t.constructor) && p.call(n) === d) }, isEmptyObject: function (e) { var t; for (t in e) return !1; return !0 }, globalEval: function (e) { m(e) }, each: function (e, t) { var n, r = 0; if (C(e)) { for (n = e.length; r < n; r++)if (!1 === t.call(e[r], r, e[r])) break } else for (r in e) if (!1 === t.call(e[r], r, e[r])) break; return e }, trim: function (e) { return null == e ? "" : (e + "").replace(T, "") }, makeArray: function (e, t) { var n = t || []; return null != e && (C(Object(e)) ? w.merge(n, "string" == typeof e ? [e] : e) : s.call(n, e)), n }, inArray: function (e, t, n) { return null == t ? -1 : u.call(t, e, n) }, merge: function (e, t) { for (var n = +t.length, r = 0, i = e.length; r < n; r++)e[i++] = t[r]; return e.length = i, e }, grep: function (e, t, n) { for (var r, i = [], o = 0, a = e.length, s = !n; o < a; o++)(r = !t(e[o], o)) !== s && i.push(e[o]); return i }, map: function (e, t, n) { var r, i, o = 0, s = []; if (C(e)) for (r = e.length; o < r; o++)null != (i = t(e[o], o, n)) && s.push(i); else for (o in e) null != (i = t(e[o], o, n)) && s.push(i); return a.apply([], s) }, guid: 1, support: h }), "function" == typeof Symbol && (w.fn[Symbol.iterator] = n[Symbol.iterator]), w.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "), function (e, t) { l["[object " + t + "]"] = t.toLowerCase() }); function C(e) { var t = !!e && "length" in e && e.length, n = x(e); return !g(e) && !y(e) && ("array" === n || 0 === t || "number" == typeof t && t > 0 && t - 1 in e) } var E = function (e) { var t, n, r, i, o, a, s, u, l, c, f, p, d, h, g, y, v, m, x, b = "sizzle" + 1 * new Date, w = e.document, T = 0, C = 0, E = ae(), k = ae(), S = ae(), D = function (e, t) { return e === t && (f = !0), 0 }, N = {}.hasOwnProperty, A = [], j = A.pop, q = A.push, L = A.push, H = A.slice, O = function (e, t) { for (var n = 0, r = e.length; n < r; n++)if (e[n] === t) return n; return -1 }, P = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped", M = "[\\x20\\t\\r\\n\\f]", R = "(?:\\\\.|[\\w-]|[^\0-\\xa0])+", I = "\\[" + M + "*(" + R + ")(?:" + M + "*([*^$|!~]?=)" + M + "*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + R + "))|)" + M + "*\\]", W = ":(" + R + ")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|" + I + ")*)|.*)\\)|)", $ = new RegExp(M + "+", "g"), B = new RegExp("^" + M + "+|((?:^|[^\\\\])(?:\\\\.)*)" + M + "+$", "g"), F = new RegExp("^" + M + "*," + M + "*"), _ = new RegExp("^" + M + "*([>+~]|" + M + ")" + M + "*"), z = new RegExp("=" + M + "*([^\\]'\"]*?)" + M + "*\\]", "g"), X = new RegExp(W), U = new RegExp("^" + R + "$"), V = { ID: new RegExp("^#(" + R + ")"), CLASS: new RegExp("^\\.(" + R + ")"), TAG: new RegExp("^(" + R + "|[*])"), ATTR: new RegExp("^" + I), PSEUDO: new RegExp("^" + W), CHILD: new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + M + "*(even|odd|(([+-]|)(\\d*)n|)" + M + "*(?:([+-]|)" + M + "*(\\d+)|))" + M + "*\\)|)", "i"), bool: new RegExp("^(?:" + P + ")$", "i"), needsContext: new RegExp("^" + M + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" + M + "*((?:-\\d)?\\d*)" + M + "*\\)|)(?=[^-]|$)", "i") }, G = /^(?:input|select|textarea|button)$/i, Y = /^h\d$/i, Q = /^[^{]+\{\s*\[native \w/, J = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/, K = /[+~]/, Z = new RegExp("\\\\([\\da-f]{1,6}" + M + "?|(" + M + ")|.)", "ig"), ee = function (e, t, n) { var r = "0x" + t - 65536; return r !== r || n ? t : r < 0 ? String.fromCharCode(r + 65536) : String.fromCharCode(r >> 10 | 55296, 1023 & r | 56320) }, te = /([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g, ne = function (e, t) { return t ? "\0" === e ? "\ufffd" : e.slice(0, -1) + "\\" + e.charCodeAt(e.length - 1).toString(16) + " " : "\\" + e }, re = function () { p() }, ie = me(function (e) { return !0 === e.disabled && ("form" in e || "label" in e) }, { dir: "parentNode", next: "legend" }); try { L.apply(A = H.call(w.childNodes), w.childNodes), A[w.childNodes.length].nodeType } catch (e) { L = { apply: A.length ? function (e, t) { q.apply(e, H.call(t)) } : function (e, t) { var n = e.length, r = 0; while (e[n++] = t[r++]); e.length = n - 1 } } } function oe(e, t, r, i) { var o, s, l, c, f, h, v, m = t && t.ownerDocument, T = t ? t.nodeType : 9; if (r = r || [], "string" != typeof e || !e || 1 !== T && 9 !== T && 11 !== T) return r; if (!i && ((t ? t.ownerDocument || t : w) !== d && p(t), t = t || d, g)) { if (11 !== T && (f = J.exec(e))) if (o = f[1]) { if (9 === T) { if (!(l = t.getElementById(o))) return r; if (l.id === o) return r.push(l), r } else if (m && (l = m.getElementById(o)) && x(t, l) && l.id === o) return r.push(l), r } else { if (f[2]) return L.apply(r, t.getElementsByTagName(e)), r; if ((o = f[3]) && n.getElementsByClassName && t.getElementsByClassName) return L.apply(r, t.getElementsByClassName(o)), r } if (n.qsa && !S[e + " "] && (!y || !y.test(e))) { if (1 !== T) m = t, v = e; else if ("object" !== t.nodeName.toLowerCase()) { (c = t.getAttribute("id")) ? c = c.replace(te, ne) : t.setAttribute("id", c = b), s = (h = a(e)).length; while (s--) h[s] = "#" + c + " " + ve(h[s]); v = h.join(","), m = K.test(e) && ge(t.parentNode) || t } if (v) try { return L.apply(r, m.querySelectorAll(v)), r } catch (e) { } finally { c === b && t.removeAttribute("id") } } } return u(e.replace(B, "$1"), t, r, i) } function ae() { var e = []; function t(n, i) { return e.push(n + " ") > r.cacheLength && delete t[e.shift()], t[n + " "] = i } return t } function se(e) { return e[b] = !0, e } function ue(e) { var t = d.createElement("fieldset"); try { return !!e(t) } catch (e) { return !1 } finally { t.parentNode && t.parentNode.removeChild(t), t = null } } function le(e, t) { var n = e.split("|"), i = n.length; while (i--) r.attrHandle[n[i]] = t } function ce(e, t) { var n = t && e, r = n && 1 === e.nodeType && 1 === t.nodeType && e.sourceIndex - t.sourceIndex; if (r) return r; if (n) while (n = n.nextSibling) if (n === t) return -1; return e ? 1 : -1 } function fe(e) { return function (t) { return "input" === t.nodeName.toLowerCase() && t.type === e } } function pe(e) { return function (t) { var n = t.nodeName.toLowerCase(); return ("input" === n || "button" === n) && t.type === e } } function de(e) { return function (t) { return "form" in t ? t.parentNode && !1 === t.disabled ? "label" in t ? "label" in t.parentNode ? t.parentNode.disabled === e : t.disabled === e : t.isDisabled === e || t.isDisabled !== !e && ie(t) === e : t.disabled === e : "label" in t && t.disabled === e } } function he(e) { return se(function (t) { return t = +t, se(function (n, r) { var i, o = e([], n.length, t), a = o.length; while (a--) n[i = o[a]] && (n[i] = !(r[i] = n[i])) }) }) } function ge(e) { return e && "undefined" != typeof e.getElementsByTagName && e } n = oe.support = {}, o = oe.isXML = function (e) { var t = e && (e.ownerDocument || e).documentElement; return !!t && "HTML" !== t.nodeName }, p = oe.setDocument = function (e) { var t, i, a = e ? e.ownerDocument || e : w; return a !== d && 9 === a.nodeType && a.documentElement ? (d = a, h = d.documentElement, g = !o(d), w !== d && (i = d.defaultView) && i.top !== i && (i.addEventListener ? i.addEventListener("unload", re, !1) : i.attachEvent && i.attachEvent("onunload", re)), n.attributes = ue(function (e) { return e.className = "i", !e.getAttribute("className") }), n.getElementsByTagName = ue(function (e) { return e.appendChild(d.createComment("")), !e.getElementsByTagName("*").length }), n.getElementsByClassName = Q.test(d.getElementsByClassName), n.getById = ue(function (e) { return h.appendChild(e).id = b, !d.getElementsByName || !d.getElementsByName(b).length }), n.getById ? (r.filter.ID = function (e) { var t = e.replace(Z, ee); return function (e) { return e.getAttribute("id") === t } }, r.find.ID = function (e, t) { if ("undefined" != typeof t.getElementById && g) { var n = t.getElementById(e); return n ? [n] : [] } }) : (r.filter.ID = function (e) { var t = e.replace(Z, ee); return function (e) { var n = "undefined" != typeof e.getAttributeNode && e.getAttributeNode("id"); return n && n.value === t } }, r.find.ID = function (e, t) { if ("undefined" != typeof t.getElementById && g) { var n, r, i, o = t.getElementById(e); if (o) { if ((n = o.getAttributeNode("id")) && n.value === e) return [o]; i = t.getElementsByName(e), r = 0; while (o = i[r++]) if ((n = o.getAttributeNode("id")) && n.value === e) return [o] } return [] } }), r.find.TAG = n.getElementsByTagName ? function (e, t) { return "undefined" != typeof t.getElementsByTagName ? t.getElementsByTagName(e) : n.qsa ? t.querySelectorAll(e) : void 0 } : function (e, t) { var n, r = [], i = 0, o = t.getElementsByTagName(e); if ("*" === e) { while (n = o[i++]) 1 === n.nodeType && r.push(n); return r } return o }, r.find.CLASS = n.getElementsByClassName && function (e, t) { if ("undefined" != typeof t.getElementsByClassName && g) return t.getElementsByClassName(e) }, v = [], y = [], (n.qsa = Q.test(d.querySelectorAll)) && (ue(function (e) { h.appendChild(e).innerHTML = "<a id='" + b + "'></a><select id='" + b + "-\r\\' msallowcapture=''><option selected=''></option></select>", e.querySelectorAll("[msallowcapture^='']").length && y.push("[*^$]=" + M + "*(?:''|\"\")"), e.querySelectorAll("[selected]").length || y.push("\\[" + M + "*(?:value|" + P + ")"), e.querySelectorAll("[id~=" + b + "-]").length || y.push("~="), e.querySelectorAll(":checked").length || y.push(":checked"), e.querySelectorAll("a#" + b + "+*").length || y.push(".#.+[+~]") }), ue(function (e) { e.innerHTML = "<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>"; var t = d.createElement("input"); t.setAttribute("type", "hidden"), e.appendChild(t).setAttribute("name", "D"), e.querySelectorAll("[name=d]").length && y.push("name" + M + "*[*^$|!~]?="), 2 !== e.querySelectorAll(":enabled").length && y.push(":enabled", ":disabled"), h.appendChild(e).disabled = !0, 2 !== e.querySelectorAll(":disabled").length && y.push(":enabled", ":disabled"), e.querySelectorAll("*,:x"), y.push(",.*:") })), (n.matchesSelector = Q.test(m = h.matches || h.webkitMatchesSelector || h.mozMatchesSelector || h.oMatchesSelector || h.msMatchesSelector)) && ue(function (e) { n.disconnectedMatch = m.call(e, "*"), m.call(e, "[s!='']:x"), v.push("!=", W) }), y = y.length && new RegExp(y.join("|")), v = v.length && new RegExp(v.join("|")), t = Q.test(h.compareDocumentPosition), x = t || Q.test(h.contains) ? function (e, t) { var n = 9 === e.nodeType ? e.documentElement : e, r = t && t.parentNode; return e === r || !(!r || 1 !== r.nodeType || !(n.contains ? n.contains(r) : e.compareDocumentPosition && 16 & e.compareDocumentPosition(r))) } : function (e, t) { if (t) while (t = t.parentNode) if (t === e) return !0; return !1 }, D = t ? function (e, t) { if (e === t) return f = !0, 0; var r = !e.compareDocumentPosition - !t.compareDocumentPosition; return r || (1 & (r = (e.ownerDocument || e) === (t.ownerDocument || t) ? e.compareDocumentPosition(t) : 1) || !n.sortDetached && t.compareDocumentPosition(e) === r ? e === d || e.ownerDocument === w && x(w, e) ? -1 : t === d || t.ownerDocument === w && x(w, t) ? 1 : c ? O(c, e) - O(c, t) : 0 : 4 & r ? -1 : 1) } : function (e, t) { if (e === t) return f = !0, 0; var n, r = 0, i = e.parentNode, o = t.parentNode, a = [e], s = [t]; if (!i || !o) return e === d ? -1 : t === d ? 1 : i ? -1 : o ? 1 : c ? O(c, e) - O(c, t) : 0; if (i === o) return ce(e, t); n = e; while (n = n.parentNode) a.unshift(n); n = t; while (n = n.parentNode) s.unshift(n); while (a[r] === s[r]) r++; return r ? ce(a[r], s[r]) : a[r] === w ? -1 : s[r] === w ? 1 : 0 }, d) : d }, oe.matches = function (e, t) { return oe(e, null, null, t) }, oe.matchesSelector = function (e, t) { if ((e.ownerDocument || e) !== d && p(e), t = t.replace(z, "='$1']"), n.matchesSelector && g && !S[t + " "] && (!v || !v.test(t)) && (!y || !y.test(t))) try { var r = m.call(e, t); if (r || n.disconnectedMatch || e.document && 11 !== e.document.nodeType) return r } catch (e) { } return oe(t, d, null, [e]).length > 0 }, oe.contains = function (e, t) { return (e.ownerDocument || e) !== d && p(e), x(e, t) }, oe.attr = function (e, t) { (e.ownerDocument || e) !== d && p(e); var i = r.attrHandle[t.toLowerCase()], o = i && N.call(r.attrHandle, t.toLowerCase()) ? i(e, t, !g) : void 0; return void 0 !== o ? o : n.attributes || !g ? e.getAttribute(t) : (o = e.getAttributeNode(t)) && o.specified ? o.value : null }, oe.escape = function (e) { return (e + "").replace(te, ne) }, oe.error = function (e) { throw new Error("Syntax error, unrecognized expression: " + e) }, oe.uniqueSort = function (e) { var t, r = [], i = 0, o = 0; if (f = !n.detectDuplicates, c = !n.sortStable && e.slice(0), e.sort(D), f) { while (t = e[o++]) t === e[o] && (i = r.push(o)); while (i--) e.splice(r[i], 1) } return c = null, e }, i = oe.getText = function (e) { var t, n = "", r = 0, o = e.nodeType; if (o) { if (1 === o || 9 === o || 11 === o) { if ("string" == typeof e.textContent) return e.textContent; for (e = e.firstChild; e; e = e.nextSibling)n += i(e) } else if (3 === o || 4 === o) return e.nodeValue } else while (t = e[r++]) n += i(t); return n }, (r = oe.selectors = { cacheLength: 50, createPseudo: se, match: V, attrHandle: {}, find: {}, relative: { ">": { dir: "parentNode", first: !0 }, " ": { dir: "parentNode" }, "+": { dir: "previousSibling", first: !0 }, "~": { dir: "previousSibling" } }, preFilter: { ATTR: function (e) { return e[1] = e[1].replace(Z, ee), e[3] = (e[3] || e[4] || e[5] || "").replace(Z, ee), "~=" === e[2] && (e[3] = " " + e[3] + " "), e.slice(0, 4) }, CHILD: function (e) { return e[1] = e[1].toLowerCase(), "nth" === e[1].slice(0, 3) ? (e[3] || oe.error(e[0]), e[4] = +(e[4] ? e[5] + (e[6] || 1) : 2 * ("even" === e[3] || "odd" === e[3])), e[5] = +(e[7] + e[8] || "odd" === e[3])) : e[3] && oe.error(e[0]), e }, PSEUDO: function (e) { var t, n = !e[6] && e[2]; return V.CHILD.test(e[0]) ? null : (e[3] ? e[2] = e[4] || e[5] || "" : n && X.test(n) && (t = a(n, !0)) && (t = n.indexOf(")", n.length - t) - n.length) && (e[0] = e[0].slice(0, t), e[2] = n.slice(0, t)), e.slice(0, 3)) } }, filter: { TAG: function (e) { var t = e.replace(Z, ee).toLowerCase(); return "*" === e ? function () { return !0 } : function (e) { return e.nodeName && e.nodeName.toLowerCase() === t } }, CLASS: function (e) { var t = E[e + " "]; return t || (t = new RegExp("(^|" + M + ")" + e + "(" + M + "|$)")) && E(e, function (e) { return t.test("string" == typeof e.className && e.className || "undefined" != typeof e.getAttribute && e.getAttribute("class") || "") }) }, ATTR: function (e, t, n) { return function (r) { var i = oe.attr(r, e); return null == i ? "!=" === t : !t || (i += "", "=" === t ? i === n : "!=" === t ? i !== n : "^=" === t ? n && 0 === i.indexOf(n) : "*=" === t ? n && i.indexOf(n) > -1 : "$=" === t ? n && i.slice(-n.length) === n : "~=" === t ? (" " + i.replace($, " ") + " ").indexOf(n) > -1 : "|=" === t && (i === n || i.slice(0, n.length + 1) === n + "-")) } }, CHILD: function (e, t, n, r, i) { var o = "nth" !== e.slice(0, 3), a = "last" !== e.slice(-4), s = "of-type" === t; return 1 === r && 0 === i ? function (e) { return !!e.parentNode } : function (t, n, u) { var l, c, f, p, d, h, g = o !== a ? "nextSibling" : "previousSibling", y = t.parentNode, v = s && t.nodeName.toLowerCase(), m = !u && !s, x = !1; if (y) { if (o) { while (g) { p = t; while (p = p[g]) if (s ? p.nodeName.toLowerCase() === v : 1 === p.nodeType) return !1; h = g = "only" === e && !h && "nextSibling" } return !0 } if (h = [a ? y.firstChild : y.lastChild], a && m) { x = (d = (l = (c = (f = (p = y)[b] || (p[b] = {}))[p.uniqueID] || (f[p.uniqueID] = {}))[e] || [])[0] === T && l[1]) && l[2], p = d && y.childNodes[d]; while (p = ++d && p && p[g] || (x = d = 0) || h.pop()) if (1 === p.nodeType && ++x && p === t) { c[e] = [T, d, x]; break } } else if (m && (x = d = (l = (c = (f = (p = t)[b] || (p[b] = {}))[p.uniqueID] || (f[p.uniqueID] = {}))[e] || [])[0] === T && l[1]), !1 === x) while (p = ++d && p && p[g] || (x = d = 0) || h.pop()) if ((s ? p.nodeName.toLowerCase() === v : 1 === p.nodeType) && ++x && (m && ((c = (f = p[b] || (p[b] = {}))[p.uniqueID] || (f[p.uniqueID] = {}))[e] = [T, x]), p === t)) break; return (x -= i) === r || x % r == 0 && x / r >= 0 } } }, PSEUDO: function (e, t) { var n, i = r.pseudos[e] || r.setFilters[e.toLowerCase()] || oe.error("unsupported pseudo: " + e); return i[b] ? i(t) : i.length > 1 ? (n = [e, e, "", t], r.setFilters.hasOwnProperty(e.toLowerCase()) ? se(function (e, n) { var r, o = i(e, t), a = o.length; while (a--) e[r = O(e, o[a])] = !(n[r] = o[a]) }) : function (e) { return i(e, 0, n) }) : i } }, pseudos: { not: se(function (e) { var t = [], n = [], r = s(e.replace(B, "$1")); return r[b] ? se(function (e, t, n, i) { var o, a = r(e, null, i, []), s = e.length; while (s--) (o = a[s]) && (e[s] = !(t[s] = o)) }) : function (e, i, o) { return t[0] = e, r(t, null, o, n), t[0] = null, !n.pop() } }), has: se(function (e) { return function (t) { return oe(e, t).length > 0 } }), contains: se(function (e) { return e = e.replace(Z, ee), function (t) { return (t.textContent || t.innerText || i(t)).indexOf(e) > -1 } }), lang: se(function (e) { return U.test(e || "") || oe.error("unsupported lang: " + e), e = e.replace(Z, ee).toLowerCase(), function (t) { var n; do { if (n = g ? t.lang : t.getAttribute("xml:lang") || t.getAttribute("lang")) return (n = n.toLowerCase()) === e || 0 === n.indexOf(e + "-") } while ((t = t.parentNode) && 1 === t.nodeType); return !1 } }), target: function (t) { var n = e.location && e.location.hash; return n && n.slice(1) === t.id }, root: function (e) { return e === h }, focus: function (e) { return e === d.activeElement && (!d.hasFocus || d.hasFocus()) && !!(e.type || e.href || ~e.tabIndex) }, enabled: de(!1), disabled: de(!0), checked: function (e) { var t = e.nodeName.toLowerCase(); return "input" === t && !!e.checked || "option" === t && !!e.selected }, selected: function (e) { return e.parentNode && e.parentNode.selectedIndex, !0 === e.selected }, empty: function (e) { for (e = e.firstChild; e; e = e.nextSibling)if (e.nodeType < 6) return !1; return !0 }, parent: function (e) { return !r.pseudos.empty(e) }, header: function (e) { return Y.test(e.nodeName) }, input: function (e) { return G.test(e.nodeName) }, button: function (e) { var t = e.nodeName.toLowerCase(); return "input" === t && "button" === e.type || "button" === t }, text: function (e) { var t; return "input" === e.nodeName.toLowerCase() && "text" === e.type && (null == (t = e.getAttribute("type")) || "text" === t.toLowerCase()) }, first: he(function () { return [0] }), last: he(function (e, t) { return [t - 1] }), eq: he(function (e, t, n) { return [n < 0 ? n + t : n] }), even: he(function (e, t) { for (var n = 0; n < t; n += 2)e.push(n); return e }), odd: he(function (e, t) { for (var n = 1; n < t; n += 2)e.push(n); return e }), lt: he(function (e, t, n) { for (var r = n < 0 ? n + t : n; --r >= 0;)e.push(r); return e }), gt: he(function (e, t, n) { for (var r = n < 0 ? n + t : n; ++r < t;)e.push(r); return e }) } }).pseudos.nth = r.pseudos.eq; for (t in { radio: !0, checkbox: !0, file: !0, password: !0, image: !0 }) r.pseudos[t] = fe(t); for (t in { submit: !0, reset: !0 }) r.pseudos[t] = pe(t); function ye() { } ye.prototype = r.filters = r.pseudos, r.setFilters = new ye, a = oe.tokenize = function (e, t) { var n, i, o, a, s, u, l, c = k[e + " "]; if (c) return t ? 0 : c.slice(0); s = e, u = [], l = r.preFilter; while (s) { n && !(i = F.exec(s)) || (i && (s = s.slice(i[0].length) || s), u.push(o = [])), n = !1, (i = _.exec(s)) && (n = i.shift(), o.push({ value: n, type: i[0].replace(B, " ") }), s = s.slice(n.length)); for (a in r.filter) !(i = V[a].exec(s)) || l[a] && !(i = l[a](i)) || (n = i.shift(), o.push({ value: n, type: a, matches: i }), s = s.slice(n.length)); if (!n) break } return t ? s.length : s ? oe.error(e) : k(e, u).slice(0) }; function ve(e) { for (var t = 0, n = e.length, r = ""; t < n; t++)r += e[t].value; return r } function me(e, t, n) { var r = t.dir, i = t.next, o = i || r, a = n && "parentNode" === o, s = C++; return t.first ? function (t, n, i) { while (t = t[r]) if (1 === t.nodeType || a) return e(t, n, i); return !1 } : function (t, n, u) { var l, c, f, p = [T, s]; if (u) { while (t = t[r]) if ((1 === t.nodeType || a) && e(t, n, u)) return !0 } else while (t = t[r]) if (1 === t.nodeType || a) if (f = t[b] || (t[b] = {}), c = f[t.uniqueID] || (f[t.uniqueID] = {}), i && i === t.nodeName.toLowerCase()) t = t[r] || t; else { if ((l = c[o]) && l[0] === T && l[1] === s) return p[2] = l[2]; if (c[o] = p, p[2] = e(t, n, u)) return !0 } return !1 } } function xe(e) { return e.length > 1 ? function (t, n, r) { var i = e.length; while (i--) if (!e[i](t, n, r)) return !1; return !0 } : e[0] } function be(e, t, n) { for (var r = 0, i = t.length; r < i; r++)oe(e, t[r], n); return n } function we(e, t, n, r, i) { for (var o, a = [], s = 0, u = e.length, l = null != t; s < u; s++)(o = e[s]) && (n && !n(o, r, i) || (a.push(o), l && t.push(s))); return a } function Te(e, t, n, r, i, o) { return r && !r[b] && (r = Te(r)), i && !i[b] && (i = Te(i, o)), se(function (o, a, s, u) { var l, c, f, p = [], d = [], h = a.length, g = o || be(t || "*", s.nodeType ? [s] : s, []), y = !e || !o && t ? g : we(g, p, e, s, u), v = n ? i || (o ? e : h || r) ? [] : a : y; if (n && n(y, v, s, u), r) { l = we(v, d), r(l, [], s, u), c = l.length; while (c--) (f = l[c]) && (v[d[c]] = !(y[d[c]] = f)) } if (o) { if (i || e) { if (i) { l = [], c = v.length; while (c--) (f = v[c]) && l.push(y[c] = f); i(null, v = [], l, u) } c = v.length; while (c--) (f = v[c]) && (l = i ? O(o, f) : p[c]) > -1 && (o[l] = !(a[l] = f)) } } else v = we(v === a ? v.splice(h, v.length) : v), i ? i(null, a, v, u) : L.apply(a, v) }) } function Ce(e) { for (var t, n, i, o = e.length, a = r.relative[e[0].type], s = a || r.relative[" "], u = a ? 1 : 0, c = me(function (e) { return e === t }, s, !0), f = me(function (e) { return O(t, e) > -1 }, s, !0), p = [function (e, n, r) { var i = !a && (r || n !== l) || ((t = n).nodeType ? c(e, n, r) : f(e, n, r)); return t = null, i }]; u < o; u++)if (n = r.relative[e[u].type]) p = [me(xe(p), n)]; else { if ((n = r.filter[e[u].type].apply(null, e[u].matches))[b]) { for (i = ++u; i < o; i++)if (r.relative[e[i].type]) break; return Te(u > 1 && xe(p), u > 1 && ve(e.slice(0, u - 1).concat({ value: " " === e[u - 2].type ? "*" : "" })).replace(B, "$1"), n, u < i && Ce(e.slice(u, i)), i < o && Ce(e = e.slice(i)), i < o && ve(e)) } p.push(n) } return xe(p) } function Ee(e, t) { var n = t.length > 0, i = e.length > 0, o = function (o, a, s, u, c) { var f, h, y, v = 0, m = "0", x = o && [], b = [], w = l, C = o || i && r.find.TAG("*", c), E = T += null == w ? 1 : Math.random() || .1, k = C.length; for (c && (l = a === d || a || c); m !== k && null != (f = C[m]); m++) { if (i && f) { h = 0, a || f.ownerDocument === d || (p(f), s = !g); while (y = e[h++]) if (y(f, a || d, s)) { u.push(f); break } c && (T = E) } n && ((f = !y && f) && v-- , o && x.push(f)) } if (v += m, n && m !== v) { h = 0; while (y = t[h++]) y(x, b, a, s); if (o) { if (v > 0) while (m--) x[m] || b[m] || (b[m] = j.call(u)); b = we(b) } L.apply(u, b), c && !o && b.length > 0 && v + t.length > 1 && oe.uniqueSort(u) } return c && (T = E, l = w), x }; return n ? se(o) : o } return s = oe.compile = function (e, t) { var n, r = [], i = [], o = S[e + " "]; if (!o) { t || (t = a(e)), n = t.length; while (n--) (o = Ce(t[n]))[b] ? r.push(o) : i.push(o); (o = S(e, Ee(i, r))).selector = e } return o }, u = oe.select = function (e, t, n, i) { var o, u, l, c, f, p = "function" == typeof e && e, d = !i && a(e = p.selector || e); if (n = n || [], 1 === d.length) { if ((u = d[0] = d[0].slice(0)).length > 2 && "ID" === (l = u[0]).type && 9 === t.nodeType && g && r.relative[u[1].type]) { if (!(t = (r.find.ID(l.matches[0].replace(Z, ee), t) || [])[0])) return n; p && (t = t.parentNode), e = e.slice(u.shift().value.length) } o = V.needsContext.test(e) ? 0 : u.length; while (o--) { if (l = u[o], r.relative[c = l.type]) break; if ((f = r.find[c]) && (i = f(l.matches[0].replace(Z, ee), K.test(u[0].type) && ge(t.parentNode) || t))) { if (u.splice(o, 1), !(e = i.length && ve(u))) return L.apply(n, i), n; break } } } return (p || s(e, d))(i, t, !g, n, !t || K.test(e) && ge(t.parentNode) || t), n }, n.sortStable = b.split("").sort(D).join("") === b, n.detectDuplicates = !!f, p(), n.sortDetached = ue(function (e) { return 1 & e.compareDocumentPosition(d.createElement("fieldset")) }), ue(function (e) { return e.innerHTML = "<a href='#'></a>", "#" === e.firstChild.getAttribute("href") }) || le("type|href|height|width", function (e, t, n) { if (!n) return e.getAttribute(t, "type" === t.toLowerCase() ? 1 : 2) }), n.attributes && ue(function (e) { return e.innerHTML = "<input/>", e.firstChild.setAttribute("value", ""), "" === e.firstChild.getAttribute("value") }) || le("value", function (e, t, n) { if (!n && "input" === e.nodeName.toLowerCase()) return e.defaultValue }), ue(function (e) { return null == e.getAttribute("disabled") }) || le(P, function (e, t, n) { var r; if (!n) return !0 === e[t] ? t.toLowerCase() : (r = e.getAttributeNode(t)) && r.specified ? r.value : null }), oe }(e); w.find = E, w.expr = E.selectors, w.expr[":"] = w.expr.pseudos, w.uniqueSort = w.unique = E.uniqueSort, w.text = E.getText, w.isXMLDoc = E.isXML, w.contains = E.contains, w.escapeSelector = E.escape; var k = function (e, t, n) { var r = [], i = void 0 !== n; while ((e = e[t]) && 9 !== e.nodeType) if (1 === e.nodeType) { if (i && w(e).is(n)) break; r.push(e) } return r }, S = function (e, t) { for (var n = []; e; e = e.nextSibling)1 === e.nodeType && e !== t && n.push(e); return n }, D = w.expr.match.needsContext; function N(e, t) { return e.nodeName && e.nodeName.toLowerCase() === t.toLowerCase() } var A = /^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i; function j(e, t, n) { return g(t) ? w.grep(e, function (e, r) { return !!t.call(e, r, e) !== n }) : t.nodeType ? w.grep(e, function (e) { return e === t !== n }) : "string" != typeof t ? w.grep(e, function (e) { return u.call(t, e) > -1 !== n }) : w.filter(t, e, n) } w.filter = function (e, t, n) { var r = t[0]; return n && (e = ":not(" + e + ")"), 1 === t.length && 1 === r.nodeType ? w.find.matchesSelector(r, e) ? [r] : [] : w.find.matches(e, w.grep(t, function (e) { return 1 === e.nodeType })) }, w.fn.extend({ find: function (e) { var t, n, r = this.length, i = this; if ("string" != typeof e) return this.pushStack(w(e).filter(function () { for (t = 0; t < r; t++)if (w.contains(i[t], this)) return !0 })); for (n = this.pushStack([]), t = 0; t < r; t++)w.find(e, i[t], n); return r > 1 ? w.uniqueSort(n) : n }, filter: function (e) { return this.pushStack(j(this, e || [], !1)) }, not: function (e) { return this.pushStack(j(this, e || [], !0)) }, is: function (e) { return !!j(this, "string" == typeof e && D.test(e) ? w(e) : e || [], !1).length } }); var q, L = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/; (w.fn.init = function (e, t, n) { var i, o; if (!e) return this; if (n = n || q, "string" == typeof e) { if (!(i = "<" === e[0] && ">" === e[e.length - 1] && e.length >= 3 ? [null, e, null] : L.exec(e)) || !i[1] && t) return !t || t.jquery ? (t || n).find(e) : this.constructor(t).find(e); if (i[1]) { if (t = t instanceof w ? t[0] : t, w.merge(this, w.parseHTML(i[1], t && t.nodeType ? t.ownerDocument || t : r, !0)), A.test(i[1]) && w.isPlainObject(t)) for (i in t) g(this[i]) ? this[i](t[i]) : this.attr(i, t[i]); return this } return (o = r.getElementById(i[2])) && (this[0] = o, this.length = 1), this } return e.nodeType ? (this[0] = e, this.length = 1, this) : g(e) ? void 0 !== n.ready ? n.ready(e) : e(w) : w.makeArray(e, this) }).prototype = w.fn, q = w(r); var H = /^(?:parents|prev(?:Until|All))/, O = { children: !0, contents: !0, next: !0, prev: !0 }; w.fn.extend({ has: function (e) { var t = w(e, this), n = t.length; return this.filter(function () { for (var e = 0; e < n; e++)if (w.contains(this, t[e])) return !0 }) }, closest: function (e, t) { var n, r = 0, i = this.length, o = [], a = "string" != typeof e && w(e); if (!D.test(e)) for (; r < i; r++)for (n = this[r]; n && n !== t; n = n.parentNode)if (n.nodeType < 11 && (a ? a.index(n) > -1 : 1 === n.nodeType && w.find.matchesSelector(n, e))) { o.push(n); break } return this.pushStack(o.length > 1 ? w.uniqueSort(o) : o) }, index: function (e) { return e ? "string" == typeof e ? u.call(w(e), this[0]) : u.call(this, e.jquery ? e[0] : e) : this[0] && this[0].parentNode ? this.first().prevAll().length : -1 }, add: function (e, t) { return this.pushStack(w.uniqueSort(w.merge(this.get(), w(e, t)))) }, addBack: function (e) { return this.add(null == e ? this.prevObject : this.prevObject.filter(e)) } }); function P(e, t) { while ((e = e[t]) && 1 !== e.nodeType); return e } w.each({ parent: function (e) { var t = e.parentNode; return t && 11 !== t.nodeType ? t : null }, parents: function (e) { return k(e, "parentNode") }, parentsUntil: function (e, t, n) { return k(e, "parentNode", n) }, next: function (e) { return P(e, "nextSibling") }, prev: function (e) { return P(e, "previousSibling") }, nextAll: function (e) { return k(e, "nextSibling") }, prevAll: function (e) { return k(e, "previousSibling") }, nextUntil: function (e, t, n) { return k(e, "nextSibling", n) }, prevUntil: function (e, t, n) { return k(e, "previousSibling", n) }, siblings: function (e) { return S((e.parentNode || {}).firstChild, e) }, children: function (e) { return S(e.firstChild) }, contents: function (e) { return N(e, "iframe") ? e.contentDocument : (N(e, "template") && (e = e.content || e), w.merge([], e.childNodes)) } }, function (e, t) { w.fn[e] = function (n, r) { var i = w.map(this, t, n); return "Until" !== e.slice(-5) && (r = n), r && "string" == typeof r && (i = w.filter(r, i)), this.length > 1 && (O[e] || w.uniqueSort(i), H.test(e) && i.reverse()), this.pushStack(i) } }); var M = /[^\x20\t\r\n\f]+/g; function R(e) { var t = {}; return w.each(e.match(M) || [], function (e, n) { t[n] = !0 }), t } w.Callbacks = function (e) { e = "string" == typeof e ? R(e) : w.extend({}, e); var t, n, r, i, o = [], a = [], s = -1, u = function () { for (i = i || e.once, r = t = !0; a.length; s = -1) { n = a.shift(); while (++s < o.length) !1 === o[s].apply(n[0], n[1]) && e.stopOnFalse && (s = o.length, n = !1) } e.memory || (n = !1), t = !1, i && (o = n ? [] : "") }, l = { add: function () { return o && (n && !t && (s = o.length - 1, a.push(n)), function t(n) { w.each(n, function (n, r) { g(r) ? e.unique && l.has(r) || o.push(r) : r && r.length && "string" !== x(r) && t(r) }) }(arguments), n && !t && u()), this }, remove: function () { return w.each(arguments, function (e, t) { var n; while ((n = w.inArray(t, o, n)) > -1) o.splice(n, 1), n <= s && s-- }), this }, has: function (e) { return e ? w.inArray(e, o) > -1 : o.length > 0 }, empty: function () { return o && (o = []), this }, disable: function () { return i = a = [], o = n = "", this }, disabled: function () { return !o }, lock: function () { return i = a = [], n || t || (o = n = ""), this }, locked: function () { return !!i }, fireWith: function (e, n) { return i || (n = [e, (n = n || []).slice ? n.slice() : n], a.push(n), t || u()), this }, fire: function () { return l.fireWith(this, arguments), this }, fired: function () { return !!r } }; return l }; function I(e) { return e } function W(e) { throw e } function $(e, t, n, r) { var i; try { e && g(i = e.promise) ? i.call(e).done(t).fail(n) : e && g(i = e.then) ? i.call(e, t, n) : t.apply(void 0, [e].slice(r)) } catch (e) { n.apply(void 0, [e]) } } w.extend({ Deferred: function (t) { var n = [["notify", "progress", w.Callbacks("memory"), w.Callbacks("memory"), 2], ["resolve", "done", w.Callbacks("once memory"), w.Callbacks("once memory"), 0, "resolved"], ["reject", "fail", w.Callbacks("once memory"), w.Callbacks("once memory"), 1, "rejected"]], r = "pending", i = { state: function () { return r }, always: function () { return o.done(arguments).fail(arguments), this }, "catch": function (e) { return i.then(null, e) }, pipe: function () { var e = arguments; return w.Deferred(function (t) { w.each(n, function (n, r) { var i = g(e[r[4]]) && e[r[4]]; o[r[1]](function () { var e = i && i.apply(this, arguments); e && g(e.promise) ? e.promise().progress(t.notify).done(t.resolve).fail(t.reject) : t[r[0] + "With"](this, i ? [e] : arguments) }) }), e = null }).promise() }, then: function (t, r, i) { var o = 0; function a(t, n, r, i) { return function () { var s = this, u = arguments, l = function () { var e, l; if (!(t < o)) { if ((e = r.apply(s, u)) === n.promise()) throw new TypeError("Thenable self-resolution"); l = e && ("object" == typeof e || "function" == typeof e) && e.then, g(l) ? i ? l.call(e, a(o, n, I, i), a(o, n, W, i)) : (o++ , l.call(e, a(o, n, I, i), a(o, n, W, i), a(o, n, I, n.notifyWith))) : (r !== I && (s = void 0, u = [e]), (i || n.resolveWith)(s, u)) } }, c = i ? l : function () { try { l() } catch (e) { w.Deferred.exceptionHook && w.Deferred.exceptionHook(e, c.stackTrace), t + 1 >= o && (r !== W && (s = void 0, u = [e]), n.rejectWith(s, u)) } }; t ? c() : (w.Deferred.getStackHook && (c.stackTrace = w.Deferred.getStackHook()), e.setTimeout(c)) } } return w.Deferred(function (e) { n[0][3].add(a(0, e, g(i) ? i : I, e.notifyWith)), n[1][3].add(a(0, e, g(t) ? t : I)), n[2][3].add(a(0, e, g(r) ? r : W)) }).promise() }, promise: function (e) { return null != e ? w.extend(e, i) : i } }, o = {}; return w.each(n, function (e, t) { var a = t[2], s = t[5]; i[t[1]] = a.add, s && a.add(function () { r = s }, n[3 - e][2].disable, n[3 - e][3].disable, n[0][2].lock, n[0][3].lock), a.add(t[3].fire), o[t[0]] = function () { return o[t[0] + "With"](this === o ? void 0 : this, arguments), this }, o[t[0] + "With"] = a.fireWith }), i.promise(o), t && t.call(o, o), o }, when: function (e) { var t = arguments.length, n = t, r = Array(n), i = o.call(arguments), a = w.Deferred(), s = function (e) { return function (n) { r[e] = this, i[e] = arguments.length > 1 ? o.call(arguments) : n, --t || a.resolveWith(r, i) } }; if (t <= 1 && ($(e, a.done(s(n)).resolve, a.reject, !t), "pending" === a.state() || g(i[n] && i[n].then))) return a.then(); while (n--) $(i[n], s(n), a.reject); return a.promise() } }); var B = /^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/; w.Deferred.exceptionHook = function (t, n) { e.console && e.console.warn && t && B.test(t.name) && e.console.warn("jQuery.Deferred exception: " + t.message, t.stack, n) }, w.readyException = function (t) { e.setTimeout(function () { throw t }) }; var F = w.Deferred(); w.fn.ready = function (e) { return F.then(e)["catch"](function (e) { w.readyException(e) }), this }, w.extend({ isReady: !1, readyWait: 1, ready: function (e) { (!0 === e ? --w.readyWait : w.isReady) || (w.isReady = !0, !0 !== e && --w.readyWait > 0 || F.resolveWith(r, [w])) } }), w.ready.then = F.then; function _() { r.removeEventListener("DOMContentLoaded", _), e.removeEventListener("load", _), w.ready() } "complete" === r.readyState || "loading" !== r.readyState && !r.documentElement.doScroll ? e.setTimeout(w.ready) : (r.addEventListener("DOMContentLoaded", _), e.addEventListener("load", _)); var z = function (e, t, n, r, i, o, a) { var s = 0, u = e.length, l = null == n; if ("object" === x(n)) { i = !0; for (s in n) z(e, t, s, n[s], !0, o, a) } else if (void 0 !== r && (i = !0, g(r) || (a = !0), l && (a ? (t.call(e, r), t = null) : (l = t, t = function (e, t, n) { return l.call(w(e), n) })), t)) for (; s < u; s++)t(e[s], n, a ? r : r.call(e[s], s, t(e[s], n))); return i ? e : l ? t.call(e) : u ? t(e[0], n) : o }, X = /^-ms-/, U = /-([a-z])/g; function V(e, t) { return t.toUpperCase() } function G(e) { return e.replace(X, "ms-").replace(U, V) } var Y = function (e) { return 1 === e.nodeType || 9 === e.nodeType || !+e.nodeType }; function Q() { this.expando = w.expando + Q.uid++ } Q.uid = 1, Q.prototype = { cache: function (e) { var t = e[this.expando]; return t || (t = {}, Y(e) && (e.nodeType ? e[this.expando] = t : Object.defineProperty(e, this.expando, { value: t, configurable: !0 }))), t }, set: function (e, t, n) { var r, i = this.cache(e); if ("string" == typeof t) i[G(t)] = n; else for (r in t) i[G(r)] = t[r]; return i }, get: function (e, t) { return void 0 === t ? this.cache(e) : e[this.expando] && e[this.expando][G(t)] }, access: function (e, t, n) { return void 0 === t || t && "string" == typeof t && void 0 === n ? this.get(e, t) : (this.set(e, t, n), void 0 !== n ? n : t) }, remove: function (e, t) { var n, r = e[this.expando]; if (void 0 !== r) { if (void 0 !== t) { n = (t = Array.isArray(t) ? t.map(G) : (t = G(t)) in r ? [t] : t.match(M) || []).length; while (n--) delete r[t[n]] } (void 0 === t || w.isEmptyObject(r)) && (e.nodeType ? e[this.expando] = void 0 : delete e[this.expando]) } }, hasData: function (e) { var t = e[this.expando]; return void 0 !== t && !w.isEmptyObject(t) } }; var J = new Q, K = new Q, Z = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/, ee = /[A-Z]/g; function te(e) { return "true" === e || "false" !== e && ("null" === e ? null : e === +e + "" ? +e : Z.test(e) ? JSON.parse(e) : e) } function ne(e, t, n) { var r; if (void 0 === n && 1 === e.nodeType) if (r = "data-" + t.replace(ee, "-$&").toLowerCase(), "string" == typeof (n = e.getAttribute(r))) { try { n = te(n) } catch (e) { } K.set(e, t, n) } else n = void 0; return n } w.extend({ hasData: function (e) { return K.hasData(e) || J.hasData(e) }, data: function (e, t, n) { return K.access(e, t, n) }, removeData: function (e, t) { K.remove(e, t) }, _data: function (e, t, n) { return J.access(e, t, n) }, _removeData: function (e, t) { J.remove(e, t) } }), w.fn.extend({ data: function (e, t) { var n, r, i, o = this[0], a = o && o.attributes; if (void 0 === e) { if (this.length && (i = K.get(o), 1 === o.nodeType && !J.get(o, "hasDataAttrs"))) { n = a.length; while (n--) a[n] && 0 === (r = a[n].name).indexOf("data-") && (r = G(r.slice(5)), ne(o, r, i[r])); J.set(o, "hasDataAttrs", !0) } return i } return "object" == typeof e ? this.each(function () { K.set(this, e) }) : z(this, function (t) { var n; if (o && void 0 === t) { if (void 0 !== (n = K.get(o, e))) return n; if (void 0 !== (n = ne(o, e))) return n } else this.each(function () { K.set(this, e, t) }) }, null, t, arguments.length > 1, null, !0) }, removeData: function (e) { return this.each(function () { K.remove(this, e) }) } }), w.extend({ queue: function (e, t, n) { var r; if (e) return t = (t || "fx") + "queue", r = J.get(e, t), n && (!r || Array.isArray(n) ? r = J.access(e, t, w.makeArray(n)) : r.push(n)), r || [] }, dequeue: function (e, t) { t = t || "fx"; var n = w.queue(e, t), r = n.length, i = n.shift(), o = w._queueHooks(e, t), a = function () { w.dequeue(e, t) }; "inprogress" === i && (i = n.shift(), r--), i && ("fx" === t && n.unshift("inprogress"), delete o.stop, i.call(e, a, o)), !r && o && o.empty.fire() }, _queueHooks: function (e, t) { var n = t + "queueHooks"; return J.get(e, n) || J.access(e, n, { empty: w.Callbacks("once memory").add(function () { J.remove(e, [t + "queue", n]) }) }) } }), w.fn.extend({ queue: function (e, t) { var n = 2; return "string" != typeof e && (t = e, e = "fx", n--), arguments.length < n ? w.queue(this[0], e) : void 0 === t ? this : this.each(function () { var n = w.queue(this, e, t); w._queueHooks(this, e), "fx" === e && "inprogress" !== n[0] && w.dequeue(this, e) }) }, dequeue: function (e) { return this.each(function () { w.dequeue(this, e) }) }, clearQueue: function (e) { return this.queue(e || "fx", []) }, promise: function (e, t) { var n, r = 1, i = w.Deferred(), o = this, a = this.length, s = function () { --r || i.resolveWith(o, [o]) }; "string" != typeof e && (t = e, e = void 0), e = e || "fx"; while (a--) (n = J.get(o[a], e + "queueHooks")) && n.empty && (r++ , n.empty.add(s)); return s(), i.promise(t) } }); var re = /[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source, ie = new RegExp("^(?:([+-])=|)(" + re + ")([a-z%]*)$", "i"), oe = ["Top", "Right", "Bottom", "Left"], ae = function (e, t) { return "none" === (e = t || e).style.display || "" === e.style.display && w.contains(e.ownerDocument, e) && "none" === w.css(e, "display") }, se = function (e, t, n, r) { var i, o, a = {}; for (o in t) a[o] = e.style[o], e.style[o] = t[o]; i = n.apply(e, r || []); for (o in t) e.style[o] = a[o]; return i }; function ue(e, t, n, r) { var i, o, a = 20, s = r ? function () { return r.cur() } : function () { return w.css(e, t, "") }, u = s(), l = n && n[3] || (w.cssNumber[t] ? "" : "px"), c = (w.cssNumber[t] || "px" !== l && +u) && ie.exec(w.css(e, t)); if (c && c[3] !== l) { u /= 2, l = l || c[3], c = +u || 1; while (a--) w.style(e, t, c + l), (1 - o) * (1 - (o = s() / u || .5)) <= 0 && (a = 0), c /= o; c *= 2, w.style(e, t, c + l), n = n || [] } return n && (c = +c || +u || 0, i = n[1] ? c + (n[1] + 1) * n[2] : +n[2], r && (r.unit = l, r.start = c, r.end = i)), i } var le = {}; function ce(e) { var t, n = e.ownerDocument, r = e.nodeName, i = le[r]; return i || (t = n.body.appendChild(n.createElement(r)), i = w.css(t, "display"), t.parentNode.removeChild(t), "none" === i && (i = "block"), le[r] = i, i) } function fe(e, t) { for (var n, r, i = [], o = 0, a = e.length; o < a; o++)(r = e[o]).style && (n = r.style.display, t ? ("none" === n && (i[o] = J.get(r, "display") || null, i[o] || (r.style.display = "")), "" === r.style.display && ae(r) && (i[o] = ce(r))) : "none" !== n && (i[o] = "none", J.set(r, "display", n))); for (o = 0; o < a; o++)null != i[o] && (e[o].style.display = i[o]); return e } w.fn.extend({ show: function () { return fe(this, !0) }, hide: function () { return fe(this) }, toggle: function (e) { return "boolean" == typeof e ? e ? this.show() : this.hide() : this.each(function () { ae(this) ? w(this).show() : w(this).hide() }) } }); var pe = /^(?:checkbox|radio)$/i, de = /<([a-z][^\/\0>\x20\t\r\n\f]+)/i, he = /^$|^module$|\/(?:java|ecma)script/i, ge = { option: [1, "<select multiple='multiple'>", "</select>"], thead: [1, "<table>", "</table>"], col: [2, "<table><colgroup>", "</colgroup></table>"], tr: [2, "<table><tbody>", "</tbody></table>"], td: [3, "<table><tbody><tr>", "</tr></tbody></table>"], _default: [0, "", ""] }; ge.optgroup = ge.option, ge.tbody = ge.tfoot = ge.colgroup = ge.caption = ge.thead, ge.th = ge.td; function ye(e, t) { var n; return n = "undefined" != typeof e.getElementsByTagName ? e.getElementsByTagName(t || "*") : "undefined" != typeof e.querySelectorAll ? e.querySelectorAll(t || "*") : [], void 0 === t || t && N(e, t) ? w.merge([e], n) : n } function ve(e, t) { for (var n = 0, r = e.length; n < r; n++)J.set(e[n], "globalEval", !t || J.get(t[n], "globalEval")) } var me = /<|&#?\w+;/; function xe(e, t, n, r, i) { for (var o, a, s, u, l, c, f = t.createDocumentFragment(), p = [], d = 0, h = e.length; d < h; d++)if ((o = e[d]) || 0 === o) if ("object" === x(o)) w.merge(p, o.nodeType ? [o] : o); else if (me.test(o)) { a = a || f.appendChild(t.createElement("div")), s = (de.exec(o) || ["", ""])[1].toLowerCase(), u = ge[s] || ge._default, a.innerHTML = u[1] + w.htmlPrefilter(o) + u[2], c = u[0]; while (c--) a = a.lastChild; w.merge(p, a.childNodes), (a = f.firstChild).textContent = "" } else p.push(t.createTextNode(o)); f.textContent = "", d = 0; while (o = p[d++]) if (r && w.inArray(o, r) > -1) i && i.push(o); else if (l = w.contains(o.ownerDocument, o), a = ye(f.appendChild(o), "script"), l && ve(a), n) { c = 0; while (o = a[c++]) he.test(o.type || "") && n.push(o) } return f } !function () { var e = r.createDocumentFragment().appendChild(r.createElement("div")), t = r.createElement("input"); t.setAttribute("type", "radio"), t.setAttribute("checked", "checked"), t.setAttribute("name", "t"), e.appendChild(t), h.checkClone = e.cloneNode(!0).cloneNode(!0).lastChild.checked, e.innerHTML = "<textarea>x</textarea>", h.noCloneChecked = !!e.cloneNode(!0).lastChild.defaultValue }(); var be = r.documentElement, we = /^key/, Te = /^(?:mouse|pointer|contextmenu|drag|drop)|click/, Ce = /^([^.]*)(?:\.(.+)|)/; function Ee() { return !0 } function ke() { return !1 } function Se() { try { return r.activeElement } catch (e) { } } function De(e, t, n, r, i, o) { var a, s; if ("object" == typeof t) { "string" != typeof n && (r = r || n, n = void 0); for (s in t) De(e, s, n, r, t[s], o); return e } if (null == r && null == i ? (i = n, r = n = void 0) : null == i && ("string" == typeof n ? (i = r, r = void 0) : (i = r, r = n, n = void 0)), !1 === i) i = ke; else if (!i) return e; return 1 === o && (a = i, (i = function (e) { return w().off(e), a.apply(this, arguments) }).guid = a.guid || (a.guid = w.guid++)), e.each(function () { w.event.add(this, t, i, r, n) }) } w.event = { global: {}, add: function (e, t, n, r, i) { var o, a, s, u, l, c, f, p, d, h, g, y = J.get(e); if (y) { n.handler && (n = (o = n).handler, i = o.selector), i && w.find.matchesSelector(be, i), n.guid || (n.guid = w.guid++), (u = y.events) || (u = y.events = {}), (a = y.handle) || (a = y.handle = function (t) { return "undefined" != typeof w && w.event.triggered !== t.type ? w.event.dispatch.apply(e, arguments) : void 0 }), l = (t = (t || "").match(M) || [""]).length; while (l--) d = g = (s = Ce.exec(t[l]) || [])[1], h = (s[2] || "").split(".").sort(), d && (f = w.event.special[d] || {}, d = (i ? f.delegateType : f.bindType) || d, f = w.event.special[d] || {}, c = w.extend({ type: d, origType: g, data: r, handler: n, guid: n.guid, selector: i, needsContext: i && w.expr.match.needsContext.test(i), namespace: h.join(".") }, o), (p = u[d]) || ((p = u[d] = []).delegateCount = 0, f.setup && !1 !== f.setup.call(e, r, h, a) || e.addEventListener && e.addEventListener(d, a)), f.add && (f.add.call(e, c), c.handler.guid || (c.handler.guid = n.guid)), i ? p.splice(p.delegateCount++, 0, c) : p.push(c), w.event.global[d] = !0) } }, remove: function (e, t, n, r, i) { var o, a, s, u, l, c, f, p, d, h, g, y = J.hasData(e) && J.get(e); if (y && (u = y.events)) { l = (t = (t || "").match(M) || [""]).length; while (l--) if (s = Ce.exec(t[l]) || [], d = g = s[1], h = (s[2] || "").split(".").sort(), d) { f = w.event.special[d] || {}, p = u[d = (r ? f.delegateType : f.bindType) || d] || [], s = s[2] && new RegExp("(^|\\.)" + h.join("\\.(?:.*\\.|)") + "(\\.|$)"), a = o = p.length; while (o--) c = p[o], !i && g !== c.origType || n && n.guid !== c.guid || s && !s.test(c.namespace) || r && r !== c.selector && ("**" !== r || !c.selector) || (p.splice(o, 1), c.selector && p.delegateCount-- , f.remove && f.remove.call(e, c)); a && !p.length && (f.teardown && !1 !== f.teardown.call(e, h, y.handle) || w.removeEvent(e, d, y.handle), delete u[d]) } else for (d in u) w.event.remove(e, d + t[l], n, r, !0); w.isEmptyObject(u) && J.remove(e, "handle events") } }, dispatch: function (e) { var t = w.event.fix(e), n, r, i, o, a, s, u = new Array(arguments.length), l = (J.get(this, "events") || {})[t.type] || [], c = w.event.special[t.type] || {}; for (u[0] = t, n = 1; n < arguments.length; n++)u[n] = arguments[n]; if (t.delegateTarget = this, !c.preDispatch || !1 !== c.preDispatch.call(this, t)) { s = w.event.handlers.call(this, t, l), n = 0; while ((o = s[n++]) && !t.isPropagationStopped()) { t.currentTarget = o.elem, r = 0; while ((a = o.handlers[r++]) && !t.isImmediatePropagationStopped()) t.rnamespace && !t.rnamespace.test(a.namespace) || (t.handleObj = a, t.data = a.data, void 0 !== (i = ((w.event.special[a.origType] || {}).handle || a.handler).apply(o.elem, u)) && !1 === (t.result = i) && (t.preventDefault(), t.stopPropagation())) } return c.postDispatch && c.postDispatch.call(this, t), t.result } }, handlers: function (e, t) { var n, r, i, o, a, s = [], u = t.delegateCount, l = e.target; if (u && l.nodeType && !("click" === e.type && e.button >= 1)) for (; l !== this; l = l.parentNode || this)if (1 === l.nodeType && ("click" !== e.type || !0 !== l.disabled)) { for (o = [], a = {}, n = 0; n < u; n++)void 0 === a[i = (r = t[n]).selector + " "] && (a[i] = r.needsContext ? w(i, this).index(l) > -1 : w.find(i, this, null, [l]).length), a[i] && o.push(r); o.length && s.push({ elem: l, handlers: o }) } return l = this, u < t.length && s.push({ elem: l, handlers: t.slice(u) }), s }, addProp: function (e, t) { Object.defineProperty(w.Event.prototype, e, { enumerable: !0, configurable: !0, get: g(t) ? function () { if (this.originalEvent) return t(this.originalEvent) } : function () { if (this.originalEvent) return this.originalEvent[e] }, set: function (t) { Object.defineProperty(this, e, { enumerable: !0, configurable: !0, writable: !0, value: t }) } }) }, fix: function (e) { return e[w.expando] ? e : new w.Event(e) }, special: { load: { noBubble: !0 }, focus: { trigger: function () { if (this !== Se() && this.focus) return this.focus(), !1 }, delegateType: "focusin" }, blur: { trigger: function () { if (this === Se() && this.blur) return this.blur(), !1 }, delegateType: "focusout" }, click: { trigger: function () { if ("checkbox" === this.type && this.click && N(this, "input")) return this.click(), !1 }, _default: function (e) { return N(e.target, "a") } }, beforeunload: { postDispatch: function (e) { void 0 !== e.result && e.originalEvent && (e.originalEvent.returnValue = e.result) } } } }, w.removeEvent = function (e, t, n) { e.removeEventListener && e.removeEventListener(t, n) }, w.Event = function (e, t) { if (!(this instanceof w.Event)) return new w.Event(e, t); e && e.type ? (this.originalEvent = e, this.type = e.type, this.isDefaultPrevented = e.defaultPrevented || void 0 === e.defaultPrevented && !1 === e.returnValue ? Ee : ke, this.target = e.target && 3 === e.target.nodeType ? e.target.parentNode : e.target, this.currentTarget = e.currentTarget, this.relatedTarget = e.relatedTarget) : this.type = e, t && w.extend(this, t), this.timeStamp = e && e.timeStamp || Date.now(), this[w.expando] = !0 }, w.Event.prototype = { constructor: w.Event, isDefaultPrevented: ke, isPropagationStopped: ke, isImmediatePropagationStopped: ke, isSimulated: !1, preventDefault: function () { var e = this.originalEvent; this.isDefaultPrevented = Ee, e && !this.isSimulated && e.preventDefault() }, stopPropagation: function () { var e = this.originalEvent; this.isPropagationStopped = Ee, e && !this.isSimulated && e.stopPropagation() }, stopImmediatePropagation: function () { var e = this.originalEvent; this.isImmediatePropagationStopped = Ee, e && !this.isSimulated && e.stopImmediatePropagation(), this.stopPropagation() } }, w.each({ altKey: !0, bubbles: !0, cancelable: !0, changedTouches: !0, ctrlKey: !0, detail: !0, eventPhase: !0, metaKey: !0, pageX: !0, pageY: !0, shiftKey: !0, view: !0, "char": !0, charCode: !0, key: !0, keyCode: !0, button: !0, buttons: !0, clientX: !0, clientY: !0, offsetX: !0, offsetY: !0, pointerId: !0, pointerType: !0, screenX: !0, screenY: !0, targetTouches: !0, toElement: !0, touches: !0, which: function (e) { var t = e.button; return null == e.which && we.test(e.type) ? null != e.charCode ? e.charCode : e.keyCode : !e.which && void 0 !== t && Te.test(e.type) ? 1 & t ? 1 : 2 & t ? 3 : 4 & t ? 2 : 0 : e.which } }, w.event.addProp), w.each({ mouseenter: "mouseover", mouseleave: "mouseout", pointerenter: "pointerover", pointerleave: "pointerout" }, function (e, t) { w.event.special[e] = { delegateType: t, bindType: t, handle: function (e) { var n, r = this, i = e.relatedTarget, o = e.handleObj; return i && (i === r || w.contains(r, i)) || (e.type = o.origType, n = o.handler.apply(this, arguments), e.type = t), n } } }), w.fn.extend({ on: function (e, t, n, r) { return De(this, e, t, n, r) }, one: function (e, t, n, r) { return De(this, e, t, n, r, 1) }, off: function (e, t, n) { var r, i; if (e && e.preventDefault && e.handleObj) return r = e.handleObj, w(e.delegateTarget).off(r.namespace ? r.origType + "." + r.namespace : r.origType, r.selector, r.handler), this; if ("object" == typeof e) { for (i in e) this.off(i, t, e[i]); return this } return !1 !== t && "function" != typeof t || (n = t, t = void 0), !1 === n && (n = ke), this.each(function () { w.event.remove(this, e, n, t) }) } }); var Ne = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi, Ae = /<script|<style|<link/i, je = /checked\s*(?:[^=]|=\s*.checked.)/i, qe = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g; function Le(e, t) { return N(e, "table") && N(11 !== t.nodeType ? t : t.firstChild, "tr") ? w(e).children("tbody")[0] || e : e } function He(e) { return e.type = (null !== e.getAttribute("type")) + "/" + e.type, e } function Oe(e) { return "true/" === (e.type || "").slice(0, 5) ? e.type = e.type.slice(5) : e.removeAttribute("type"), e } function Pe(e, t) { var n, r, i, o, a, s, u, l; if (1 === t.nodeType) { if (J.hasData(e) && (o = J.access(e), a = J.set(t, o), l = o.events)) { delete a.handle, a.events = {}; for (i in l) for (n = 0, r = l[i].length; n < r; n++)w.event.add(t, i, l[i][n]) } K.hasData(e) && (s = K.access(e), u = w.extend({}, s), K.set(t, u)) } } function Me(e, t) { var n = t.nodeName.toLowerCase(); "input" === n && pe.test(e.type) ? t.checked = e.checked : "input" !== n && "textarea" !== n || (t.defaultValue = e.defaultValue) } function Re(e, t, n, r) { t = a.apply([], t); var i, o, s, u, l, c, f = 0, p = e.length, d = p - 1, y = t[0], v = g(y); if (v || p > 1 && "string" == typeof y && !h.checkClone && je.test(y)) return e.each(function (i) { var o = e.eq(i); v && (t[0] = y.call(this, i, o.html())), Re(o, t, n, r) }); if (p && (i = xe(t, e[0].ownerDocument, !1, e, r), o = i.firstChild, 1 === i.childNodes.length && (i = o), o || r)) { for (u = (s = w.map(ye(i, "script"), He)).length; f < p; f++)l = i, f !== d && (l = w.clone(l, !0, !0), u && w.merge(s, ye(l, "script"))), n.call(e[f], l, f); if (u) for (c = s[s.length - 1].ownerDocument, w.map(s, Oe), f = 0; f < u; f++)l = s[f], he.test(l.type || "") && !J.access(l, "globalEval") && w.contains(c, l) && (l.src && "module" !== (l.type || "").toLowerCase() ? w._evalUrl && w._evalUrl(l.src) : m(l.textContent.replace(qe, ""), c, l)) } return e } function Ie(e, t, n) { for (var r, i = t ? w.filter(t, e) : e, o = 0; null != (r = i[o]); o++)n || 1 !== r.nodeType || w.cleanData(ye(r)), r.parentNode && (n && w.contains(r.ownerDocument, r) && ve(ye(r, "script")), r.parentNode.removeChild(r)); return e } w.extend({ htmlPrefilter: function (e) { return e.replace(Ne, "<$1></$2>") }, clone: function (e, t, n) { var r, i, o, a, s = e.cloneNode(!0), u = w.contains(e.ownerDocument, e); if (!(h.noCloneChecked || 1 !== e.nodeType && 11 !== e.nodeType || w.isXMLDoc(e))) for (a = ye(s), r = 0, i = (o = ye(e)).length; r < i; r++)Me(o[r], a[r]); if (t) if (n) for (o = o || ye(e), a = a || ye(s), r = 0, i = o.length; r < i; r++)Pe(o[r], a[r]); else Pe(e, s); return (a = ye(s, "script")).length > 0 && ve(a, !u && ye(e, "script")), s }, cleanData: function (e) { for (var t, n, r, i = w.event.special, o = 0; void 0 !== (n = e[o]); o++)if (Y(n)) { if (t = n[J.expando]) { if (t.events) for (r in t.events) i[r] ? w.event.remove(n, r) : w.removeEvent(n, r, t.handle); n[J.expando] = void 0 } n[K.expando] && (n[K.expando] = void 0) } } }), w.fn.extend({ detach: function (e) { return Ie(this, e, !0) }, remove: function (e) { return Ie(this, e) }, text: function (e) { return z(this, function (e) { return void 0 === e ? w.text(this) : this.empty().each(function () { 1 !== this.nodeType && 11 !== this.nodeType && 9 !== this.nodeType || (this.textContent = e) }) }, null, e, arguments.length) }, append: function () { return Re(this, arguments, function (e) { 1 !== this.nodeType && 11 !== this.nodeType && 9 !== this.nodeType || Le(this, e).appendChild(e) }) }, prepend: function () { return Re(this, arguments, function (e) { if (1 === this.nodeType || 11 === this.nodeType || 9 === this.nodeType) { var t = Le(this, e); t.insertBefore(e, t.firstChild) } }) }, before: function () { return Re(this, arguments, function (e) { this.parentNode && this.parentNode.insertBefore(e, this) }) }, after: function () { return Re(this, arguments, function (e) { this.parentNode && this.parentNode.insertBefore(e, this.nextSibling) }) }, empty: function () { for (var e, t = 0; null != (e = this[t]); t++)1 === e.nodeType && (w.cleanData(ye(e, !1)), e.textContent = ""); return this }, clone: function (e, t) { return e = null != e && e, t = null == t ? e : t, this.map(function () { return w.clone(this, e, t) }) }, html: function (e) { return z(this, function (e) { var t = this[0] || {}, n = 0, r = this.length; if (void 0 === e && 1 === t.nodeType) return t.innerHTML; if ("string" == typeof e && !Ae.test(e) && !ge[(de.exec(e) || ["", ""])[1].toLowerCase()]) { e = w.htmlPrefilter(e); try { for (; n < r; n++)1 === (t = this[n] || {}).nodeType && (w.cleanData(ye(t, !1)), t.innerHTML = e); t = 0 } catch (e) { } } t && this.empty().append(e) }, null, e, arguments.length) }, replaceWith: function () { var e = []; return Re(this, arguments, function (t) { var n = this.parentNode; w.inArray(this, e) < 0 && (w.cleanData(ye(this)), n && n.replaceChild(t, this)) }, e) } }), w.each({ appendTo: "append", prependTo: "prepend", insertBefore: "before", insertAfter: "after", replaceAll: "replaceWith" }, function (e, t) { w.fn[e] = function (e) { for (var n, r = [], i = w(e), o = i.length - 1, a = 0; a <= o; a++)n = a === o ? this : this.clone(!0), w(i[a])[t](n), s.apply(r, n.get()); return this.pushStack(r) } }); var We = new RegExp("^(" + re + ")(?!px)[a-z%]+$", "i"), $e = function (t) { var n = t.ownerDocument.defaultView; return n && n.opener || (n = e), n.getComputedStyle(t) }, Be = new RegExp(oe.join("|"), "i"); !function () { function t() { if (c) { l.style.cssText = "position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0", c.style.cssText = "position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%", be.appendChild(l).appendChild(c); var t = e.getComputedStyle(c); i = "1%" !== t.top, u = 12 === n(t.marginLeft), c.style.right = "60%", s = 36 === n(t.right), o = 36 === n(t.width), c.style.position = "absolute", a = 36 === c.offsetWidth || "absolute", be.removeChild(l), c = null } } function n(e) { return Math.round(parseFloat(e)) } var i, o, a, s, u, l = r.createElement("div"), c = r.createElement("div"); c.style && (c.style.backgroundClip = "content-box", c.cloneNode(!0).style.backgroundClip = "", h.clearCloneStyle = "content-box" === c.style.backgroundClip, w.extend(h, { boxSizingReliable: function () { return t(), o }, pixelBoxStyles: function () { return t(), s }, pixelPosition: function () { return t(), i }, reliableMarginLeft: function () { return t(), u }, scrollboxSize: function () { return t(), a } })) }(); function Fe(e, t, n) { var r, i, o, a, s = e.style; return (n = n || $e(e)) && ("" !== (a = n.getPropertyValue(t) || n[t]) || w.contains(e.ownerDocument, e) || (a = w.style(e, t)), !h.pixelBoxStyles() && We.test(a) && Be.test(t) && (r = s.width, i = s.minWidth, o = s.maxWidth, s.minWidth = s.maxWidth = s.width = a, a = n.width, s.width = r, s.minWidth = i, s.maxWidth = o)), void 0 !== a ? a + "" : a } function _e(e, t) { return { get: function () { if (!e()) return (this.get = t).apply(this, arguments); delete this.get } } } var ze = /^(none|table(?!-c[ea]).+)/, Xe = /^--/, Ue = { position: "absolute", visibility: "hidden", display: "block" }, Ve = { letterSpacing: "0", fontWeight: "400" }, Ge = ["Webkit", "Moz", "ms"], Ye = r.createElement("div").style; function Qe(e) { if (e in Ye) return e; var t = e[0].toUpperCase() + e.slice(1), n = Ge.length; while (n--) if ((e = Ge[n] + t) in Ye) return e } function Je(e) { var t = w.cssProps[e]; return t || (t = w.cssProps[e] = Qe(e) || e), t } function Ke(e, t, n) { var r = ie.exec(t); return r ? Math.max(0, r[2] - (n || 0)) + (r[3] || "px") : t } function Ze(e, t, n, r, i, o) { var a = "width" === t ? 1 : 0, s = 0, u = 0; if (n === (r ? "border" : "content")) return 0; for (; a < 4; a += 2)"margin" === n && (u += w.css(e, n + oe[a], !0, i)), r ? ("content" === n && (u -= w.css(e, "padding" + oe[a], !0, i)), "margin" !== n && (u -= w.css(e, "border" + oe[a] + "Width", !0, i))) : (u += w.css(e, "padding" + oe[a], !0, i), "padding" !== n ? u += w.css(e, "border" + oe[a] + "Width", !0, i) : s += w.css(e, "border" + oe[a] + "Width", !0, i)); return !r && o >= 0 && (u += Math.max(0, Math.ceil(e["offset" + t[0].toUpperCase() + t.slice(1)] - o - u - s - .5))), u } function et(e, t, n) { var r = $e(e), i = Fe(e, t, r), o = "border-box" === w.css(e, "boxSizing", !1, r), a = o; if (We.test(i)) { if (!n) return i; i = "auto" } return a = a && (h.boxSizingReliable() || i === e.style[t]), ("auto" === i || !parseFloat(i) && "inline" === w.css(e, "display", !1, r)) && (i = e["offset" + t[0].toUpperCase() + t.slice(1)], a = !0), (i = parseFloat(i) || 0) + Ze(e, t, n || (o ? "border" : "content"), a, r, i) + "px" } w.extend({ cssHooks: { opacity: { get: function (e, t) { if (t) { var n = Fe(e, "opacity"); return "" === n ? "1" : n } } } }, cssNumber: { animationIterationCount: !0, columnCount: !0, fillOpacity: !0, flexGrow: !0, flexShrink: !0, fontWeight: !0, lineHeight: !0, opacity: !0, order: !0, orphans: !0, widows: !0, zIndex: !0, zoom: !0 }, cssProps: {}, style: function (e, t, n, r) { if (e && 3 !== e.nodeType && 8 !== e.nodeType && e.style) { var i, o, a, s = G(t), u = Xe.test(t), l = e.style; if (u || (t = Je(s)), a = w.cssHooks[t] || w.cssHooks[s], void 0 === n) return a && "get" in a && void 0 !== (i = a.get(e, !1, r)) ? i : l[t]; "string" == (o = typeof n) && (i = ie.exec(n)) && i[1] && (n = ue(e, t, i), o = "number"), null != n && n === n && ("number" === o && (n += i && i[3] || (w.cssNumber[s] ? "" : "px")), h.clearCloneStyle || "" !== n || 0 !== t.indexOf("background") || (l[t] = "inherit"), a && "set" in a && void 0 === (n = a.set(e, n, r)) || (u ? l.setProperty(t, n) : l[t] = n)) } }, css: function (e, t, n, r) { var i, o, a, s = G(t); return Xe.test(t) || (t = Je(s)), (a = w.cssHooks[t] || w.cssHooks[s]) && "get" in a && (i = a.get(e, !0, n)), void 0 === i && (i = Fe(e, t, r)), "normal" === i && t in Ve && (i = Ve[t]), "" === n || n ? (o = parseFloat(i), !0 === n || isFinite(o) ? o || 0 : i) : i } }), w.each(["height", "width"], function (e, t) { w.cssHooks[t] = { get: function (e, n, r) { if (n) return !ze.test(w.css(e, "display")) || e.getClientRects().length && e.getBoundingClientRect().width ? et(e, t, r) : se(e, Ue, function () { return et(e, t, r) }) }, set: function (e, n, r) { var i, o = $e(e), a = "border-box" === w.css(e, "boxSizing", !1, o), s = r && Ze(e, t, r, a, o); return a && h.scrollboxSize() === o.position && (s -= Math.ceil(e["offset" + t[0].toUpperCase() + t.slice(1)] - parseFloat(o[t]) - Ze(e, t, "border", !1, o) - .5)), s && (i = ie.exec(n)) && "px" !== (i[3] || "px") && (e.style[t] = n, n = w.css(e, t)), Ke(e, n, s) } } }), w.cssHooks.marginLeft = _e(h.reliableMarginLeft, function (e, t) { if (t) return (parseFloat(Fe(e, "marginLeft")) || e.getBoundingClientRect().left - se(e, { marginLeft: 0 }, function () { return e.getBoundingClientRect().left })) + "px" }), w.each({ margin: "", padding: "", border: "Width" }, function (e, t) { w.cssHooks[e + t] = { expand: function (n) { for (var r = 0, i = {}, o = "string" == typeof n ? n.split(" ") : [n]; r < 4; r++)i[e + oe[r] + t] = o[r] || o[r - 2] || o[0]; return i } }, "margin" !== e && (w.cssHooks[e + t].set = Ke) }), w.fn.extend({ css: function (e, t) { return z(this, function (e, t, n) { var r, i, o = {}, a = 0; if (Array.isArray(t)) { for (r = $e(e), i = t.length; a < i; a++)o[t[a]] = w.css(e, t[a], !1, r); return o } return void 0 !== n ? w.style(e, t, n) : w.css(e, t) }, e, t, arguments.length > 1) } }); function tt(e, t, n, r, i) { return new tt.prototype.init(e, t, n, r, i) } w.Tween = tt, tt.prototype = { constructor: tt, init: function (e, t, n, r, i, o) { this.elem = e, this.prop = n, this.easing = i || w.easing._default, this.options = t, this.start = this.now = this.cur(), this.end = r, this.unit = o || (w.cssNumber[n] ? "" : "px") }, cur: function () { var e = tt.propHooks[this.prop]; return e && e.get ? e.get(this) : tt.propHooks._default.get(this) }, run: function (e) { var t, n = tt.propHooks[this.prop]; return this.options.duration ? this.pos = t = w.easing[this.easing](e, this.options.duration * e, 0, 1, this.options.duration) : this.pos = t = e, this.now = (this.end - this.start) * t + this.start, this.options.step && this.options.step.call(this.elem, this.now, this), n && n.set ? n.set(this) : tt.propHooks._default.set(this), this } }, tt.prototype.init.prototype = tt.prototype, tt.propHooks = { _default: { get: function (e) { var t; return 1 !== e.elem.nodeType || null != e.elem[e.prop] && null == e.elem.style[e.prop] ? e.elem[e.prop] : (t = w.css(e.elem, e.prop, "")) && "auto" !== t ? t : 0 }, set: function (e) { w.fx.step[e.prop] ? w.fx.step[e.prop](e) : 1 !== e.elem.nodeType || null == e.elem.style[w.cssProps[e.prop]] && !w.cssHooks[e.prop] ? e.elem[e.prop] = e.now : w.style(e.elem, e.prop, e.now + e.unit) } } }, tt.propHooks.scrollTop = tt.propHooks.scrollLeft = { set: function (e) { e.elem.nodeType && e.elem.parentNode && (e.elem[e.prop] = e.now) } }, w.easing = { linear: function (e) { return e }, swing: function (e) { return .5 - Math.cos(e * Math.PI) / 2 }, _default: "swing" }, w.fx = tt.prototype.init, w.fx.step = {}; var nt, rt, it = /^(?:toggle|show|hide)$/, ot = /queueHooks$/; function at() { rt && (!1 === r.hidden && e.requestAnimationFrame ? e.requestAnimationFrame(at) : e.setTimeout(at, w.fx.interval), w.fx.tick()) } function st() { return e.setTimeout(function () { nt = void 0 }), nt = Date.now() } function ut(e, t) { var n, r = 0, i = { height: e }; for (t = t ? 1 : 0; r < 4; r += 2 - t)i["margin" + (n = oe[r])] = i["padding" + n] = e; return t && (i.opacity = i.width = e), i } function lt(e, t, n) { for (var r, i = (pt.tweeners[t] || []).concat(pt.tweeners["*"]), o = 0, a = i.length; o < a; o++)if (r = i[o].call(n, t, e)) return r } function ct(e, t, n) { var r, i, o, a, s, u, l, c, f = "width" in t || "height" in t, p = this, d = {}, h = e.style, g = e.nodeType && ae(e), y = J.get(e, "fxshow"); n.queue || (null == (a = w._queueHooks(e, "fx")).unqueued && (a.unqueued = 0, s = a.empty.fire, a.empty.fire = function () { a.unqueued || s() }), a.unqueued++ , p.always(function () { p.always(function () { a.unqueued-- , w.queue(e, "fx").length || a.empty.fire() }) })); for (r in t) if (i = t[r], it.test(i)) { if (delete t[r], o = o || "toggle" === i, i === (g ? "hide" : "show")) { if ("show" !== i || !y || void 0 === y[r]) continue; g = !0 } d[r] = y && y[r] || w.style(e, r) } if ((u = !w.isEmptyObject(t)) || !w.isEmptyObject(d)) { f && 1 === e.nodeType && (n.overflow = [h.overflow, h.overflowX, h.overflowY], null == (l = y && y.display) && (l = J.get(e, "display")), "none" === (c = w.css(e, "display")) && (l ? c = l : (fe([e], !0), l = e.style.display || l, c = w.css(e, "display"), fe([e]))), ("inline" === c || "inline-block" === c && null != l) && "none" === w.css(e, "float") && (u || (p.done(function () { h.display = l }), null == l && (c = h.display, l = "none" === c ? "" : c)), h.display = "inline-block")), n.overflow && (h.overflow = "hidden", p.always(function () { h.overflow = n.overflow[0], h.overflowX = n.overflow[1], h.overflowY = n.overflow[2] })), u = !1; for (r in d) u || (y ? "hidden" in y && (g = y.hidden) : y = J.access(e, "fxshow", { display: l }), o && (y.hidden = !g), g && fe([e], !0), p.done(function () { g || fe([e]), J.remove(e, "fxshow"); for (r in d) w.style(e, r, d[r]) })), u = lt(g ? y[r] : 0, r, p), r in y || (y[r] = u.start, g && (u.end = u.start, u.start = 0)) } } function ft(e, t) { var n, r, i, o, a; for (n in e) if (r = G(n), i = t[r], o = e[n], Array.isArray(o) && (i = o[1], o = e[n] = o[0]), n !== r && (e[r] = o, delete e[n]), (a = w.cssHooks[r]) && "expand" in a) { o = a.expand(o), delete e[r]; for (n in o) n in e || (e[n] = o[n], t[n] = i) } else t[r] = i } function pt(e, t, n) { var r, i, o = 0, a = pt.prefilters.length, s = w.Deferred().always(function () { delete u.elem }), u = function () { if (i) return !1; for (var t = nt || st(), n = Math.max(0, l.startTime + l.duration - t), r = 1 - (n / l.duration || 0), o = 0, a = l.tweens.length; o < a; o++)l.tweens[o].run(r); return s.notifyWith(e, [l, r, n]), r < 1 && a ? n : (a || s.notifyWith(e, [l, 1, 0]), s.resolveWith(e, [l]), !1) }, l = s.promise({ elem: e, props: w.extend({}, t), opts: w.extend(!0, { specialEasing: {}, easing: w.easing._default }, n), originalProperties: t, originalOptions: n, startTime: nt || st(), duration: n.duration, tweens: [], createTween: function (t, n) { var r = w.Tween(e, l.opts, t, n, l.opts.specialEasing[t] || l.opts.easing); return l.tweens.push(r), r }, stop: function (t) { var n = 0, r = t ? l.tweens.length : 0; if (i) return this; for (i = !0; n < r; n++)l.tweens[n].run(1); return t ? (s.notifyWith(e, [l, 1, 0]), s.resolveWith(e, [l, t])) : s.rejectWith(e, [l, t]), this } }), c = l.props; for (ft(c, l.opts.specialEasing); o < a; o++)if (r = pt.prefilters[o].call(l, e, c, l.opts)) return g(r.stop) && (w._queueHooks(l.elem, l.opts.queue).stop = r.stop.bind(r)), r; return w.map(c, lt, l), g(l.opts.start) && l.opts.start.call(e, l), l.progress(l.opts.progress).done(l.opts.done, l.opts.complete).fail(l.opts.fail).always(l.opts.always), w.fx.timer(w.extend(u, { elem: e, anim: l, queue: l.opts.queue })), l } w.Animation = w.extend(pt, { tweeners: { "*": [function (e, t) { var n = this.createTween(e, t); return ue(n.elem, e, ie.exec(t), n), n }] }, tweener: function (e, t) { g(e) ? (t = e, e = ["*"]) : e = e.match(M); for (var n, r = 0, i = e.length; r < i; r++)n = e[r], pt.tweeners[n] = pt.tweeners[n] || [], pt.tweeners[n].unshift(t) }, prefilters: [ct], prefilter: function (e, t) { t ? pt.prefilters.unshift(e) : pt.prefilters.push(e) } }), w.speed = function (e, t, n) { var r = e && "object" == typeof e ? w.extend({}, e) : { complete: n || !n && t || g(e) && e, duration: e, easing: n && t || t && !g(t) && t }; return w.fx.off ? r.duration = 0 : "number" != typeof r.duration && (r.duration in w.fx.speeds ? r.duration = w.fx.speeds[r.duration] : r.duration = w.fx.speeds._default), null != r.queue && !0 !== r.queue || (r.queue = "fx"), r.old = r.complete, r.complete = function () { g(r.old) && r.old.call(this), r.queue && w.dequeue(this, r.queue) }, r }, w.fn.extend({ fadeTo: function (e, t, n, r) { return this.filter(ae).css("opacity", 0).show().end().animate({ opacity: t }, e, n, r) }, animate: function (e, t, n, r) { var i = w.isEmptyObject(e), o = w.speed(t, n, r), a = function () { var t = pt(this, w.extend({}, e), o); (i || J.get(this, "finish")) && t.stop(!0) }; return a.finish = a, i || !1 === o.queue ? this.each(a) : this.queue(o.queue, a) }, stop: function (e, t, n) { var r = function (e) { var t = e.stop; delete e.stop, t(n) }; return "string" != typeof e && (n = t, t = e, e = void 0), t && !1 !== e && this.queue(e || "fx", []), this.each(function () { var t = !0, i = null != e && e + "queueHooks", o = w.timers, a = J.get(this); if (i) a[i] && a[i].stop && r(a[i]); else for (i in a) a[i] && a[i].stop && ot.test(i) && r(a[i]); for (i = o.length; i--;)o[i].elem !== this || null != e && o[i].queue !== e || (o[i].anim.stop(n), t = !1, o.splice(i, 1)); !t && n || w.dequeue(this, e) }) }, finish: function (e) { return !1 !== e && (e = e || "fx"), this.each(function () { var t, n = J.get(this), r = n[e + "queue"], i = n[e + "queueHooks"], o = w.timers, a = r ? r.length : 0; for (n.finish = !0, w.queue(this, e, []), i && i.stop && i.stop.call(this, !0), t = o.length; t--;)o[t].elem === this && o[t].queue === e && (o[t].anim.stop(!0), o.splice(t, 1)); for (t = 0; t < a; t++)r[t] && r[t].finish && r[t].finish.call(this); delete n.finish }) } }), w.each(["toggle", "show", "hide"], function (e, t) { var n = w.fn[t]; w.fn[t] = function (e, r, i) { return null == e || "boolean" == typeof e ? n.apply(this, arguments) : this.animate(ut(t, !0), e, r, i) } }), w.each({ slideDown: ut("show"), slideUp: ut("hide"), slideToggle: ut("toggle"), fadeIn: { opacity: "show" }, fadeOut: { opacity: "hide" }, fadeToggle: { opacity: "toggle" } }, function (e, t) { w.fn[e] = function (e, n, r) { return this.animate(t, e, n, r) } }), w.timers = [], w.fx.tick = function () { var e, t = 0, n = w.timers; for (nt = Date.now(); t < n.length; t++)(e = n[t])() || n[t] !== e || n.splice(t--, 1); n.length || w.fx.stop(), nt = void 0 }, w.fx.timer = function (e) { w.timers.push(e), w.fx.start() }, w.fx.interval = 13, w.fx.start = function () { rt || (rt = !0, at()) }, w.fx.stop = function () { rt = null }, w.fx.speeds = { slow: 600, fast: 200, _default: 400 }, w.fn.delay = function (t, n) { return t = w.fx ? w.fx.speeds[t] || t : t, n = n || "fx", this.queue(n, function (n, r) { var i = e.setTimeout(n, t); r.stop = function () { e.clearTimeout(i) } }) }, function () { var e = r.createElement("input"), t = r.createElement("select").appendChild(r.createElement("option")); e.type = "checkbox", h.checkOn = "" !== e.value, h.optSelected = t.selected, (e = r.createElement("input")).value = "t", e.type = "radio", h.radioValue = "t" === e.value }(); var dt, ht = w.expr.attrHandle; w.fn.extend({ attr: function (e, t) { return z(this, w.attr, e, t, arguments.length > 1) }, removeAttr: function (e) { return this.each(function () { w.removeAttr(this, e) }) } }), w.extend({ attr: function (e, t, n) { var r, i, o = e.nodeType; if (3 !== o && 8 !== o && 2 !== o) return "undefined" == typeof e.getAttribute ? w.prop(e, t, n) : (1 === o && w.isXMLDoc(e) || (i = w.attrHooks[t.toLowerCase()] || (w.expr.match.bool.test(t) ? dt : void 0)), void 0 !== n ? null === n ? void w.removeAttr(e, t) : i && "set" in i && void 0 !== (r = i.set(e, n, t)) ? r : (e.setAttribute(t, n + ""), n) : i && "get" in i && null !== (r = i.get(e, t)) ? r : null == (r = w.find.attr(e, t)) ? void 0 : r) }, attrHooks: { type: { set: function (e, t) { if (!h.radioValue && "radio" === t && N(e, "input")) { var n = e.value; return e.setAttribute("type", t), n && (e.value = n), t } } } }, removeAttr: function (e, t) { var n, r = 0, i = t && t.match(M); if (i && 1 === e.nodeType) while (n = i[r++]) e.removeAttribute(n) } }), dt = { set: function (e, t, n) { return !1 === t ? w.removeAttr(e, n) : e.setAttribute(n, n), n } }, w.each(w.expr.match.bool.source.match(/\w+/g), function (e, t) { var n = ht[t] || w.find.attr; ht[t] = function (e, t, r) { var i, o, a = t.toLowerCase(); return r || (o = ht[a], ht[a] = i, i = null != n(e, t, r) ? a : null, ht[a] = o), i } }); var gt = /^(?:input|select|textarea|button)$/i, yt = /^(?:a|area)$/i; w.fn.extend({ prop: function (e, t) { return z(this, w.prop, e, t, arguments.length > 1) }, removeProp: function (e) { return this.each(function () { delete this[w.propFix[e] || e] }) } }), w.extend({ prop: function (e, t, n) { var r, i, o = e.nodeType; if (3 !== o && 8 !== o && 2 !== o) return 1 === o && w.isXMLDoc(e) || (t = w.propFix[t] || t, i = w.propHooks[t]), void 0 !== n ? i && "set" in i && void 0 !== (r = i.set(e, n, t)) ? r : e[t] = n : i && "get" in i && null !== (r = i.get(e, t)) ? r : e[t] }, propHooks: { tabIndex: { get: function (e) { var t = w.find.attr(e, "tabindex"); return t ? parseInt(t, 10) : gt.test(e.nodeName) || yt.test(e.nodeName) && e.href ? 0 : -1 } } }, propFix: { "for": "htmlFor", "class": "className" } }), h.optSelected || (w.propHooks.selected = { get: function (e) { var t = e.parentNode; return t && t.parentNode && t.parentNode.selectedIndex, null }, set: function (e) { var t = e.parentNode; t && (t.selectedIndex, t.parentNode && t.parentNode.selectedIndex) } }), w.each(["tabIndex", "readOnly", "maxLength", "cellSpacing", "cellPadding", "rowSpan", "colSpan", "useMap", "frameBorder", "contentEditable"], function () { w.propFix[this.toLowerCase()] = this }); function vt(e) { return (e.match(M) || []).join(" ") } function mt(e) { return e.getAttribute && e.getAttribute("class") || "" } function xt(e) { return Array.isArray(e) ? e : "string" == typeof e ? e.match(M) || [] : [] } w.fn.extend({ addClass: function (e) { var t, n, r, i, o, a, s, u = 0; if (g(e)) return this.each(function (t) { w(this).addClass(e.call(this, t, mt(this))) }); if ((t = xt(e)).length) while (n = this[u++]) if (i = mt(n), r = 1 === n.nodeType && " " + vt(i) + " ") { a = 0; while (o = t[a++]) r.indexOf(" " + o + " ") < 0 && (r += o + " "); i !== (s = vt(r)) && n.setAttribute("class", s) } return this }, removeClass: function (e) { var t, n, r, i, o, a, s, u = 0; if (g(e)) return this.each(function (t) { w(this).removeClass(e.call(this, t, mt(this))) }); if (!arguments.length) return this.attr("class", ""); if ((t = xt(e)).length) while (n = this[u++]) if (i = mt(n), r = 1 === n.nodeType && " " + vt(i) + " ") { a = 0; while (o = t[a++]) while (r.indexOf(" " + o + " ") > -1) r = r.replace(" " + o + " ", " "); i !== (s = vt(r)) && n.setAttribute("class", s) } return this }, toggleClass: function (e, t) { var n = typeof e, r = "string" === n || Array.isArray(e); return "boolean" == typeof t && r ? t ? this.addClass(e) : this.removeClass(e) : g(e) ? this.each(function (n) { w(this).toggleClass(e.call(this, n, mt(this), t), t) }) : this.each(function () { var t, i, o, a; if (r) { i = 0, o = w(this), a = xt(e); while (t = a[i++]) o.hasClass(t) ? o.removeClass(t) : o.addClass(t) } else void 0 !== e && "boolean" !== n || ((t = mt(this)) && J.set(this, "__className__", t), this.setAttribute && this.setAttribute("class", t || !1 === e ? "" : J.get(this, "__className__") || "")) }) }, hasClass: function (e) { var t, n, r = 0; t = " " + e + " "; while (n = this[r++]) if (1 === n.nodeType && (" " + vt(mt(n)) + " ").indexOf(t) > -1) return !0; return !1 } }); var bt = /\r/g; w.fn.extend({ val: function (e) { var t, n, r, i = this[0]; { if (arguments.length) return r = g(e), this.each(function (n) { var i; 1 === this.nodeType && (null == (i = r ? e.call(this, n, w(this).val()) : e) ? i = "" : "number" == typeof i ? i += "" : Array.isArray(i) && (i = w.map(i, function (e) { return null == e ? "" : e + "" })), (t = w.valHooks[this.type] || w.valHooks[this.nodeName.toLowerCase()]) && "set" in t && void 0 !== t.set(this, i, "value") || (this.value = i)) }); if (i) return (t = w.valHooks[i.type] || w.valHooks[i.nodeName.toLowerCase()]) && "get" in t && void 0 !== (n = t.get(i, "value")) ? n : "string" == typeof (n = i.value) ? n.replace(bt, "") : null == n ? "" : n } } }), w.extend({ valHooks: { option: { get: function (e) { var t = w.find.attr(e, "value"); return null != t ? t : vt(w.text(e)) } }, select: { get: function (e) { var t, n, r, i = e.options, o = e.selectedIndex, a = "select-one" === e.type, s = a ? null : [], u = a ? o + 1 : i.length; for (r = o < 0 ? u : a ? o : 0; r < u; r++)if (((n = i[r]).selected || r === o) && !n.disabled && (!n.parentNode.disabled || !N(n.parentNode, "optgroup"))) { if (t = w(n).val(), a) return t; s.push(t) } return s }, set: function (e, t) { var n, r, i = e.options, o = w.makeArray(t), a = i.length; while (a--) ((r = i[a]).selected = w.inArray(w.valHooks.option.get(r), o) > -1) && (n = !0); return n || (e.selectedIndex = -1), o } } } }), w.each(["radio", "checkbox"], function () { w.valHooks[this] = { set: function (e, t) { if (Array.isArray(t)) return e.checked = w.inArray(w(e).val(), t) > -1 } }, h.checkOn || (w.valHooks[this].get = function (e) { return null === e.getAttribute("value") ? "on" : e.value }) }), h.focusin = "onfocusin" in e; var wt = /^(?:focusinfocus|focusoutblur)$/, Tt = function (e) { e.stopPropagation() }; w.extend(w.event, { trigger: function (t, n, i, o) { var a, s, u, l, c, p, d, h, v = [i || r], m = f.call(t, "type") ? t.type : t, x = f.call(t, "namespace") ? t.namespace.split(".") : []; if (s = h = u = i = i || r, 3 !== i.nodeType && 8 !== i.nodeType && !wt.test(m + w.event.triggered) && (m.indexOf(".") > -1 && (m = (x = m.split(".")).shift(), x.sort()), c = m.indexOf(":") < 0 && "on" + m, t = t[w.expando] ? t : new w.Event(m, "object" == typeof t && t), t.isTrigger = o ? 2 : 3, t.namespace = x.join("."), t.rnamespace = t.namespace ? new RegExp("(^|\\.)" + x.join("\\.(?:.*\\.|)") + "(\\.|$)") : null, t.result = void 0, t.target || (t.target = i), n = null == n ? [t] : w.makeArray(n, [t]), d = w.event.special[m] || {}, o || !d.trigger || !1 !== d.trigger.apply(i, n))) { if (!o && !d.noBubble && !y(i)) { for (l = d.delegateType || m, wt.test(l + m) || (s = s.parentNode); s; s = s.parentNode)v.push(s), u = s; u === (i.ownerDocument || r) && v.push(u.defaultView || u.parentWindow || e) } a = 0; while ((s = v[a++]) && !t.isPropagationStopped()) h = s, t.type = a > 1 ? l : d.bindType || m, (p = (J.get(s, "events") || {})[t.type] && J.get(s, "handle")) && p.apply(s, n), (p = c && s[c]) && p.apply && Y(s) && (t.result = p.apply(s, n), !1 === t.result && t.preventDefault()); return t.type = m, o || t.isDefaultPrevented() || d._default && !1 !== d._default.apply(v.pop(), n) || !Y(i) || c && g(i[m]) && !y(i) && ((u = i[c]) && (i[c] = null), w.event.triggered = m, t.isPropagationStopped() && h.addEventListener(m, Tt), i[m](), t.isPropagationStopped() && h.removeEventListener(m, Tt), w.event.triggered = void 0, u && (i[c] = u)), t.result } }, simulate: function (e, t, n) { var r = w.extend(new w.Event, n, { type: e, isSimulated: !0 }); w.event.trigger(r, null, t) } }), w.fn.extend({ trigger: function (e, t) { return this.each(function () { w.event.trigger(e, t, this) }) }, triggerHandler: function (e, t) { var n = this[0]; if (n) return w.event.trigger(e, t, n, !0) } }), h.focusin || w.each({ focus: "focusin", blur: "focusout" }, function (e, t) { var n = function (e) { w.event.simulate(t, e.target, w.event.fix(e)) }; w.event.special[t] = { setup: function () { var r = this.ownerDocument || this, i = J.access(r, t); i || r.addEventListener(e, n, !0), J.access(r, t, (i || 0) + 1) }, teardown: function () { var r = this.ownerDocument || this, i = J.access(r, t) - 1; i ? J.access(r, t, i) : (r.removeEventListener(e, n, !0), J.remove(r, t)) } } }); var Ct = e.location, Et = Date.now(), kt = /\?/; w.parseXML = function (t) { var n; if (!t || "string" != typeof t) return null; try { n = (new e.DOMParser).parseFromString(t, "text/xml") } catch (e) { n = void 0 } return n && !n.getElementsByTagName("parsererror").length || w.error("Invalid XML: " + t), n }; var St = /\[\]$/, Dt = /\r?\n/g, Nt = /^(?:submit|button|image|reset|file)$/i, At = /^(?:input|select|textarea|keygen)/i; function jt(e, t, n, r) { var i; if (Array.isArray(t)) w.each(t, function (t, i) { n || St.test(e) ? r(e, i) : jt(e + "[" + ("object" == typeof i && null != i ? t : "") + "]", i, n, r) }); else if (n || "object" !== x(t)) r(e, t); else for (i in t) jt(e + "[" + i + "]", t[i], n, r) } w.param = function (e, t) { var n, r = [], i = function (e, t) { var n = g(t) ? t() : t; r[r.length] = encodeURIComponent(e) + "=" + encodeURIComponent(null == n ? "" : n) }; if (Array.isArray(e) || e.jquery && !w.isPlainObject(e)) w.each(e, function () { i(this.name, this.value) }); else for (n in e) jt(n, e[n], t, i); return r.join("&") }, w.fn.extend({ serialize: function () { return w.param(this.serializeArray()) }, serializeArray: function () { return this.map(function () { var e = w.prop(this, "elements"); return e ? w.makeArray(e) : this }).filter(function () { var e = this.type; return this.name && !w(this).is(":disabled") && At.test(this.nodeName) && !Nt.test(e) && (this.checked || !pe.test(e)) }).map(function (e, t) { var n = w(this).val(); return null == n ? null : Array.isArray(n) ? w.map(n, function (e) { return { name: t.name, value: e.replace(Dt, "\r\n") } }) : { name: t.name, value: n.replace(Dt, "\r\n") } }).get() } }); var qt = /%20/g, Lt = /#.*$/, Ht = /([?&])_=[^&]*/, Ot = /^(.*?):[ \t]*([^\r\n]*)$/gm, Pt = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/, Mt = /^(?:GET|HEAD)$/, Rt = /^\/\//, It = {}, Wt = {}, $t = "*/".concat("*"), Bt = r.createElement("a"); Bt.href = Ct.href; function Ft(e) { return function (t, n) { "string" != typeof t && (n = t, t = "*"); var r, i = 0, o = t.toLowerCase().match(M) || []; if (g(n)) while (r = o[i++]) "+" === r[0] ? (r = r.slice(1) || "*", (e[r] = e[r] || []).unshift(n)) : (e[r] = e[r] || []).push(n) } } function _t(e, t, n, r) { var i = {}, o = e === Wt; function a(s) { var u; return i[s] = !0, w.each(e[s] || [], function (e, s) { var l = s(t, n, r); return "string" != typeof l || o || i[l] ? o ? !(u = l) : void 0 : (t.dataTypes.unshift(l), a(l), !1) }), u } return a(t.dataTypes[0]) || !i["*"] && a("*") } function zt(e, t) { var n, r, i = w.ajaxSettings.flatOptions || {}; for (n in t) void 0 !== t[n] && ((i[n] ? e : r || (r = {}))[n] = t[n]); return r && w.extend(!0, e, r), e } function Xt(e, t, n) { var r, i, o, a, s = e.contents, u = e.dataTypes; while ("*" === u[0]) u.shift(), void 0 === r && (r = e.mimeType || t.getResponseHeader("Content-Type")); if (r) for (i in s) if (s[i] && s[i].test(r)) { u.unshift(i); break } if (u[0] in n) o = u[0]; else { for (i in n) { if (!u[0] || e.converters[i + " " + u[0]]) { o = i; break } a || (a = i) } o = o || a } if (o) return o !== u[0] && u.unshift(o), n[o] } function Ut(e, t, n, r) { var i, o, a, s, u, l = {}, c = e.dataTypes.slice(); if (c[1]) for (a in e.converters) l[a.toLowerCase()] = e.converters[a]; o = c.shift(); while (o) if (e.responseFields[o] && (n[e.responseFields[o]] = t), !u && r && e.dataFilter && (t = e.dataFilter(t, e.dataType)), u = o, o = c.shift()) if ("*" === o) o = u; else if ("*" !== u && u !== o) { if (!(a = l[u + " " + o] || l["* " + o])) for (i in l) if ((s = i.split(" "))[1] === o && (a = l[u + " " + s[0]] || l["* " + s[0]])) { !0 === a ? a = l[i] : !0 !== l[i] && (o = s[0], c.unshift(s[1])); break } if (!0 !== a) if (a && e["throws"]) t = a(t); else try { t = a(t) } catch (e) { return { state: "parsererror", error: a ? e : "No conversion from " + u + " to " + o } } } return { state: "success", data: t } } w.extend({ active: 0, lastModified: {}, etag: {}, ajaxSettings: { url: Ct.href, type: "GET", isLocal: Pt.test(Ct.protocol), global: !0, processData: !0, async: !0, contentType: "application/x-www-form-urlencoded; charset=UTF-8", accepts: { "*": $t, text: "text/plain", html: "text/html", xml: "application/xml, text/xml", json: "application/json, text/javascript" }, contents: { xml: /\bxml\b/, html: /\bhtml/, json: /\bjson\b/ }, responseFields: { xml: "responseXML", text: "responseText", json: "responseJSON" }, converters: { "* text": String, "text html": !0, "text json": JSON.parse, "text xml": w.parseXML }, flatOptions: { url: !0, context: !0 } }, ajaxSetup: function (e, t) { return t ? zt(zt(e, w.ajaxSettings), t) : zt(w.ajaxSettings, e) }, ajaxPrefilter: Ft(It), ajaxTransport: Ft(Wt), ajax: function (t, n) { "object" == typeof t && (n = t, t = void 0), n = n || {}; var i, o, a, s, u, l, c, f, p, d, h = w.ajaxSetup({}, n), g = h.context || h, y = h.context && (g.nodeType || g.jquery) ? w(g) : w.event, v = w.Deferred(), m = w.Callbacks("once memory"), x = h.statusCode || {}, b = {}, T = {}, C = "canceled", E = { readyState: 0, getResponseHeader: function (e) { var t; if (c) { if (!s) { s = {}; while (t = Ot.exec(a)) s[t[1].toLowerCase()] = t[2] } t = s[e.toLowerCase()] } return null == t ? null : t }, getAllResponseHeaders: function () { return c ? a : null }, setRequestHeader: function (e, t) { return null == c && (e = T[e.toLowerCase()] = T[e.toLowerCase()] || e, b[e] = t), this }, overrideMimeType: function (e) { return null == c && (h.mimeType = e), this }, statusCode: function (e) { var t; if (e) if (c) E.always(e[E.status]); else for (t in e) x[t] = [x[t], e[t]]; return this }, abort: function (e) { var t = e || C; return i && i.abort(t), k(0, t), this } }; if (v.promise(E), h.url = ((t || h.url || Ct.href) + "").replace(Rt, Ct.protocol + "//"), h.type = n.method || n.type || h.method || h.type, h.dataTypes = (h.dataType || "*").toLowerCase().match(M) || [""], null == h.crossDomain) { l = r.createElement("a"); try { l.href = h.url, l.href = l.href, h.crossDomain = Bt.protocol + "//" + Bt.host != l.protocol + "//" + l.host } catch (e) { h.crossDomain = !0 } } if (h.data && h.processData && "string" != typeof h.data && (h.data = w.param(h.data, h.traditional)), _t(It, h, n, E), c) return E; (f = w.event && h.global) && 0 == w.active++ && w.event.trigger("ajaxStart"), h.type = h.type.toUpperCase(), h.hasContent = !Mt.test(h.type), o = h.url.replace(Lt, ""), h.hasContent ? h.data && h.processData && 0 === (h.contentType || "").indexOf("application/x-www-form-urlencoded") && (h.data = h.data.replace(qt, "+")) : (d = h.url.slice(o.length), h.data && (h.processData || "string" == typeof h.data) && (o += (kt.test(o) ? "&" : "?") + h.data, delete h.data), !1 === h.cache && (o = o.replace(Ht, "$1"), d = (kt.test(o) ? "&" : "?") + "_=" + Et++ + d), h.url = o + d), h.ifModified && (w.lastModified[o] && E.setRequestHeader("If-Modified-Since", w.lastModified[o]), w.etag[o] && E.setRequestHeader("If-None-Match", w.etag[o])), (h.data && h.hasContent && !1 !== h.contentType || n.contentType) && E.setRequestHeader("Content-Type", h.contentType), E.setRequestHeader("Accept", h.dataTypes[0] && h.accepts[h.dataTypes[0]] ? h.accepts[h.dataTypes[0]] + ("*" !== h.dataTypes[0] ? ", " + $t + "; q=0.01" : "") : h.accepts["*"]); for (p in h.headers) E.setRequestHeader(p, h.headers[p]); if (h.beforeSend && (!1 === h.beforeSend.call(g, E, h) || c)) return E.abort(); if (C = "abort", m.add(h.complete), E.done(h.success), E.fail(h.error), i = _t(Wt, h, n, E)) { if (E.readyState = 1, f && y.trigger("ajaxSend", [E, h]), c) return E; h.async && h.timeout > 0 && (u = e.setTimeout(function () { E.abort("timeout") }, h.timeout)); try { c = !1, i.send(b, k) } catch (e) { if (c) throw e; k(-1, e) } } else k(-1, "No Transport"); function k(t, n, r, s) { var l, p, d, b, T, C = n; c || (c = !0, u && e.clearTimeout(u), i = void 0, a = s || "", E.readyState = t > 0 ? 4 : 0, l = t >= 200 && t < 300 || 304 === t, r && (b = Xt(h, E, r)), b = Ut(h, b, E, l), l ? (h.ifModified && ((T = E.getResponseHeader("Last-Modified")) && (w.lastModified[o] = T), (T = E.getResponseHeader("etag")) && (w.etag[o] = T)), 204 === t || "HEAD" === h.type ? C = "nocontent" : 304 === t ? C = "notmodified" : (C = b.state, p = b.data, l = !(d = b.error))) : (d = C, !t && C || (C = "error", t < 0 && (t = 0))), E.status = t, E.statusText = (n || C) + "", l ? v.resolveWith(g, [p, C, E]) : v.rejectWith(g, [E, C, d]), E.statusCode(x), x = void 0, f && y.trigger(l ? "ajaxSuccess" : "ajaxError", [E, h, l ? p : d]), m.fireWith(g, [E, C]), f && (y.trigger("ajaxComplete", [E, h]), --w.active || w.event.trigger("ajaxStop"))) } return E }, getJSON: function (e, t, n) { return w.get(e, t, n, "json") }, getScript: function (e, t) { return w.get(e, void 0, t, "script") } }), w.each(["get", "post"], function (e, t) { w[t] = function (e, n, r, i) { return g(n) && (i = i || r, r = n, n = void 0), w.ajax(w.extend({ url: e, type: t, dataType: i, data: n, success: r }, w.isPlainObject(e) && e)) } }), w._evalUrl = function (e) { return w.ajax({ url: e, type: "GET", dataType: "script", cache: !0, async: !1, global: !1, "throws": !0 }) }, w.fn.extend({ wrapAll: function (e) { var t; return this[0] && (g(e) && (e = e.call(this[0])), t = w(e, this[0].ownerDocument).eq(0).clone(!0), this[0].parentNode && t.insertBefore(this[0]), t.map(function () { var e = this; while (e.firstElementChild) e = e.firstElementChild; return e }).append(this)), this }, wrapInner: function (e) { return g(e) ? this.each(function (t) { w(this).wrapInner(e.call(this, t)) }) : this.each(function () { var t = w(this), n = t.contents(); n.length ? n.wrapAll(e) : t.append(e) }) }, wrap: function (e) { var t = g(e); return this.each(function (n) { w(this).wrapAll(t ? e.call(this, n) : e) }) }, unwrap: function (e) { return this.parent(e).not("body").each(function () { w(this).replaceWith(this.childNodes) }), this } }), w.expr.pseudos.hidden = function (e) { return !w.expr.pseudos.visible(e) }, w.expr.pseudos.visible = function (e) { return !!(e.offsetWidth || e.offsetHeight || e.getClientRects().length) }, w.ajaxSettings.xhr = function () { try { return new e.XMLHttpRequest } catch (e) { } }; var Vt = { 0: 200, 1223: 204 }, Gt = w.ajaxSettings.xhr(); h.cors = !!Gt && "withCredentials" in Gt, h.ajax = Gt = !!Gt, w.ajaxTransport(function (t) { var n, r; if (h.cors || Gt && !t.crossDomain) return { send: function (i, o) { var a, s = t.xhr(); if (s.open(t.type, t.url, t.async, t.username, t.password), t.xhrFields) for (a in t.xhrFields) s[a] = t.xhrFields[a]; t.mimeType && s.overrideMimeType && s.overrideMimeType(t.mimeType), t.crossDomain || i["X-Requested-With"] || (i["X-Requested-With"] = "XMLHttpRequest"); for (a in i) s.setRequestHeader(a, i[a]); n = function (e) { return function () { n && (n = r = s.onload = s.onerror = s.onabort = s.ontimeout = s.onreadystatechange = null, "abort" === e ? s.abort() : "error" === e ? "number" != typeof s.status ? o(0, "error") : o(s.status, s.statusText) : o(Vt[s.status] || s.status, s.statusText, "text" !== (s.responseType || "text") || "string" != typeof s.responseText ? { binary: s.response } : { text: s.responseText }, s.getAllResponseHeaders())) } }, s.onload = n(), r = s.onerror = s.ontimeout = n("error"), void 0 !== s.onabort ? s.onabort = r : s.onreadystatechange = function () { 4 === s.readyState && e.setTimeout(function () { n && r() }) }, n = n("abort"); try { s.send(t.hasContent && t.data || null) } catch (e) { if (n) throw e } }, abort: function () { n && n() } } }), w.ajaxPrefilter(function (e) { e.crossDomain && (e.contents.script = !1) }), w.ajaxSetup({ accepts: { script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript" }, contents: { script: /\b(?:java|ecma)script\b/ }, converters: { "text script": function (e) { return w.globalEval(e), e } } }), w.ajaxPrefilter("script", function (e) { void 0 === e.cache && (e.cache = !1), e.crossDomain && (e.type = "GET") }), w.ajaxTransport("script", function (e) { if (e.crossDomain) { var t, n; return { send: function (i, o) { t = w("<script>").prop({ charset: e.scriptCharset, src: e.url }).on("load error", n = function (e) { t.remove(), n = null, e && o("error" === e.type ? 404 : 200, e.type) }), r.head.appendChild(t[0]) }, abort: function () { n && n() } } } }); var Yt = [], Qt = /(=)\?(?=&|$)|\?\?/; w.ajaxSetup({ jsonp: "callback", jsonpCallback: function () { var e = Yt.pop() || w.expando + "_" + Et++; return this[e] = !0, e } }), w.ajaxPrefilter("json jsonp", function (t, n, r) { var i, o, a, s = !1 !== t.jsonp && (Qt.test(t.url) ? "url" : "string" == typeof t.data && 0 === (t.contentType || "").indexOf("application/x-www-form-urlencoded") && Qt.test(t.data) && "data"); if (s || "jsonp" === t.dataTypes[0]) return i = t.jsonpCallback = g(t.jsonpCallback) ? t.jsonpCallback() : t.jsonpCallback, s ? t[s] = t[s].replace(Qt, "$1" + i) : !1 !== t.jsonp && (t.url += (kt.test(t.url) ? "&" : "?") + t.jsonp + "=" + i), t.converters["script json"] = function () { return a || w.error(i + " was not called"), a[0] }, t.dataTypes[0] = "json", o = e[i], e[i] = function () { a = arguments }, r.always(function () { void 0 === o ? w(e).removeProp(i) : e[i] = o, t[i] && (t.jsonpCallback = n.jsonpCallback, Yt.push(i)), a && g(o) && o(a[0]), a = o = void 0 }), "script" }), h.createHTMLDocument = function () { var e = r.implementation.createHTMLDocument("").body; return e.innerHTML = "<form></form><form></form>", 2 === e.childNodes.length }(), w.parseHTML = function (e, t, n) { if ("string" != typeof e) return []; "boolean" == typeof t && (n = t, t = !1); var i, o, a; return t || (h.createHTMLDocument ? ((i = (t = r.implementation.createHTMLDocument("")).createElement("base")).href = r.location.href, t.head.appendChild(i)) : t = r), o = A.exec(e), a = !n && [], o ? [t.createElement(o[1])] : (o = xe([e], t, a), a && a.length && w(a).remove(), w.merge([], o.childNodes)) }, w.fn.load = function (e, t, n) { var r, i, o, a = this, s = e.indexOf(" "); return s > -1 && (r = vt(e.slice(s)), e = e.slice(0, s)), g(t) ? (n = t, t = void 0) : t && "object" == typeof t && (i = "POST"), a.length > 0 && w.ajax({ url: e, type: i || "GET", dataType: "html", data: t }).done(function (e) { o = arguments, a.html(r ? w("<div>").append(w.parseHTML(e)).find(r) : e) }).always(n && function (e, t) { a.each(function () { n.apply(this, o || [e.responseText, t, e]) }) }), this }, w.each(["ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend"], function (e, t) { w.fn[t] = function (e) { return this.on(t, e) } }), w.expr.pseudos.animated = function (e) { return w.grep(w.timers, function (t) { return e === t.elem }).length }, w.offset = { setOffset: function (e, t, n) { var r, i, o, a, s, u, l, c = w.css(e, "position"), f = w(e), p = {}; "static" === c && (e.style.position = "relative"), s = f.offset(), o = w.css(e, "top"), u = w.css(e, "left"), (l = ("absolute" === c || "fixed" === c) && (o + u).indexOf("auto") > -1) ? (a = (r = f.position()).top, i = r.left) : (a = parseFloat(o) || 0, i = parseFloat(u) || 0), g(t) && (t = t.call(e, n, w.extend({}, s))), null != t.top && (p.top = t.top - s.top + a), null != t.left && (p.left = t.left - s.left + i), "using" in t ? t.using.call(e, p) : f.css(p) } }, w.fn.extend({ offset: function (e) { if (arguments.length) return void 0 === e ? this : this.each(function (t) { w.offset.setOffset(this, e, t) }); var t, n, r = this[0]; if (r) return r.getClientRects().length ? (t = r.getBoundingClientRect(), n = r.ownerDocument.defaultView, { top: t.top + n.pageYOffset, left: t.left + n.pageXOffset }) : { top: 0, left: 0 } }, position: function () { if (this[0]) { var e, t, n, r = this[0], i = { top: 0, left: 0 }; if ("fixed" === w.css(r, "position")) t = r.getBoundingClientRect(); else { t = this.offset(), n = r.ownerDocument, e = r.offsetParent || n.documentElement; while (e && (e === n.body || e === n.documentElement) && "static" === w.css(e, "position")) e = e.parentNode; e && e !== r && 1 === e.nodeType && ((i = w(e).offset()).top += w.css(e, "borderTopWidth", !0), i.left += w.css(e, "borderLeftWidth", !0)) } return { top: t.top - i.top - w.css(r, "marginTop", !0), left: t.left - i.left - w.css(r, "marginLeft", !0) } } }, offsetParent: function () { return this.map(function () { var e = this.offsetParent; while (e && "static" === w.css(e, "position")) e = e.offsetParent; return e || be }) } }), w.each({ scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function (e, t) { var n = "pageYOffset" === t; w.fn[e] = function (r) { return z(this, function (e, r, i) { var o; if (y(e) ? o = e : 9 === e.nodeType && (o = e.defaultView), void 0 === i) return o ? o[t] : e[r]; o ? o.scrollTo(n ? o.pageXOffset : i, n ? i : o.pageYOffset) : e[r] = i }, e, r, arguments.length) } }), w.each(["top", "left"], function (e, t) { w.cssHooks[t] = _e(h.pixelPosition, function (e, n) { if (n) return n = Fe(e, t), We.test(n) ? w(e).position()[t] + "px" : n }) }), w.each({ Height: "height", Width: "width" }, function (e, t) { w.each({ padding: "inner" + e, content: t, "": "outer" + e }, function (n, r) { w.fn[r] = function (i, o) { var a = arguments.length && (n || "boolean" != typeof i), s = n || (!0 === i || !0 === o ? "margin" : "border"); return z(this, function (t, n, i) { var o; return y(t) ? 0 === r.indexOf("outer") ? t["inner" + e] : t.document.documentElement["client" + e] : 9 === t.nodeType ? (o = t.documentElement, Math.max(t.body["scroll" + e], o["scroll" + e], t.body["offset" + e], o["offset" + e], o["client" + e])) : void 0 === i ? w.css(t, n, s) : w.style(t, n, i, s) }, t, a ? i : void 0, a) } }) }), w.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "), function (e, t) { w.fn[t] = function (e, n) { return arguments.length > 0 ? this.on(t, null, e, n) : this.trigger(t) } }), w.fn.extend({ hover: function (e, t) { return this.mouseenter(e).mouseleave(t || e) } }), w.fn.extend({ bind: function (e, t, n) { return this.on(e, null, t, n) }, unbind: function (e, t) { return this.off(e, null, t) }, delegate: function (e, t, n, r) { return this.on(t, e, n, r) }, undelegate: function (e, t, n) { return 1 === arguments.length ? this.off(e, "**") : this.off(t, e || "**", n) } }), w.proxy = function (e, t) { var n, r, i; if ("string" == typeof t && (n = e[t], t = e, e = n), g(e)) return r = o.call(arguments, 2), i = function () { return e.apply(t || this, r.concat(o.call(arguments))) }, i.guid = e.guid = e.guid || w.guid++ , i }, w.holdReady = function (e) { e ? w.readyWait++ : w.ready(!0) }, w.isArray = Array.isArray, w.parseJSON = JSON.parse, w.nodeName = N, w.isFunction = g, w.isWindow = y, w.camelCase = G, w.type = x, w.now = Date.now, w.isNumeric = function (e) { var t = w.type(e); return ("number" === t || "string" === t) && !isNaN(e - parseFloat(e)) }, "function" == typeof define && define.amd && define("jquery", [], function () { return w }); var Jt = e.jQuery, Kt = e.$; return w.noConflict = function (t) { return e.$ === w && (e.$ = Kt), t && e.jQuery === w && (e.jQuery = Jt), w }, t || (e.jQuery = e.$ = w), w });
/* jQuery end */

/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
*
 * v15.0.7081.30245
*/
window.MadCap={};MadCap.CreateNamespace=function(c){var d=c.split(".");var e=MadCap;for(var a=0,b=d.length;a<b;a++){var c=d[a];if(c=="MadCap"){continue}if(typeof(e[c])!="undefined"){e=e[c];continue}e[c]={};e=e[c]}return e};if(!Object.create){Object.create=function(b){if(arguments.length>1){throw new Error("Object.create implementation only accepts the first parameter.")}function a(){}a.prototype=b;return new a()}}if(typeof String.prototype.trim!=="function"){String.prototype.trim=function(){return this.replace(/^\s+|\s+$/g,"")}}if(!Array.prototype.indexOf){Array.prototype.indexOf=function(a){var c=this.length>>>0;var b=Number(arguments[1])||0;b=(b<0)?Math.ceil(b):Math.floor(b);if(b<0){b+=c}for(;b<c;b++){if(b in this&&this[b]===a){return b}}return -1}}MadCap.Extend=function(a,b){b.prototype=Object.create(a.prototype);b.prototype.constructor=b;b.prototype.base=a.prototype};MadCap.Exception=function(b,a){this.Number=b;this.Message=a};MadCap.IsIOS=function(){return MadCap.String.Contains(navigator.userAgent,"iphone")||MadCap.String.Contains(navigator.userAgent,"ipad")};MadCap.IsIBooks=function(){return MadCap.HasEpubReadingSystem()&&navigator.epubReadingSystem.name=="iBooks"};MadCap.HasEpubReadingSystem=function(){return"epubReadingSystem" in navigator};MadCap.IsSafari=function(){return MadCap.String.Contains(navigator.userAgent,"safari")&&!MadCap.String.Contains(navigator.userAgent,"chrome")};(function(){var a=MadCap.CreateNamespace("String");a.IsNullOrEmpty=function(b){if(b==null){return true}if(b.length==0){return true}return false};a.StartsWith=function(c,d,b){if(d==null){return false}if(c.length<d.length){return false}var e=c;var f=d;if(!b){e=e.toLowerCase();f=f.toLowerCase()}if(e.substring(0,f.length)==f){return true}else{return false}};a.EndsWith=function(c,d,b){if(d==null){return false}if(c.length<d.length){return false}var e=c;var f=d;if(!b){e=e.toLowerCase();f=f.toLowerCase()}if(e.substring(e.length-f.length)==f){return true}else{return false}};a.Contains=function(e,f,b){var g=b?e:e.toLowerCase();if($.isArray(f)){for(var c=0,d=f.length;c<d;c++){var h=b?f[c]:f[c].toLowerCase();if(g.indexOf(h)!=-1){return true}}return false}var h=b?f:f.toLowerCase();return g.indexOf(h)!=-1};a.Trim=function(b){return a.TrimRight(a.TrimLeft(b))};a.TrimLeft=function(d){var b=0;var c=d.length;for(b=0;b<c&&d.charAt(b)==" ";b++){}return d.substring(b,d.length)};a.TrimRight=function(c){var b=0;for(b=c.length-1;b>=0&&c.charAt(b)==" ";b--){}return c.substring(0,b+1)};a.ToBool=function(d,c){var b=c;if(d!=null){var e=d.toLowerCase();if(e!="true"&&e!="false"&&e!="1"&&e!="0"&&e!="yes"&&e!="no"){throw new MadCap.Exception(-1,"The string can not be converted to a boolean value.")}b=e=="true"||e=="1"||e=="yes"}return b};a.ToInt=function(d,b){var c=b;if(d!=null){c=parseInt(d)}return c};a.ToDashed=function(b){return b.replace(/([A-Z])/g,function(c){return"-"+c.toLowerCase()})};a.LocaleCompare=function(d,e,c){if(c){if(typeof Intl!=="undefined"&&typeof Intl.Collator!=="undefined"){var b=new Intl.Collator(c);if(b){return b.compare(d,e)}}if(String.prototype.localeCompare){return d.localeCompare(e,c)}}return d<e?-1:d>e?1:0};a.Compare=function(g,h){var e=g.length;var f=h.length;for(var d=0;d<e&&d<f;d++){var b=g.charCodeAt(d);var c=h.charCodeAt(d);if(b<c){return -1}else{if(b>c){return 1}}}if(e<f){return -1}else{if(e>f){return 1}else{return 0}}};a.IsPunctuation=function(d){var b=d.charCodeAt(0);return(b>=33&&b<=35)||(b>=37&&b<=42)||(b>=44&&b<=47)||(b==58||b==59)||(b==63||b==64)||(b>=91&&b<=93)||(b==95)||(b==123)||(b==125)||(b==161)||(b==171)||(b==173)||(b==183)||(b==187)||(b==191)||(b==894)||(b==903)||(b>=1370&&b<=1375)||(b==1417||b==1418)||(b==1470)||(b==1472)||(b==1475)||(b==1478)||(b==1523||b==1524)||(b==1548||b==1549)||(b==1563)||(b==1566||b==1567)||(b>=1642&&b<=1645)||(b==1748)||(b>=1792&&b<=1805)||(b>=2039&&b<=2041)||(b==2404||b==2405)||(b==2416)||(b==3572)||(b>=3663&&b<=3675)||(b>=3844&&b<=3858)||(b>=3898&&b<=3901)||(b==3973)||(b==4048||b==4049)||(b>=4170&&b<=4175)||(b==4347)||(b>=4961&&b<=4968)||(b==5741||b==5742)||(b==5787||b==5788)||(b>=5867&&b<=5869)||(b==5941||b==5942)||(b>=6100&&b<=6102)||(b>=6104&&b<=6106)||(b>=6144&&b<=6154)||(b==6468||b==6469)||(b==6622||b==6623)||(b==6686||b==6687)||(b>=7002&&b<=7008)||(b>=8208&&b<=8231)||(b>=8240&&b<=8259)||(b>=8261&&b<=8273)||(b>=8275&&b<=8286)||(b==8317||b==8318)||(b==8333||b==8334)||(b==9001||b==9002)||(b>=10088&&b<=10101)||(b>=10181&&b<=10182)||(b>=10214&&b<=10219)||(b>=10627&&b<=10648)||(b>=10712&&b<=10715)||(b==10748||b==10749)||(b>=11513&&b<=11516)||(b==11518||b==11519)||(b>=11776&&b<=11799)||(b==11804||b==11805)||(b>=12289&&b<=12291)||(b>=12296&&b<=12305)||(b>=12308&&b<=12319)||(b==12336)||(b==12349)||(b==12448)||(b==12539)||(b>=43124&&b<=43127)||(b==64830||b==64831)||(b>=65040&&b<=65049)||(b>=65072&&b<=65106)||(b>=65108&&b<=65121)||(b==65123)||(b==65128)||(b==65130||b==65131)||(b>=65281&&b<=65283)||(b>=65285&&b<=65290)||(b>=65292&&b<=65295)||(b==65306||b==65307)||(b==65311||b==65312)||(b>=65339&&b<=65341)||(b==65343)||(b==65371)||(b==65373)||(b>=65375&&b<=65381)};a.Split=function(h,g){var e=h.length;var f=[];var b=-1,c=-1;for(var d=0;d<=e;d++){if(d==e||g(h.charAt(d))){if(b>-1){f.push(h.slice(b,c));b=-1}}else{if(b==-1){b=d}c=d+1}}return f}})();(function(){MadCap.CreateNamespace("DEBUG");var a=MadCap.DEBUG;a.Log={};a.Log.Create=function(){var c=document.createElement("div");c.setAttribute("id","DEBUG_Log");var f=document.createElement("div");$(f).addClass("MCDebugLogHeader");f.appendChild(document.createTextNode("Log Console"));c.appendChild(f);var b=document.createElement("div");$(b).addClass("MCDebugLogBody");c.appendChild(b);var e=document.createElement("div");$(e).addClass("MCDebugLogFooter");c.appendChild(e);document.body.appendChild(c);var d=new MadCap.DragDrop(c,f)};a.Log._LoadTime=new Date();a.Log.AddLine=function(f){if(parent!=window){MadCap.Utilities.CrossFrame.PostMessageRequest(parent,"DEBUG-AddLine",[f],null);return}var e=document.getElementById("DEBUG_Log");if(e==null){return}var g=new Date();var h=g-a.Log._LoadTime;var c=document.createElement("p");$(c).addClass("MCDebugLogEntryTime");c.appendChild(document.createTextNode(h+"ms "+g.toLocaleTimeString()));var b=document.createElement("div");$(b).addClass("MCDebugLogEntry");b.appendChild(c);b.appendChild(document.createTextNode(f));var d=MadCap.Dom.GetElementsByClassName("MCDebugLogBody","div",e)[0];d.insertBefore(b,d.firstChild)}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v15.0.7081.30245
 */
(function(){MadCap.CreateNamespace("Dom");var a=MadCap.Dom;a.Dataset=function(b,c){return b.getAttribute("data-"+MadCap.String.ToDashed(c))};a.GetElementsByClassName=function(b,j,h){j=j||"*";h=h||document;var g=new Array();var d=h.getElementsByTagName(j);for(var e=0,f=d.length;e<f;e++){var c=d[e];if($(c).hasClass(b)){g[g.length]=c}}return g};a.GetElementsByAttribute=function(b,c,k,j){k=k||"*";j=j||document;var h=new Array();var e=j.getElementsByTagName(k);for(var f=0,g=e.length;f<g;f++){var d=e[f];var l=a.GetAttribute(d,b);if(l==c){h[h.length]=d}}return h};a.GetChildNodeByTagName=function(f,g,d){var c=null;var e=-1;for(var b=f.firstChild;b!=null;b=b.nextSibling){if(b.nodeName.toLowerCase()==g.toLowerCase()){e++;if(e==d){c=b;break}}}return c};a.GetAncestorNodeByTagName=function(d,f,e){e=e||document.body;var c=null;var b=d.parentNode;while(b!=null&&b!=e){if(b.nodeName.toLowerCase()==f.toLowerCase()){c=b;break}b=b.parentNode}return c};a.GetAttribute=function(c,b){var e=c.getAttribute(b);if(e==null){e=c.getAttribute(b.toLowerCase());if(e==null){var d=b.indexOf(":");if(d!=-1){e=c.getAttribute(b.substring(d+1,b.length))}}}return e};a.GetAttributeInt=function(e,b,c){var d=c;var f=a.GetAttribute(e,b);if(f!=null){d=parseInt(f)}return d};a.GetAttributeBool=function(e,b,d){var c=d;var f=a.GetAttribute(e,b);if(f!=null){c=MadCap.String.ToBool(f,d)}return c};a.GetScrollPosition=function(){var b=0;var c=0;if(typeof(window.pageYOffset)!="undefined"){b=window.pageXOffset;c=window.pageYOffset}else{if(typeof(document.documentElement.scrollTop)!="undefined"&&document.documentElement.scrollTop>0){b=document.documentElement.scrollLeft;c=document.documentElement.scrollTop}}return{X:b,Y:c}}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v15.0.7081.30245
 */
(function(){MadCap.CreateNamespace("Utilities");MadCap.Utilities.Dictionary=function(f){this._Map=new Object();this._Overflows=new Array();this._Length=0;this._IgnoreCase=f==true};var c=MadCap.Utilities.Dictionary;c.prototype.GetLength=function(f){return this._Length};c.prototype.ForEach=function(f){var l=this._Map;for(var j in l){var o=l[j];var n=f(j,o);if(n!=undefined&&!n){return}}var m=this._Overflows;for(var g=0,k=m.length;g<k;g++){var h=m[g];var n=f(h.Key,h.Value);if(n!=undefined&&!n){return}}};c.prototype.GetItem=function(h){if(this._IgnoreCase){h=h.toLowerCase()}var g=null;if(typeof(this._Map[h])=="function"){var f=this.GetItemOverflowIndex(h);if(f>=0){g=this._Overflows[f].Value}}else{g=this._Map[h];if(typeof(g)=="undefined"){g=null}}return g};c.prototype.GetItemOverflowIndex=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var j=this._Overflows;for(var f=0,h=j.length;f<h;f++){if(j[f].Key==g){return f}}return -1};c.prototype.Remove=function(g){if(this._IgnoreCase){g=g.toLowerCase()}if(typeof(this._Map[g])=="function"){var f=this.GetItemOverflowIndex(g);if(f>=0){this._Overflows.splice(f,1);this._Length--}}else{if(typeof(this._Map[g])!="undefined"){delete (this._Map[g]);this._Length--}}};c.prototype.Add=function(g,h){if(this._IgnoreCase){g=g.toLowerCase()}if(typeof(this._Map[g])=="function"){var f=this.GetItem(g);if(f!=null){this.Remove(g)}this._Overflows[this._Overflows.length]={Key:g,Value:h}}else{this._Map[g]=h}this._Length++};c.prototype.AddUnique=function(f,h){if(this._IgnoreCase){f=f.toLowerCase()}var g=this.GetItem(f);if(typeof(g)=="undefined"||!g){this.Add(f,h)}};MadCap.Utilities.DateTime=function(h){var g=/\/Date\(([0-9]+)\)\//i;var f=g.exec(h);if(f!=null){this.Date=new Date(parseInt(f[1]))}else{this.Date=new Date(h)}};var b=MadCap.Utilities.DateTime;b.Months=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];MadCap.Utilities.TimeSpan=function(f,g){if(typeof f=="undefined"){f=new Date()}if(typeof g=="undefined"){g=new Date()}if(f>g){this.FromDate=g;this.ToDate=f}else{this.FromDate=f;this.ToDate=g}this.Ticks=this.ToDate-this.FromDate;this.Seconds=this.Ticks/1000;this.Minutes=this.Seconds/60;this.Hours=this.Minutes/60;this.Days=this.Hours/24};var d=MadCap.Utilities.TimeSpan;d.prototype.ToDurationString=function(){if(this.Minutes<1){return"Just now"}if(this.Hours<1){return parseInt(this.Minutes)+" minutes ago"}if(this.Days<1){return parseInt(this.Hours)+" hours ago"}if(this.Days<30){return parseInt(this.Days)+" days ago"}var f=b.Months[this.FromDate.getMonth()]+" "+this.FromDate.getDate();if(this.FromDate.getFullYear()!=this.ToDate.getFullYear()){f+=", "+this.FromDate.getFullYear()}return f};MadCap.Utilities.Url=function(h){var g=this;var f=/^(?:([A-Za-z]+):)?(\/{0,3})([0-9.\-A-Za-z]+)(?::(\d+))?(?:\/([^?#]*))?(?:\?([^#]*))?(?:#(.*))?$/;this._Segments=[];this.FullPath=null;this.Path=null;this.PlainPath=null;this.Name=null;this.Extension=null;this.NameWithExtension=null;this.FullFragment=null;this.Fragment=null;this.Query=null;this.Origin=null;this.IsAbsolute=false;this.IsRootRelative=false;this.IsFolder=false;this.QueryMap=new MadCap.Utilities.Dictionary(true);this.HashMap=new MadCap.Utilities.Dictionary(true);(function(){var j="";var l="";var w="";var q="";var k=h.indexOf("#");var x=h.indexOf("?");if(k!=-1){l=h.substring(k);if(k>x){j=h.substring(k)}else{j=h.substring(k,x)}}if(x!=-1){if(x>k){w=h.substring(x)}else{w=h.substring(x,k)}}var v=k>-1?(x>-1?Math.min(k,x):k):x;var u=h.substring(0,v==-1?h.length:v);v=u.lastIndexOf("/");var t=u.substring(0,v+1);var p=u.substring(v+1);v=p.lastIndexOf(".");var o=p.substring(0,v);var i=p.substring(v+1);var y="";v=u.indexOf(":");if(v>=0){y=u.substring(0,v)}var n=!MadCap.String.IsNullOrEmpty(y);if(!MadCap.String.IsNullOrEmpty(h)){var A=h;if(MadCap.String.EndsWith(A,"/")){A=A.substring(0,A.length-1)}g._Segments=A.split("/");if(n){var s=h.match(f);if(s){if(s[4]){q=s[1]+":"+s[2]+s[3]+":"+s[4]}else{q=s[1]+":"+s[2]+s[3]}g.Origin=q}}}g.FullPath=h;g.Path=t;g.PlainPath=u;g.Name=o;g.Extension=i;g.NameWithExtension=p;g.Scheme=y;g.IsAbsolute=n;g.IsRootRelative=MadCap.String.StartsWith(u,"/",false);g.IsFolder=MadCap.String.EndsWith(u,"/");g.FullFragment=l;g.Fragment=j;g.Query=w;var z=g.Query;if(!MadCap.String.IsNullOrEmpty(z)){z=z.substring(1);z=z.replace(/\+/g," ");r(z,"&",g.QueryMap)}var m=g.Fragment;if(!MadCap.String.IsNullOrEmpty(m)){m=m.substring(1);r(m,"&",g.HashMap)}function r(E,B,H){var J=E.split(B);for(var C=0,G=J.length;C<G;C++){var I=J[C];var D=I.indexOf("=");var F=null;var K=null;if(D>=0){F=decodeURIComponent(I.substring(0,D));K=decodeURIComponent(I.substring(D+1))}else{F=I}H.Add(F,K)}}})()};var e=MadCap.Utilities.Url;e.GetDocumentUrl=function(){return new e(document.location.href)};e.GetAbsolutePath=function(g){var f=e.GetDocumentUrl();var h=new MadCap.Utilities.Url(f.PlainPath);if(!h.IsFolder){h=h.ToFolder()}return h.CombinePath(g).FullPath};e.StripInvalidCharacters=function(f){return f.replace(/(javascript:|data:|[<>])/gi,"")};e.SanitizeHash=function(){var f=MadCap.Utilities.Url.CurrentHash();if(f){var g=decodeURIComponent(f.slice(1));var h=MadCap.Utilities.Url.StripInvalidCharacters(g);if(g!=h){document.location.hash=encodeURI(h)}}};e.ReplaceReservedCharacters=function(k,h){var j=/[ ()&;,!'$]/;var f=k.split("");for(var g=0;g<f.length;g++){if(f[g].charCodeAt(0)>127||f[g].match(j)){f[g]=h}}return f.join("")};e.Navigate=function(f){document.location=e.StripInvalidCharacters(f)};e.GenerateNavigateTopicPath=function(h){var f=h.IsRootRelative?h.PlainPath:e.GetAbsolutePath(h.PlainPath);var g=e.GetDocumentUrl().QueryMap.GetItem("skinName")||h.QueryMap.GetItem("skinName");if(g!=null){f+=("?skinName="+g)}if(h.FullFragment.indexOf("#search-")==0){f+=h.FullFragment}else{if(h.QueryMap.GetLength()>0){f+=(g==null)?"?":"&";h.QueryMap.ForEach(function(i,k){var j=["skinName","highlight"];if(k&&j.indexOf(i)==-1){f+=(i+"="+encodeURIComponent(k)+"&")}});f=f.slice(0,-1)}f+=h.Fragment}return f};e.NavigateTopic=function(g){var f=e.GenerateNavigateTopicPath(g);e.Navigate(f)};e.OnNavigateTopic=function(f){var g=$(this).attr("href");if(typeof g!="undefined"){var j=new e(g);if(!MadCap.String.IsNullOrEmpty(g)&&!j.IsAbsolute&&j.PlainPath){var h=e.GenerateNavigateTopicPath(j);var i=new MadCap.Utilities.Url(h);var g=new MadCap.Utilities.Url(document.location.href);if(decodeURI(i.PlainPath)==decodeURI(g.PlainPath)&&j.HashMap.GetLength()>0){e.NavigateHash(j.Fragment);$(window).trigger("hashchange");f.preventDefault()}else{if(h!=e.GetAbsolutePath(j.PlainPath)){MadCap.Utilities.PreventDefault(f);e.Navigate(h)}}}else{if(j.HashMap.GetLength()>0&&j.Fragment!="#"){e.NavigateHash(j.Fragment);$(window).trigger("hashchange");f.preventDefault()}}}};e.NavigateHash=function(f){document.location.hash=e.StripInvalidCharacters(f)};e.CurrentHash=function(){return new MadCap.Utilities.Url(document.location.href).FullFragment};e.prototype.AddFile=function(i){if(typeof(i)=="string"){i=new e(i)}if(i.IsAbsolute){return i}var h=i.FullPath;if(h.charAt(0)=="/"){var g=document.location;var j=g.href.lastIndexOf(g.pathname);var k=g.href.substring(0,j);return new e(k+h)}var f=this.FullPath;if(!MadCap.String.EndsWith(f,"/")){f=f+"/"}return new e(f+h)};e.prototype.CombinePath=function(k){if(typeof(k)=="string"){k=new e(k)}if(k.IsAbsolute){throw new MadCap.Exception(-1,"Cannot combine two absolute paths.")}var j=k.FullPath;var o=k.FullPath.split("/");var f=this.FullPath;var m="";if(this.Origin&&k.IsRootRelative){return new e(this.Origin+j)}if(this.Scheme=="mk"){var l=f.indexOf("::");m=f.substring(0,l+"::".length);f=f.substring(l+"::".length)}for(var g=0,h=o.length;g<h;g++){var n=o[g];if(f.length>1&&MadCap.String.EndsWith(f,"/")){f=f.substring(0,f.length-1)}if(n=="."){f+="/"}else{if(n==".."){f=f.substring(0,f.lastIndexOf("/")+1)}else{if(f!=""&&!MadCap.String.EndsWith(f,"/")){f+="/"}f+=n}}}f=m+f;return new e(f)};e.prototype.ToQuery=function(g){var f=this.PlainPath+"?"+g+this.Fragment;return new e(f)};e.prototype.ToFolder=function(){var f=this.PlainPath;if(MadCap.String.EndsWith(f,"/")){f=f.substring(0,f.length-1)}var h=f.lastIndexOf("/");var g=f.substring(0,h+1);return new e(g)};e.prototype.ToRelative=function(l){if(typeof(l)=="string"){l=new e(l)}if(this.IsAbsolute!=l.IsAbsolute){return this}var f=0;var h=l._Segments.length;for(;f<h;f++){var n=this._Segments[f];var o=l._Segments[f];if(n!=o){break}}var m="";var k=MadCap.String.EndsWith(l.FullPath,"/")?0:1;for(var g=0;g<h-f-k;g++){m+="../"}for(var g=f;g<this._Segments.length;g++){if(g>f){m+="/"}m+=this._Segments[g]}return new e(m)};e.prototype.ToExtension=function(g){var i=this.FullPath;var j=i.lastIndexOf(".");var f=i.substring(0,j);var h=f+"."+g;return new e(h)};e.prototype.ToScheme=function(g){var h=this.FullPath;pos=h.indexOf(":");if(pos<0){return this}var f=g+":"+h.substring(pos);return new e(f)};e.prototype.ToPath=function(){return new e(this.Path)};e.prototype.ToPlainPath=function(){return new e(this.PlainPath)};e.prototype.ToNoQuery=function(){return new e(this.PlainPath+this.Fragment)};e.prototype.ToNoFragment=function(){return new e(this.PlainPath+this.Query)};MadCap.Utilities.CrossFrame={};var a=MadCap.Utilities.CrossFrame;a.MESSAGE_SEPARATOR="%%%%%";a.DATA_SEPARATOR="^^^^^";a._MessageID=0;a._MessageInfos=new Array();a._MessageHandlerFuncs=new Array();a._SafeList=[];a._PostMessage=function(h,g){if(typeof h=="undefined"||h==null){return}if(h.postMessage!=null){h.postMessage(g,"*");return}var f={data:g,source:window};h.MadCap.Utilities.CrossFrame.OnMessage(f)};a.AddMessageHandler=function(g,f){var h=a._MessageHandlerFuncs.length;a._MessageHandlerFuncs[h]={HandlerFunc:g,ContextObj:f}};a.AddVerifiedOrigin=function(f){a._SafeList.push(f)};a.PostMessageRequest=function(n,m,g,f){a._MessageInfos[a._MessageID]=f;var h="";if(g!=null){for(var k=0,l=g.length;k<l;k++){if(k>0){h+=a.DATA_SEPARATOR}h+=g[k]}}var j="request"+a.MESSAGE_SEPARATOR+m+a.MESSAGE_SEPARATOR+h+a.MESSAGE_SEPARATOR+a._MessageID;a._PostMessage(n,j);a._MessageID++};a._PostMessageResponse=function(n,l,f,m){var g="";if(f!=null){for(var j=0,k=f.length;j<k;j++){if(j>0){g+=a.DATA_SEPARATOR}g+=f[j]}}var h="response"+a.MESSAGE_SEPARATOR+l+a.MESSAGE_SEPARATOR+g+a.MESSAGE_SEPARATOR+m;a._PostMessage(n,h);a._MessageID++};a.OnMessage=function(j){var h=j.originalEvent;if(!a.CheckMessageOrigin(h)){console.warn("Refusing to handle cross-origin message: %s",h.data);return}var v=h.data.split(a.MESSAGE_SEPARATOR);var u=v[0];var r=v[1];var s=v[2];var t=parseInt(v[3]);var g=null;if(!MadCap.String.IsNullOrEmpty(s)){g=s.split(a.DATA_SEPARATOR);for(var p=0,q=g.length;p<q;p++){if(g[p]=="null"){g[p]=null}}}if(u=="request"){var l=false;var k=true;var x=new Array();for(var p=0,q=a._MessageHandlerFuncs.length;p<q;p++){var m=a._MessageHandlerFuncs[p];var n=m.HandlerFunc;var f=m.ContextObj;var o=null;if(f!=null){o=n.call(f,r,g,x,h.source,t)}else{o=n(r,g,x,h.source,t)}l=o.Handled;k=o.FireResponse;if(l){break}}if(!l){if(r=="DEBUG-AddLine"){var r=g[0];MadCap.DEBUG.Log.AddLine(r);l=true}else{if(r=="url"){x[x.length]=document.location.href;l=true}else{if(r=="get-title"){x[x.length]=document.title;l=true}else{if(r=="navigate"){var w=g[0];document.location.href=w;l=true}}}}}if(k){a._PostMessageResponse(h.source,r,x.length>0?x:null,t)}}else{if(u=="response"){if(a._MessageInfos[t]!=null){a._MessageInfos[t](g)}}}};if(window.postMessage!="undefined"){$(window).on("message",a.OnMessage)}else{}a.CheckMessageOrigin=function(f){return(f.origin===window.origin)||(f.origin===location.origin)||(f.origin==="file:"&&(f.origin===location.origin.replace(/\//g,"")))||a._SafeList.indexOf(f.origin)>-1};MadCap.Utilities.PreventDefault=function(f){f.preventDefault?f.preventDefault():event.returnValue=false};MadCap.Utilities.EncodeHtml=function(f){var g=document.createElement("textarea");g.textContent=f;return g.innerHTML};MadCap.Utilities.DecodeHtml=function(f){var g=document.createElement("textarea");g.innerHTML=f;return g.textContent};MadCap.Utilities.AsyncForeach=function(f,h,g){f=f.slice(0);function i(){var j=f.shift();h(j,function(k){if(f.length>0){i()}else{g()}})}if(f.length>0){i()}else{g()}};MadCap.Utilities.Now=Date.now||function(){return new Date().getTime()};MadCap.Utilities.Has=function(g,f){return g!=null&&Object.prototype.hasOwnProperty.call(g,f)};MadCap.Utilities.CreateEvent=function(g,h){var f;if(typeof(CustomEvent)==="function"){f=new CustomEvent(g,h)}else{f=document.createEvent("Event");f.initEvent(g,true,true);for(var i in h){f[i]=h[i]}}return f};MadCap.Utilities.Debounce=function(h,n,i){var l,f,g,m,k;var j=function(){var o=MadCap.Utilities.Now()-m;if(o<n&&o>0){l=setTimeout(j,n-o)}else{l=null;if(!i){k=h.apply(g,f);if(!l){g=f=null}}}};return function(){g=this;f=arguments;m=MadCap.Utilities.Now();var o=i&&!l;if(!l){l=setTimeout(j,n)}if(o){k=h.apply(g,f);g=f=null}return k}};MadCap.Utilities.Memoize=function(f,g){var h=function(k){var j=h.cache;var i=""+(g?g.apply(this,arguments):k);if(!MadCap.Utilities.Has(j,i)){j[i]=f.apply(this,arguments)}return j[i]};h.cache={};return h};MadCap.Utilities.Get=function(i,j,f){var k=undefined;if(i!=null){j=j.split(".");var g=0,h=j.length;while(i!=null&&g<h){i=i[j[g++]]}k=(g&&g==h)?i:undefined}return k===undefined?f:k};MadCap.Utilities.IsRuntimeFileType=function(f){return MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")==f};MadCap.Utilities.HasRuntimeFileType=function(g){var f=MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType");return f&&f.split(";").indexOf(g)>-1};MadCap.Utilities.CreateStylesheet=function(g,h){var f=g||document,j;var i=f.createElement("style");if(h){i.setAttribute("media",h)}f.getElementsByTagName("head")[0].appendChild(i);j=f.styleSheets[f.styleSheets.length-1];return j};MadCap.Utilities.AsyncForeachParallel=function(f,j,g){var h=0;if(f.length===0){g()}var l=f.length;for(var k=0;k<l;k++){j(f[k],function(){h++;if(h===f.length){g()}})}};MadCap.Utilities.FixLink=function(g,k,j,f){var i=g;var h=new MadCap.Utilities.Url(g);if(!h.IsAbsolute&&h.Fragment!=h.FullPath){h=k.CombinePath(h);i=h.FullPath;if(!MadCap.String.IsNullOrEmpty(j)&&j!=null&&f){h=h.ToRelative(f);i=j+h.FullPath}}return i};MadCap.Utilities.FixLinks=function(j,l,i,g){var k=["href","src","cite","data","data-mc-topics","poster"];var h=["href","data-mc-topics"];var m="["+k.join("],[")+"]";var f=$(j);f.find(m).each(function(){var n=$(this).hasClass("MCPopupThumbnailPopup")||$(this).hasClass("MCPopupThumbnailHover")||$(this).hasClass("MCTopicPopup");var p=!n;var o=false;$.each(this.attributes,function(s,q){var u=p&&h.indexOf(q.name)>-1?i:"";if(q.name==="data-mc-topics"){var x=q.value;var w=x?x.split("||"):null;if(w){for(var t=0;t<w.length;t++){var v=w[t].split("|");v[1]=MadCap.Utilities.FixLink(v[1],l,u,g);w[t]=v.join("|")}q.value=w.join("||")}}else{if(k.indexOf(q.name)>-1){var r=MadCap.Utilities.FixLink(q.value,l,u,g);if(r!==q.value){q.value=r;o=true}}}});if(o){$(this).attr("data-mc-processed-link",true)}});return f};MadCap.Utilities.IsRTL=function(){return $("html").css("direction")==="rtl"};MadCap.Utilities.IsTouchDevice=function(){var f=false;(function(g){if(/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino|android|ipad|playbook|silk/i.test(g)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(g.substr(0,4))){f=true}})(navigator.userAgent||navigator.vendor||window.opera);return f};MadCap.Utilities.ToggleButtonState=function(g){var f=$(g);var h=f.attr("data-current-state")||"1";var i=h=="1"?2:1;MadCap.Utilities.SetButtonState(g,i)};MadCap.Utilities.SetButtonState=function(g,l){var f=$(g);var h=l==1?2:1;var m=f.attr("data-state"+l+"-class");var i=f.attr("data-state"+h+"-class");f.attr("data-current-state",l);f.removeClass(i).addClass(m);f.attr("title",f.attr("data-state"+l+"-title"));if(MadCap.Utilities.HasRuntimeFileType("SkinPreview")){var k=f.attr("data-mc-style2");if(k){var j=f.attr("data-mc-style1");if(!j){j=f.attr("data-mc-style");f.attr("data-mc-style1",MadCap.Utilities.EncodeHtml(j))}f.attr("data-mc-style",l==1?j:k)}}};MadCap.Utilities.LoadHandlers=Object.create(null);MadCap.Utilities.InitContent=function(f){for(var g in MadCap.Utilities.LoadHandlers){MadCap.Utilities.LoadHandlers[g](f)}};MadCap.Utilities.LoadScript=function(h,g,f){var i=document.createElement("script");i.src=h;i.type="text/javascript";if(i.addEventListener){$(i).on("error",f);$(i).on("load",g)}else{if(i.readyState){i.onreadystatechange=function(){if(i.readyState=="loaded"||i.readyState=="complete"){g()}}}}document.getElementsByTagName("head")[0].appendChild(i);return i};MadCap.Utilities.LoadRegisteredScript=function(l,k,j,f){var g=false;var m;$("script").each(function(n,o){var p=$(o).attr("src");if(!MadCap.String.IsNullOrEmpty(p)&&p.toLowerCase()==l.toLowerCase()){g=true;m=o}});if(g){var i=new MadCap.Utilities.Url(l).Name;var h=MadCap.Utilities.LoadHandlers[i];if(h){h(f)}k()}};MadCap.Utilities.LoadScripts=function(i,h,g,f){MadCap.Utilities.AsyncForeach(i,function(k,j){if(!MadCap.String.IsNullOrEmpty(k)){MadCap.Utilities.LoadRegisteredScript(k,j,g,f)}else{j()}},h)};MadCap.Utilities.DynamicStylesheets=Object.create(null);MadCap.Utilities.LoadStylesheets=function(g,f){$.each(g,function(i,h){if(!MadCap.String.IsNullOrEmpty(h)){MadCap.Utilities.LoadStylesheet(h,f)}})};MadCap.Utilities.LoadStylesheet=function(h,i){var f=false;$("link").each(function(l,m){var n=$(m).attr("href");if(!MadCap.String.IsNullOrEmpty(n)&&n.toLowerCase()===h.toLowerCase()){f=true}});if(!f){var j='<link rel="stylesheet" type="text/css" href="{0}" data-mc-dynamic="true" />';j=j.replace("{0}",h);var g=$("head")[0];var k=i?$(j).insertAfter(i):$(j).appendTo(g);MadCap.Utilities.DynamicStylesheets[h]=k}};MadCap.Utilities.UpdateDynamicStylesheets=function(f){MadCap.Utilities.RemoveDynamicStylesheets();for(var g=0;g<f.length;g++){MadCap.Utilities.LoadStylesheet(f[g])}};MadCap.Utilities.RemoveDynamicStylesheets=function(){$.each(MadCap.Utilities.DynamicStylesheets,function(f,g){$(g).remove()});MadCap.Utilities.DynamicStylesheets=Object.create(null)};MadCap.Utilities.CombineRelevancy=function(h,j){var f=MadCap.Utilities.CapNumber(h,j,16,0,2);for(var g=2;g<7;g++){f=MadCap.Utilities.CapNumber(f,j,16,g,1)}f=MadCap.Utilities.CapNumber(f,j,16,7,1,7);return f};MadCap.Utilities.CalculateScore=function(h,f,g){return(Math.log(h)/Math.log(2147483647)*g)+(f*(1-g))};MadCap.Utilities.CapNumber=function(l,m,f,n,h,i){if(!i){i=Math.pow(f,h)-1}var g=Math.pow(f,n);var k=g*Math.pow(f,h);var o=~~(l%k/g);var p=~~(m%k/g);var j=Math.min(o+p,i);return l+((j-o)*g)};MadCap.Utilities.Require=function(i,j){if(!MadCap.Utilities._requireCache){MadCap.Utilities._requireCache=Object.create(null)}var f=MadCap.Utilities._requireCache;var h=i[0];var g=f[h];if(g&&g.data){j(g.data)}else{if(g&&g.callbacks){g.callbacks.push(j)}else{f[h]={callbacks:[j]};require([h],function(k){g=f[h];g.data=k;for(var l=0;l<g.callbacks.length;l++){g.callbacks[l](k)}g.callbacks=null;require.undef(h)})}}};MadCap.Utilities.GetChunkId=function(f,k,h){for(var j=0;j<f.length;j++){var l=f[j];var g=h(k,l);if(g===0){return j}else{if(g===-1){return j-1}}}return f.length-1};MadCap.Utilities.GetChunkIds=function(g,m,j){var f=[];var k=false;for(var l=0;l<g.length;l++){var n=g[l];var h=j(m,n);if(h===-1&&l===0){return f}if(h===0){if(l>0&&!k){f.push(l-1)}f.push(l);k=true}else{if(h===-1){if(l>0&&!k){f.push(l-1)}break}}}if(f.length===0){f.push(g.length-1)}return f};MadCap.Utilities.ClearRequireCache=function(){MadCap.Utilities._requireCache=null};MadCap.Utilities.StopWords=Array("a","an","the","to","of","is","for","and","or","do","be","by","he","she","on","in","at","it","not","no","are","as","but","her","his","its","non","only","than","that","then","they","this","we","were","which","with","you","into","about","after","all","also","been","can","come","from","had","has","have","me","made","many","may","more","most","near","over","some","such","their","there","these","under","use","was","when","where","against","among","became","because","between","during","each","early","found","however","include","late","later","med","other","several","through","until","who","your");MadCap.Utilities.Store=(function(){try{if(window.localStorage){return window.localStorage}}catch(g){if(console&&console.log){console.log("window.localStorage not available")}}var i="MadCap";var f=document.createElement("div");f.style.display="none";document.getElementsByTagName("head")[0].appendChild(f);if(typeof f.addBehavior=="function"){f.addBehavior("#default#userdata");f.load(i);return{getItem:function(j){return f.XMLDocument.documentElement.getAttribute(j)},setItem:function(j,k){f.XMLDocument.documentElement.setAttribute(j,k);f.save(i)},removeItem:function(j){f.removeAttribute(j);f.save(i)}}}var h="data-"+i+"-";return{getItem:function(j){var k=f.getAttribute(h+j);return k?decodeURIComponent(k):k},setItem:function(j,k){f.setAttribute(h+j,k?encodeURIComponent(k):null)},removeItem:function(j){f.removeAttribute(h+j)}}})();MadCap.Utilities.SanitizeHtml=function(f){return sanitizeHtml(f,{allowedTags:["a","abbr","address","area","article","aside","audio","b","bdi","bdo","blockquote","br","button","canvas","caption","cite","code","col","colgroup","data","datalist","dd","del","details","dfn","div","dl","dt","em","embed","fieldset","figcaption","figure","footer","h1","h2","h3","h4","h5","h6","header","hr","i","iframe","img","input","ins","kbd","label","legend","li","map","mark","meter","nav","object","ol","optgroup","option","output","p","param","picture","pre","progress","q","rp","rt","ruby","s","samp","section","select","small","source","span","strike","strong","sub","summary","sup","svg","table","tbody","td","template","tfoot","th","thead","time","tr","track","u","ul","var","video","wbr"],allowedAttributes:{"*":["accesskey","class","data-*","dir","hidden","id","lang","style","tabindex","title","translate"],a:["href","hreflang","name","rel","target"],area:["alt","coords","href","hreflang","media","rel","shape","target","type"],audio:["autoplay","controls","loop","muted","preload","src"],blockquote:["cite"],button:["disabled","name","type","value"],canvas:["height","width"],col:["span"],colgroup:["span"],data:["value"],del:["cite","datetime"],details:["open"],embed:["height","src","type","width","pluginspage","wmode"],fieldset:["disabled","form","name"],iframe:["frameborder","height","name","sandbox","src","width"],img:["alt","height","ismap","longdesc","sizes","src","srcset","usemap","width"],input:["alt","autocomplete","checked","dirname","disabled","form","height","list","max","maxlength","min","multiple","name","pattern","placeholder","readonly","required","size","src","step","type","value","width"],ins:["cite","datetime"],label:["for","form"],li:["value"],map:["name"],meter:["form","high","low","max","min","optimum","value"],object:["classid","codebase","data","form","height","name","type","usemap","width"],ol:["reversed","start","type"],optgroup:["disabled","label"],option:["disabled","label","selected","value"],output:["for","form","name"],param:["name","value"],progress:["max","value"],q:["cite"],select:["disabled","form","multiple","name","required","size"],source:["src","srcset","media","sizes","type"],table:["border","cellpadding","cellspacing","frame","rules","summary","width"],td:["abbr","colspan","headers","rowspan"],th:["abbr","colspan","headers","rowspan","scope","sorted"],time:["datetime"],track:["default","kind","label","src","srclang"],ul:["type"],video:["autoplay","controls","height","loop","muted","poster","preload","src","width"]},selfClosing:["img","br","hr","area","input"],allowedSchemes:["http","https","ftp","mailto","file"],allowedSchemesByTag:{},allowedSchemesAppliedToAttributes:["href","src","cite","data","poster"],allowProtocolRelative:true,allowedIframeHostnames:false})}})();Array.prototype.Remove=function(a){if(a<0||a>this.length){throw"Index out of bounds."}this.splice(a,1)};Array.prototype.RemoveValue=function(b){for(var a=this.length-1;a>=0;a--){if(this[a]==b){this.Remove(a)}}};Array.prototype.Union=function(c){var a=[].concat(this);if(c){for(var b=0;b<c.length;b++){if(this.indexOf(c[b])===-1){a.push(c[b])}}}return a};Array.prototype.Intersect=function(c){var a=[];for(var b=0;b<c.length;b++){if(this.indexOf(c[b])!==-1){a.push(c[b])}}return a};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v15.0.7081.30245
 */
(function(){MadCap.Utilities.Xhr=function(b,d,c){var e=this;this._XmlDoc=null;this._XmlHttp=null;this._Args=b;this._LoadFunc=d;this._LoadContextObj=c;this.OnreadystatechangeLocal=function(){if(e._XmlDoc.readyState==4){e._XmlDoc.onreadystatechange=a._Noop;var f=null;if(e._XmlDoc.documentElement!=null){f=e._XmlDoc}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}};this.OnreadystatechangeRemote=function(){if(e._XmlHttp.readyState==4){e._XmlHttp.onreadystatechange=a._Noop;var f=null;if(e._XmlHttp.responseXML!=null&&e._XmlHttp.responseXML.documentElement!=null){f=e._XmlHttp.responseXML}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}}};var a=MadCap.Utilities.Xhr;a.prototype._LoadLocal=function(d,b){if(window.ActiveXObject){this._XmlDoc=a._GetMicrosoftXmlDomObject();this._XmlDoc.async=b;if(this._LoadFunc){this._XmlDoc.onreadystatechange=this.OnreadystatechangeLocal}try{if(!this._XmlDoc.load(d)){this._XmlDoc=null}}catch(c){this._XmlDoc=null}}else{if(window.XMLHttpRequest){this._LoadRemote(d,b)}}return this._XmlDoc};a.prototype._LoadRemote=function(d,b){this._XmlHttp=a._GetXhrObject();if(this._LoadFunc){this._XmlHttp.onreadystatechange=this.OnreadystatechangeRemote}try{this._XmlHttp.open("GET",d,b);this._XmlHttp.send(null);if(!b&&(this._XmlHttp.status==0||this._XmlHttp.status==200)){this._XmlDoc=this._XmlHttp.responseXML}}catch(c){this._XmlHttp.abort();if(this._LoadFunc){if(this._LoadContextObj==null){this._LoadFunc(null,this._Args)}else{this._LoadFunc.call(this._LoadContextObj,null,this._Args)}}}return this._XmlDoc};a.prototype.Load=function(e,b){var d=null;var c=document.location.protocol;if(c=="file:"||c=="mk:"||c=="ms-its:"||c=="app:"){d=this._LoadLocal(e,b)}else{if(c=="http:"||c=="https:"){d=this._LoadRemote(e,b)}}return d};a.LoadXmlString=function(d){var c=null;if(window.ActiveXObject){c=a._GetMicrosoftXmlDomObject();c.async=false;c.loadXML(d)}else{if(DOMParser){var b=new DOMParser();c=b.parseFromString(d,"text/xml")}}return c};a.CreateXmlDocument=function(b){var c="<"+b+" />";var d=a.LoadXmlString(c);return d};a.GetOuterXml=function(d){var c=null;if(window.ActiveXObject){c=d.xml}else{if(window.XMLSerializer){var b=new XMLSerializer();c=b.serializeToString(d)}}return c};a.ImportNode=function(b,c){if(typeof(b.importNode)=="function"){return b.importNode(c,true)}return c.cloneNode(true)};a.CallWebService=function(e,b,d,c){var g=new a(c,d,null);var f=g.Load(e,b);return f};a._MicrosoftXmlDomProgIDs=["Msxml2.DOMDocument.6.0","Msxml2.DOMDocument","Microsoft.XMLDOM"];a._MicrosoftXmlHttpProgIDs=["Msxml2.XMLHTTP.6.0","Msxml2.XMLHTTP","Microsoft.XMLHTTP"];a._MicrosoftXmlDomProgID=null;a._MicrosoftXmlHttpProgID=null;a._FilePathToXmlStringMap=new MadCap.Utilities.Dictionary();a._LoadingFilesPathMap=new MadCap.Utilities.Dictionary();a._LoadingFromQueue=false;a.ForceUseJS=false;a.Load=function(m,c,g,b,f){function i(){a._LoadingFilesPathMap.Remove(e.FullPath);var n=a._FilePathToXmlStringMap.GetItem(e.Name);if(n!=null){a._FilePathToXmlStringMap.Remove(e.Name);j=a.LoadXmlString(n)}a._LoadingFilesPathMap.ForEach(function(o,r){var q=new MadCap.Utilities.Url(o);var p=r;if(q.Name==d&&q.FullPath!=e.FullPath){a._LoadingFilesPathMap.Remove(q.FullPath);a._LoadingFromQueue=true;a.Load(q.FullPath,p.async,p.LoadFunc,p.args,p.loadContextObj);return false}return true});if(f==null){g(j,b)}else{g.call(f,j,b)}}var j=null;if(a.ForceUseJS||(Boolean(!window.ActiveXObject)&&MadCap.String.StartsWith(document.location.protocol,"file"))){var k=new MadCap.Utilities.Url(m);var e=k.ToExtension("js");var d=e.Name;a._LoadingFilesPathMap.Add(e.FullPath,{async:c,LoadFunc:g,args:b,loadContextObj:f});var h=false;a._LoadingFilesPathMap.ForEach(function(n,q){var p=new MadCap.Utilities.Url(n);var o=q;if(p.Name==d&&p.FullPath!=e.FullPath){h=true;return false}return true});if(a._LoadingFromQueue||!h){a._LoadingFromQueue=false;MadCap.Utilities.LoadScript(e.FullPath,i,i)}}else{var l=new a(b,g,f);j=l.Load(m,c)}return j};a._Noop=function(){};a._GetMicrosoftXmlDomObject=function(){var d=null;if(a._MicrosoftXmlDomProgID==null){for(var c=0;c<a._MicrosoftXmlDomProgIDs.length;c++){var e=a._MicrosoftXmlDomProgIDs[c];try{d=new ActiveXObject(e);a._MicrosoftXmlDomProgID=e;break}catch(b){}}}else{d=new ActiveXObject(a._MicrosoftXmlDomProgID)}return d};a._GetXhrObject=function(){if(window.XMLHttpRequest){return function(){return new window.XMLHttpRequest()}}else{if(window.ActiveXObject){return function(){var e=null;if(a._MicrosoftXmlHttpProgID==null){for(var c=0;c<a._MicrosoftXmlHttpProgIDs.length;c++){var d=a._MicrosoftXmlHttpProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlHttpProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlHttpProgID)}return e}}}}()})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v15.0.7081.30245
 */
MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.HelpSystem=function(G,F,J,I,a){var z=this;var x=G;var y=new MadCap.Utilities.Url(J).ToFolder().ToFolder().FullPath;var j=null;var B=new Array();var D=I;var m=a;var t=null;var u=[];var v=new MadCap.Utilities.Dictionary();var n=null;var E=new MadCap.Utilities.Dictionary();var s=false;var k=new MadCap.WebHelp.AliasFile(y+"Data/Alias.xml",this);var C=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.Toc);var w=null;var l=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.BrowseSequence);var A=new MadCap.Utilities.Dictionary();this.TargetType=null;this.DefaultStartTopic=null;this.InPreviewMode=null;this.LiveHelpOutputId=null;this.LiveHelpServer=null;this.LiveHelpEnabled=false;this.IsWebHelpPlus=false;this.ContentFolder=null;this.UseCustomTopicFileExtension=false;this.CustomTopicFileExtension=null;this.IsMultilingual=false;this.GlossaryUrl=null;this.SearchFilterSetUrl=null;this.SyncTOC=null;this.IndexPartialWordSearch=true;this.GlossaryPartialWordSearch=true;this.DefaultSkin=null;this.IsAutoMerged=false;this.LanguageUrl=null;this.BreakpointsUrl=null;this.PreventExternalUrls=false;this.IsResponsive=false;this.SearchUrl=null;this.PulsePage=null;this.ScriptsFolderPath=null;this.LanguageCode=null;this.LanguageName=null;this.IncludeCSHRuntime=null;this.ShowMadCapBacklink=false;(function(){})();this.Load=function(K){MadCap.Utilities.Xhr.Load(J,true,function(aa){var P=0;function R(){P++;if(P==B.length){K()}}function Q(ad,ac){if(B.length>0){for(var ab=0;ab<B.length;ab++){B[ab].Load(ad)}}else{ac()}}s=aa!=null;if(!s){K();return}this.LanguageCode=aa.documentElement.getAttribute("xml:lang");this.LanguageName=aa.documentElement.getAttribute("LanguageName");this.TargetType=aa.documentElement.getAttribute("TargetType");this.DefaultStartTopic=aa.documentElement.getAttribute("DefaultUrl");this.InPreviewMode=MadCap.Dom.GetAttributeBool(aa.documentElement,"InPreviewMode",false);this.LiveHelpOutputId=aa.documentElement.getAttribute("LiveHelpOutputId");this.LiveHelpServer=aa.documentElement.getAttribute("LiveHelpServer");this.LiveHelpEnabled=this.LiveHelpOutputId!=null;this.MoveContentToRoot=MadCap.Dom.GetAttributeBool(aa.documentElement,"MoveOutputContentToRoot",false);this.ReplaceReservedCharacters=MadCap.Dom.GetAttributeBool(aa.documentElement,"ReplaceReservedCharacters",false);this.MakeFileLowerCase=MadCap.Dom.GetAttributeBool(aa.documentElement,"MakeFileLowerCase",false);this.PreventExternalUrls=MadCap.Dom.GetAttributeBool(aa.documentElement,"PreventExternalUrls",false);this.IsResponsive=MadCap.Dom.GetAttributeBool(aa.documentElement,"EnableResponsiveOutput",false);this.IncludeGlossarySearchResults=MadCap.Dom.GetAttributeBool(aa.documentElement,"IncludeGlossarySearchResults",true);this.ResultsPerPage=MadCap.Dom.GetAttributeInt(aa.documentElement,"ResultsPerPage",20);this.SearchEngine=MadCap.Dom.GetAttribute(aa.documentElement,"SearchEngine");this.IncludeCSHRuntime=MadCap.Dom.GetAttributeBool(aa.documentElement,"IncludeCSHRuntime",true);this.DebugMode=MadCap.Dom.GetAttributeBool(aa.documentElement,"DebugMode",false);if(this.SearchEngine=="Elasticsearch"){var N=aa.documentElement.getElementsByTagName("Elasticsearch");this.Elasticsearch=N.item(0)}var S=MadCap.Dom.GetAttributeBool(aa.documentElement,"ServerEnabled",false);this.IsWebHelpPlus=(this.TargetType=="WebHelpPlus"||S)&&MadCap.String.StartsWith(document.location.protocol,"http",false);var M="";if(!this.MoveContentToRoot){M="Content/"}if(this.MakeFileLowerCase){M=M.toLowerCase()}this.ContentFolder=M;this.UseCustomTopicFileExtension=MadCap.Dom.GetAttributeBool(aa.documentElement,"UseCustomTopicFileExtension",false);this.CustomTopicFileExtension=MadCap.Dom.GetAttribute(aa.documentElement,"CustomTopicFileExtension");this.IsMultilingual=MadCap.Dom.GetAttributeBool(aa.documentElement,"Multilingual",false);this.ShowMadCapBacklink=MadCap.Dom.GetAttributeBool(aa.documentElement,"ShowMadCapBacklink",false);this.GlossaryUrl=f(aa,"Glossary");this.TocUrl=f(aa,"Toc");this.SearchUrl=f(aa,"SearchUrl");this.PulsePage=f(aa,"PulsePage");this.BrowseSequencesUrl=f(aa,"BrowseSequence");this.IndexUrl=f(aa,"Index");this.SearchFilterSetUrl=f(aa,"SearchFilterSet");this.LanguageUrl=y+"Data/Language.js";this.BreakpointsUrl=y+"Data/Breakpoints.js";this.ScriptsFolderPath=aa.documentElement.getAttribute("PathToScriptsFolder");this.HasBrowseSequences=aa.documentElement.getAttribute("BrowseSequence")!=null;this.HasToc=aa.documentElement.getAttribute("Toc")!=null;this.TopNavTocPath=aa.documentElement.getAttribute("TopNavTocPath")=="true";b.call(this,aa);this.DefaultSkin=this.GetSkin($(aa.documentElement).attr("SkinID"));this.SyncTOC=this.DefaultSkin!=null&&MadCap.String.ToBool(this.DefaultSkin.AutoSyncTOC,false);this.IndexPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.IndexPartialWordSearch,true);this.GlossaryPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.GlossaryPartialWordSearch,true);this.DisplayCommunitySearchResults=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.DisplayCommunitySearchResults,true);this.CommunitySearchResultsCount=3;if(this.DefaultSkin!=null){this.CommunitySearchResultsCount=MadCap.String.ToInt(this.DefaultSkin.CommunitySearchResultsCount,3)}var V=aa.getElementsByTagName("Subsystems");if(V.length>0&&V[0].getElementsByTagName("Url").length>0){var Z=aa.getElementsByTagName("Subsystems")[0].getElementsByTagName("Url");for(var O=0;O<Z.length;O++){var Y=Z[O];if(!Y){continue}var X=Y.getAttribute("Source");var U=X.substring(0,X.lastIndexOf("/")+1);var W=Y.getAttribute("TocPath");var L=Y.getAttribute("BrowseSequencePath");var T=new MadCap.WebHelp.HelpSystem(this,y+U,y+U+"Data/HelpSystem.xml",W,L);B.push(T)}}this.LoadBreakpoints(function(){z.LoadLanguage(function(){if(!z.IsAutoMerged&&z.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(z.GetPath()+"Service/Service.asmx/GetSubsystems",true,function(ac,ab){if(ac){$.each(ac.documentElement.childNodes,function(ad,ae){if(ae.nodeName=="Subsystems"){$.each(ae.childNodes,function(af,ag){if(ag.nodeName=="Url"){var aj=ag.getAttribute("Source");var ai=aj.substring(0,aj.lastIndexOf("/")+1);if(ai){var ah=new MadCap.WebHelp.HelpSystem(z,y+ai,y+ai+"Data/HelpSystem.xml",null,null);ah.IsAutoMerged=true;B.push(ah)}}})}})}Q(R,K)})}else{Q(R,K)}})})},null,this)};this.GetExists=function(){return s};this.GetMasterHelpSystem=function(){var L=this;for(var K=L.GetParentSubsystem();K!=null;K=K.GetParentSubsystem()){L=K}return L};this.GetParentSubsystem=function(){return x};this.GetPath=function(){return y};this.GetCurrentTopicPath=function(){return MadCap.Utilities.Url.GetDocumentUrl().ToRelative(MadCap.Utilities.Url.GetAbsolutePath(y)).FullPath};this.GetAbsolutePath=function(){if(j==null){var K=new MadCap.Utilities.Url(y);j=K.IsAbsolute?K.FullPath:new MadCap.Utilities.Url(document.location.href).Path}return j};this.GetContentPath=function(){return y+this.ContentFolder};this.GetSkin=function(K){return A.GetItem(K)};this.GetSkinByName=function(L){var N=this.GetSkins();for(var K=0;K<N.length;K++){var M=N[K];if(M.Name==L){return M}}return null};this.GetCurrentSkin=function(){var O=MadCap.Utilities.Url.GetDocumentUrl();var N=O.QueryMap.GetItem("skinName")||O.HashMap.GetItem("skinName");if(N){var M=this.GetSkin(N);if(!M){M=this.GetSkinByName(N)}return M}var K=O.QueryMap.GetItem("cshid");if(K){var L=k.LookupID(K);if(L.Skin){var M=this.GetSkin(L.Skin);if(!M){M=this.GetSkinByName(L.Skin)}return M}}return this.DefaultSkin};this.GetTocPath=function(K){return K=="toc"?D:m};this.GetFullTocPath=function(N,L){var M=this.GetHelpSystem(L);if(M==null){return null}var K=new Object();K.tocPath=this.GetTocPath(N);M.ComputeTocPath(N,K);return K.tocPath};this.GetTopicPath=function(M){var O=this.GetPath();var N=this.GetMasterHelpSystem();var L=(new MadCap.Utilities.Url(document.location.href)).ToPath();var K=L.CombinePath(O+"Data/").CombinePath(M);var P=K.ToRelative(L);if(MadCap.Utilities.HasRuntimeFileType("TriPane")&&!N.MoveContentToRoot){P=P.ToRelative(N.ContentFolder)}return P};this.GetPatchedPath=function(K){if(this.ReplaceReservedCharacters){K=MadCap.Utilities.Url.ReplaceReservedCharacters(K,"_")}if(this.MakeFileLowerCase){K=K.toLowerCase()}if(this.UseCustomTopicFileExtension){K=new MadCap.Utilities.Url(K).ToExtension(this.CustomTopicFileExtension).FullPath}return K};this.GetAbsoluteTopicPath=function(M){var L=new MadCap.Utilities.Url(M);var K=(new MadCap.Utilities.Url(document.location.href)).ToPlainPath();return K.CombinePath(this.GetTopicPath("../"+L.FullPath).FullPath)};this.ComputeTocPath=function(M,L){if(x){var K=this.GetTocPath(M);if(!MadCap.String.IsNullOrEmpty(K)){L.tocPath=L.tocPath?K+"|"+L.tocPath:K}x.ComputeTocPath(M,L)}};this.GetHelpSystem=function(M){var K=null;for(var L=0;L<B.length;L++){K=B[L].GetHelpSystem(M);if(K!=null){return K}}if(MadCap.String.StartsWith(M,y,false)){return this}return null};this.GetSubsystem=function(K){return B[K]};this.GetMergedAliasIDs=function(K){k.Load(function(){function Q(S){for(var R=0,T=S.length;R<T;R++){P[P.length]=S[R]}L++;if(L==O+1){K(P)}}var P=new Array();var O=B.length;var L=0;var N=k.GetIDs();Q(N);for(var M=0;M<O;M++){B[M].GetMergedAliasIDs(Q)}})};this.GetMergedAliasNames=function(K){k.Load(function(){function Q(T){for(var R=0,S=T.length;R<S;R++){O[O.length]=T[R]}L++;if(L==N+1){K(O)}}var O=new Array();var N=B.length;var L=0;var P=k.GetNames();Q(P);for(var M=0,N=B.length;M<N;M++){B[M].GetMergedAliasNames(Q)}})};this.LookupCSHID=function(K,L){k.Load(function(){function R(S){if(O){return}M++;if(S.Found){O=true;L(S);return}if(M==Q){L(N)}}var N=k.LookupID(K);if(N.Found){N.Topic=z.GetPath()+N.Topic;L(N);return}if(B.length==0){L(N);return}var O=false;var M=0;for(var P=0,Q=B.length;P<Q;P++){B[P].LookupCSHID(K,R)}})};this.GetTocFile=function(){return C};this.GetBrowseSequenceFile=function(){return l};this.IsMerged=function(){return(B.length>0)};this.IsRoot=function(){return x==null};this.IsTabletLayout=function(K){return this.isGivenLayout("Tablet",K)};this.getLayout=function(K){if(this.isGivenLayout("Mobile",K)){return"Mobile"}else{if(this.isGivenLayout("Tablet",K)){return"Tablet"}else{return"Web"}}};this.isGivenLayout=function(L,N){if(this.IsResponsive&&this.Breakpoints){var K=this.Breakpoints.mediums[L];var M=this.Breakpoints.prop;if(M=="max-width"){if(!N){N=window.innerWidth}return N<=K}else{return window.matchMedia("("+M+": "+K+"px)").matches}}return false};this.ProcessMicroContentXhtml=function(M){var P=MadCap.Utilities.SanitizeHtml("<div>"+M+"</div>");var O=new MadCap.Utilities.Url(this.GetPath()+"MicroContent/");var N=MadCap.Utilities.HasRuntimeFileType("TriPane");var L=N?"#":"";var K=MadCap.Utilities.FixLinks(P,O,L,this.ContentFolder);return K};this.LoadLanguage=function(L,K){var M=this;require([this.LanguageUrl],function(N){M.Language=N;L.call(K,N)})};this.LoadBreakpoints=function(L,K){if(this.IsResponsive&&this.IsRoot()){var M=this;require([this.BreakpointsUrl],function(N){M.Breakpoints=N;L.call(K,N)})}else{L.call(K,null)}};this.LoadConcepts=function(){var K=$.Deferred();require([y+"Data/Concepts.js"],function(L){n=L;K.resolve(n)});return K.promise()};this.LoadAllConcepts=function(N){function O(){K++;if(K==M+1){N()}}var K=0;var M=B.length;this.LoadConcepts().then(O);for(var L=0;L<M;L++){var P=B[L];if(!P.GetExists()){O();continue}P.LoadAllConcepts(O)}};this.GetConceptsLinks=function(L){var M=$.Deferred();var P=[];if(this.IsWebHelpPlus){function Q(aa,T){var X=aa.documentElement.getElementsByTagName("Url");var W=X.length;for(var U=0;U<W;U++){var V=X[U];var Y=V.getAttribute("Title");var Z=V.getAttribute("Source");Z=y+((Z.charAt(0)=="/")?Z.substring(1,Z.length):Z);P[P.length]={Title:Y,Link:Z}}M.resolve(P)}MadCap.Utilities.Xhr.CallWebService(y+"Service/Service.asmx/GetTopicsForConcepts?Concepts="+L,true,Q)}else{function S(T){P=P.Union(T)}L=L.replace("\\;","%%%%%");if(L==""){M.resolve(P)}else{var K=L.split(";");var N=[];N.push(this.GetConceptsLinksLocal(K).then(S));for(var O=0;O<B.length;O++){var R=B[O];if(R.GetExists()){N.push(R.GetConceptsLinks(L).then(S))}}$.when.apply(this,N).done(function(){M.resolve(P)})}}return M.promise()};this.GetConceptsLinksLocal=function(L){var P=[];var N=[];for(var O=0;O<L.length;O++){var K=L[O];K=K.replace("%%%%%",";");N.push(this.GetConceptLinks(K).then(function(Q){P=P.concat(Q)}))}var M=$.Deferred();$.when.apply(this,N).done(function(){M.resolve(P)});return M.promise()};this.LoadTopicChunk=function(K){var L=$.Deferred();MadCap.Utilities.Require([y+"Data/SearchTopic_Chunk"+K+".js"],function(M){L.resolve(M)});return L.promise()};this.GetSearchChunkIds=function(L){var K=$.Deferred();MadCap.Utilities.Require([y+"Data/Search.js"],function(M){var P=M.t;var O=[];for(var N=0;N<L.length;N++){O.push(MadCap.Utilities.GetChunkId(P,L[N],function(Q,R){if(Q<R){return -1}else{if(Q===R){return 0}else{return 1}}}))}K.resolve(O)});return K.promise()};this.GetConceptLinks=function(K){var L=$.Deferred();var M=this;this.LoadConcepts().done(function(){var N=[];var O=n[K];if(!O){L.resolve(N)}else{M.GetSearchChunkIds(O).then(function(Q){var R=[];for(var S=0;S<Q.length;S++){var P=Q[S];R.push(M.LoadTopicChunk(P).then(function(T){for(var U=0;U<O.length;U++){var V=T[O[U]];if(V){V.Url=M.GetTopicPath(V.u);N.push(V)}}}))}$.when.apply(this,R).done(function(){L.resolve(N)})})}});return L.promise()};this.LoadToc=MadCap.Utilities.Memoize(function(L){var K=$.Deferred();var M=L[0];var N=L[1];this.GetToc(M,N,function(O){K.resolve(O)});return K.promise()});this.GetToc=function(N,M,K){var L=this;var O=this[N+"Url"];if(M){O=e(M)}require([O],function(X){if(typeof X=="undefined"||(L[N]&&X.chunks)){K(X);return}L[N]=X;X.type=N;X.helpSystem=L;X.chunks=[];X.entries=[];X.nodes={};var Q=new MadCap.Utilities.Url(O).ToFolder();for(var P=0;P<X.numchunks;P++){X.chunks[P]={path:Q.AddFile(X.prefix+P+".js").FullPath,loaded:false}}var V=X.tree;var T={};X.automerge=X.tree;while(V!=null){V.toc=X;V.childrenLoaded=false;X.nodes[V.i]=V;if(typeof V.m!=="undefined"){T[V.m]=V}if(typeof V.a!=="undefined"){X.automerge=V}if(typeof V.n!=="undefined"){for(var S=0;S<V.n.length;S++){V.n[S].parent=V;if(S<V.n.length-1){V.n[S].next=V.n[S+1]}if(S>0){V.n[S].previous=V.n[S-1]}}}V=g(V)}var U=[];var R=false;for(var S=0;S<B.length;S++){var W=B[S];if(W.GetExists()){if(!W.IsAutoMerged){W.MergeNode=T[S]}else{R=true}if(W.IsAutoMerged||typeof W.MergeNode!=="undefined"){U.push(W)}}else{H(T[S])}}if(!R&&X.automerge.a=="replace"){H(X.automerge)}if(U.length==0){K(X);return}MadCap.Utilities.AsyncForeach(U,function(Z,Y){r(X,Z,Y)},function(){K(X)})})};function H(M){var N=M.parent;var O=M.previous;var L=M.next;if(O){O.next=L;M.previous=null}if(L){L.previous=O;M.next=null}if(N){var K=M.parent.n.indexOf(M);N.n.splice(K,1);M.parent=null}}function g(L){var K=null;if(typeof L.n!="undefined"){K=L.n[0]}else{if(typeof L.next!="undefined"){K=L.next}else{K=L;while(typeof K.parent!="undefined"){if(typeof K.parent.next!="undefined"){K=K.parent.next;break}else{K=K.parent}}if(typeof K.parent=="undefined"){K=null}}}return K}function h(K){var L=null;if(typeof K.previous!="undefined"){L=K.previous;while(typeof L.n!=="undefined"&&L.n.length>0){L=L.n[L.n.length-1]}}else{if(typeof K.parent!="undefined"){L=K.parent}}return L}function i(P,M){var Q="";var O=-1;var K=null;if(P.n&&P.n.length>0){Q=P.toc.entries[P.i].title;if(M){Q=encodeURIComponent(Q)}O=0}else{O=P.parent.n.indexOf(P)+1}if(Q.length>0){Q+="|"}Q+=("_____"+O);for(var L=P.parent;L&&typeof L.i!=="undefined";L=L.parent){if(Q==null){Q=""}if(Q.length>0){Q="|"+Q}var N=L.toc.entries[L.i];if(N){var R=N.title;if(M){R=encodeURIComponent(R)}Q=R+Q}}return Q}function r(M,L,K){L.GetToc(M.type,null,function(X){if(typeof X=="undefined"){K();return}var U=L.IsAutoMerged?M.automerge:L.MergeNode;var T=X.tree;if(T.n!==undefined&&U!==undefined){var W=U.r==1||(L.IsAutoMerged&&U.a=="replace");var P=W||(L.IsAutoMerged&&(U.a=="before-head"||U.a=="after-head"));var Q=W||(L.IsAutoMerged&&(U.a=="before-head"||U.a=="after-tail"));var V=Q?U.parent:U;if(typeof V.n=="undefined"){V.n=[]}var N=Q?V.n.indexOf(U)+(P?0:1):P?0:V.n.length;var S=T.n.length;for(var O=0;O<S;O++){T.n[O].parent=V;V.n.splice(N+O,0,T.n[O])}if(W){V.n.splice(N+S,1)}if(N>0){V.n[N].previous=V.n[N-1];V.n[N-1].next=V.n[N]}var R=N+S-(W?1:0)-1;if(R>=0&&R+1<V.n.length){V.n[R].next=V.n[R+1];V.n[R+1].previous=V.n[R]}if(L.IsAutoMerged){M.automerge=V.n[N+S-1];M.automerge.a="after-tail"}}K()})}this.LoadTocChunk=function(M,K){var L=$.Deferred();require([M.chunks[K].path],function(N){if(!M.chunks[K].loaded){for(var P in N){for(var O=0;O<N[P].i.length;O++){M.entries[N[P].i[O]]={link:P,title:N[P].t[O],bookmark:N[P].b[O]}}}M.chunks[K].loaded=true}return L.resolve(N)});return L.promise()};this.GetTocEntryHref=function(M,Y,aa,K){var Q=null;var W=M.toc;var L=W.entries[M.i];if(L){var T=L.link+L.bookmark;if(typeof M.m=="undefined"&&T!="___"){var Z=null;var U=new MadCap.Utilities.Url(T);var O=W.helpSystem;var P=O.GetPath();var V=O.GetMasterHelpSystem().GetContentPath();var N=typeof M.f!="undefined";if(!U.IsAbsolute){if(!MadCap.String.IsNullOrEmpty(P)){U=new MadCap.Utilities.Url(P).CombinePath(T);Z=U.ToRelative(V)}else{U=U.ToRelative("/"+V);Z=U}}else{Z=U}if(N||!aa){if(Z.IsAbsolute){Q=Z.FullPath}else{Q=V+Z.FullPath}}else{if(MadCap.Utilities.HasRuntimeFileType("TriPane")){Q="#"+Z.FullPath}else{Q=U.FullPath}}}}if(Q!=null&&Y&&K){var S=window.name=="topic"&&!MadCap.Utilities.HasRuntimeFileType("Default");var X=i(M,true);if(MadCap.Utilities.HasRuntimeFileType("TriPane")){Q+=encodeURIComponent("?"+Y+"Path="+X)}else{var R=new MadCap.Utilities.Url(Q);if(S){Q=R.PlainPath+encodeURIComponent("?"+Y+"Path="+X)+R.Fragment}else{Q=R.PlainPath+"?"+(Y+"Path="+X)+R.Fragment}}}return Q};this.GetTocData=function(L){var S=null,R=null,K=null;var O=MadCap.Utilities.HasRuntimeFileType("TriPane");if(O&&!MadCap.String.IsNullOrEmpty(L.Fragment)&&L.Fragment.length>1||!O){var Q=(O&&!(L.QueryMap.GetItem("TocPath")||L.QueryMap.GetItem("BrowseSequencesPath"))&&!MadCap.String.IsNullOrEmpty(L.Fragment))?new MadCap.Utilities.Url(L.Fragment):L;R=Q.QueryMap.GetItem("TocPath");if(R!=null){S="Toc"}else{K=Q.QueryMap.GetItem("BrowseSequencesPath");if(K!=null){S="BrowseSequences"}}if(L.HashMap.GetItem("cshid")==null){var M=L.Query.indexOf("?");var N=L.Query.lastIndexOf("?");var P="";if(M!=N){P=L.Query.substr(M,N)}if(O){L=new MadCap.Utilities.Url(L.Fragment.substr(1))}if(!MadCap.String.IsNullOrEmpty(P)){L.Query=P}}}else{L=new MadCap.Utilities.Url(this.DefaultStartTopic).ToRelative(this.GetContentPath())}return{TocType:S,TocPath:R,BrowseSequencesPath:K,Href:L}};this.FindTocNode=function(M,K,L,N){z.FindNode("Toc",M,K,L,N)};this.FindBrowseSequenceNode=function(M,K,L){z.FindNode("BrowseSequences",M,K,L)};this.FindNode=function(N,M,K,L,O){z.FindNodeInToc(N,M,K,L,O,true)};this.FindNodeInToc=function(O,N,K,M,P,L){z.LoadToc([O,P]).then(function(U){var T=new MadCap.Utilities.Url(z.GetMasterHelpSystem().GetContentPath());var V=K;var Q=0;var R;if(!K.IsAbsolute){var V=!MadCap.String.IsNullOrEmpty(T.FullPath)?T.CombinePath(K):K;V=V.ToRelative(z.GetPath());V=new MadCap.Utilities.Url("/"+V.FullPath)}for(var S=1;S<U.chunkstart.length;S++){if(U.chunkstart[S]<=decodeURIComponent(V.PlainPath)){Q++}}z.LoadTocChunk(U,Q).then(function(W){var X=W[decodeURIComponent(V.PlainPath)];if(typeof X!=="undefined"){var Z=[];if(!R){R=U.nodes[X.i[0]]}if(N){for(var Y=0;Y<X.i.length;Y++){if(i(U.nodes[X.i[Y]],false)==N){Z.push(X.i[Y])}}}else{for(var Y=0;Y<X.i.length;Y++){if(X.b[Y].toLowerCase()==decodeURIComponent(V.Fragment).toLowerCase()){Z.push(X.i[Y])}}}if(Z.length){M(U.nodes[Z.pop()]);return}}if(B.length>0&&L){MadCap.Utilities.AsyncForeach(B,function(ab,aa){ab.FindNode(O,N,K,function(ac){if(typeof ac!=="undefined"){M(ac);return}aa()})},function(){M(R)})}else{M(R)}})})};this.NodeDepth=function(L){var K=1;while(L.parent&&L.c!==undefined){K++;L=L.parent}return K};this.LoadGlossary=function(L,K){if(typeof this.Glossary!="undefined"){L.call(K,this.Glossary);return}var M=this;this.GetGlossary(function(N){if(N&&N.terms){N.termMap=Object.create(null);for(var O=0;O<N.terms.length;O++){var P=N.terms[O];N.termMap[P.t.toLowerCase()]=P}}M.Glossary=N;L.call(K,N)})};this.GetGlossary=function(K){var L=this;require([this.GlossaryUrl],function(P){function S(){N++;if(N==R){K(P)}}if(typeof P=="undefined"){K(P);return}var N=0;var R=0;P.chunks=[];var O=new MadCap.Utilities.Url(z.GlossaryUrl).ToFolder();for(var M=0;M<P.numchunks;M++){P.chunks.push({helpSystem:L,path:O.AddFile(P.prefix+M+".js").FullPath})}for(var Q=0;Q<B.length;Q++){var T=B[Q];if(!T.GetExists()){continue}R++}if(R==0){K(P);return}for(var Q=0;Q<B.length;Q++){var T=B[Q];if(!T.GetExists()){continue}p(P,T,S)}})};this.SearchGlossary=function(L){var K=$.Deferred();var M=this;this.LoadGlossary(function(P){var O=false;if(P&&P.termMap){var Q=P.termMap[L.toLowerCase()];O=typeof Q!="undefined";if(O){var N=P.chunks[Q.c];require([N.path],function(R){var S={term:Q.t,definition:R[Q.t].d,link:R[Q.t].l};if(S.link){var T=N.helpSystem;var U=(new MadCap.Utilities.Url("../")).CombinePath(S.link).FullPath;S.link=T.GetTopicPath(U).FullPath;T.SearchDB.LoadTopicByUrl(U).done(function(W,V){if(V){S.abstractText=V.a}K.resolve(S)})}else{K.resolve(S)}})}}if(!O){K.resolve()}},this);return K.promise()};this.LoadIndex=function(L,K){if(typeof this.Index!=="undefined"){L.call(K,this.Index);return}var M=this;this.GetIndex(function(N){M.Index=N;L.call(K,N)})};this.GetIndex=function(K){var L=this;require([this.IndexUrl],function(Q){function S(){N++;if(N==R){K(Q)}}if(typeof Q=="undefined"){K(Q);return}var N=0;var R=0;Q.chunks=[];var O=new MadCap.Utilities.Url(z.IndexUrl).ToFolder();for(var M=0;M<Q.numchunks;M++){Q.chunks.push({helpSystem:L,path:O.AddFile(Q.prefix+M+".js").FullPath})}for(var P=0;P<B.length;P++){var T=B[P];if(!T.GetExists()){continue}R++}if(R==0){K(Q);return}for(var P=0;P<B.length;P++){var T=B[P];if(!T.GetExists()){continue}q(Q,T,S)}})};this.LoadRootIndexEntry=function(L,K){if(L.loaded){if(K){K(L)}return}this.LoadIndex(function(N){var M=typeof L.c=="number"?[L.c]:L.c;MadCap.Utilities.AsyncForeach(M,function(O,P){var Q=N.chunks[O];require([Q.path],function(R){var S=R[L.t];z.SetIndexEntryHelpSystem(S,Q.helpSystem);z.MergeIndexEntries(L,S);P()})},function(){z.LoadIndexEntry(L);if(K){K(L)}})})};this.SetIndexEntryHelpSystem=function(K,L){if(K.l){$.each(K.l,function(M,N){N.helpSystem=L})}if(K.e){$.each(K.e,function(N,M){z.SetIndexEntryHelpSystem(M,L)})}};this.LoadIndexEntry=function(K){if(K.l){var L=[];$.each(K.l,function(M,N){var O={Title:N.t,Link:N.helpSystem.GetTopicPath(".."+N.u).FullPath};L[L.length]=O});K.linkList=z.SortLinkList(L)}if(K.e){$.each(K.e,function(N,M){z.LoadIndexEntry(M)})}K.loaded=true};this.MergeIndexEntries=function(K,L){if(L.l){if(typeof K.l=="undefined"){K.l=L.l}else{K.l=K.l.concat(L.l)}}if(L.r){if(typeof K.r=="undefined"){K.r=L.r}else{if(K.r=="SeeAlso"||L.r=="SeeAlso"){K.r="SeeAlso"}}if(typeof K.f=="undefined"){K.f=L.f}else{var M=K.f.split(";");var N=L.f.split(";");$.each(N,function(O,P){if($.inArray(M,P)){M.push(P)}});M.sort(function(Q,R){var O=Q.toLowerCase();var P=R.toLowerCase();return O<P?-1:O>P?1:0});K.f=M.join("; ")}}if(L.e){if(typeof K.e=="undefined"){K.e={}}$.each(L.e,function(P,O){if(typeof K.e[P]!=="undefined"){z.MergeIndexEntries(K.e[P],O)}else{K.e[P]=O}})}};this.FindIndexEntry=function(L,K){z.LoadIndex(function(M){if(!M.entries){M.entries={};$.each(M.terms,function(R,Q){M.entries[Q.t]=Q})}var P=L.split(":");var O=P.length;var N=M.entries[P[0]];if(N){z.LoadRootIndexEntry(N,function(S){var Q=S;for(var R=1;R<O;R++){Q=Q.e[P[R]];if(!Q){break}}if(K){K(S,Q)}})}else{if(K){K()}}})};this.SortLinkList=function(K){K.sort(function(L,M){var N=L.Title.toLowerCase();var O=M.Title.toLowerCase();return N<O?-1:N>O?1:0});return K};this.GetSearchDBs=function(K){var L=new Array();var M=this;require([y+"Data/Search.js"],function(P){function Q(T){if(T!=null){for(var S=0;S<T.length;S++){L[L.length]=T[S]}}N++;if(N==O){K(L)}}var N=0;var O=B.length;var R=new MadCap.WebHelp.Search.SearchDB(M);M.SearchDB=R;L[L.length]=R;R.Load(P,function(){var T=P.pm;if(T||O==0){K(L)}else{for(var S=0;S<O;S++){var U=B[S];if(!U.GetExists()){Q(null);continue}U.GetSearchDBs(Q)}}})})};this.GetConcepts=function(){return n};this.GetSearchFilters=function(){return t.map};this.ParseSearchFilterDoc=function(Q){filterMap=Object.create(null);if(Q!=null){var M=Q.getElementsByTagName("SearchFilter");for(var N=0;N<M.length;N++){var L=M[N];var O=L.getAttribute("Name");var P=L.getAttribute("Order");var K=L.getAttribute("Concepts");if(!K){continue}filterMap[O]={c:K,o:P,group:0}}}return filterMap};this.LoadSearchFiltersLocal=function(){var K=$.Deferred();require([this.SearchFilterSetUrl],function(L){var M=null;if(L){M={map:L,count:1}}K.resolve(M)});return K.promise()};this.LoadSearchFilters=function(){var K=$.Deferred();if(!this.IsWebHelpPlus){function O(W){if(W){if(!N){N=W;for(var V in W.map){W.map[V].group=0}}else{for(var V in W.map){if(!N.map[V]){N.map[V]=W.map[V];N.map[V].group+=N.count}else{var T=N.map[V];var U=W.map[V];var R=T.c.split(";");var S=U.c.split(";");T.c=R.Union(S).join(";");if(MadCap.String.IsNullOrEmpty(T.cm)){T.cm=U.cm}}}N.count+=W.count}}}var N;var L=[];L.push(this.LoadSearchFiltersLocal().then(O));for(var M=0;M<B.length;M++){var Q=B[M];if(Q.GetExists()){L.push(Q.LoadSearchFilters().then(O))}}$.when.apply(this,L).done(function(){t=N;K.resolve(N)})}else{var P=this;MadCap.Utilities.Xhr.CallWebService(y+"Service/Service.asmx/GetSearchFilters",true,function(T,R){var S=P.ParseSearchFilterDoc(T);K.resolve({map:S})})}return K.promise()};this.AdvanceTopic=function(Q,O,P,K,N,L){var M=null;z.FindNode(Q,P,N,function(S){if(S){function R(U,T){U=T=="next"?g(U):h(U);if(U&&typeof U.i!=="undefined"){z.LoadTocChunk(U.toc,U.c).then(function(V){var W=U.toc.entries[U.i];var X=z.GetTocEntryHref(U,Q,true,K);if(X){if(MadCap.String.StartsWith(X,"#")){X=X.substring(1)}L(X)}else{R(U,T)}})}}R(S,O)}})};this.SetBrowseSequencePath=function(L,M){var K=$(".current-topic-index-button");if(L!=null){this.FindBrowseSequenceNode(L,M,function(N){if(N&&N.parent){K.removeClass("disabled");$(".sequence-index").text(N.parent.n.indexOf(N)+1);$(".sequence-total").text(N.parent.n.length)}else{K.addClass("disabled")}})}else{K.addClass("disabled")}};this.GetSkins=function(){var K=[];A.ForEach(function(L,M){K.push(M)});return K};function f(M,K){var L=M.documentElement.getAttribute(K);return e(L)}function e(L){if(L==null){return null}var K=new MadCap.Utilities.Url(y);if(!K.IsAbsolute){return y+L}return K.AddFile(L).ToRelative(document.location.href).FullPath}function b(aa){var Z=$("CatapultSkin",aa.documentElement);for(var O=0,R=Z.length;O<R;O++){var Y=Z[O];var K=$(Y);var X=K.attr("SkinID");var W={};for(var P=0,S=Y.attributes.length;P<S;P++){var L=Y.attributes[P];W[L.name]=L.value}var N=K.children();for(var P=0,S=N.length;P<S;P++){var M=N[P];var U=M.nodeName;var V={};W[U]=V;for(var Q=0,T=M.attributes.length;Q<T;Q++){var L=M.attributes[Q];V[L.name]=L.value}}A.Add(X,W)}}function c(N,P){if(N.nodeName.toLowerCase()=="madcap:glossarychunkref"){var K=$(N);var O=K.attr("src");if(!MadCap.String.IsNullOrEmpty(O)){var Q=new MadCap.Utilities.Url(P).CombinePath("../../Data/").CombinePath(O);var L=MadCap.Utilities.EncodeHtml("../"+Q.FullPath);K.attr("src",L)}}else{var M=N.getElementsByTagName("a")[0];var O=$(M).attr("href");if(!MadCap.String.IsNullOrEmpty(O)){var Q=new MadCap.Utilities.Url(P).CombinePath("../../Content/").CombinePath(O);var L=MadCap.Utilities.EncodeHtml("../"+Q.FullPath);$(M).attr("href",L)}}}function d(M){for(var L=0;L<M.childNodes.length;L++){var K=M.childNodes[L];if(K.nodeName=="Entries"){for(var N=0;N<K.childNodes.length;N++){d(K.childNodes[N])}}else{if(K.nodeName=="Links"){for(var N=0;N<K.childNodes.length;N++){if(K.childNodes[N].nodeType==1){var O=MadCap.Dom.GetAttribute(K.childNodes[N],"Link");O=y+((O.charAt(0)=="/")?O.substring(1,O.length):O);K.childNodes[N].setAttribute("Link",O)}}}}}}function o(L,M){if(!M){return}for(var K=0;K<M.length;K++){L[L.length]=M[K]}}function p(K,M,L){M.GetGlossary(function(Q){if(typeof Q=="undefined"){L();return}K.chunks=K.chunks.concat(Q.chunks);for(var R=0,S=0;R<K.terms.length&&S<Q.terms.length;){var O=K.terms[R];var P=Q.terms[S];var T=O.t;var U=P.t;if(T.toLowerCase()==U.toLowerCase()){R++;S++}else{if(T.toLowerCase()>U.toLowerCase()){P.c+=K.numchunks;K.terms.splice(R,0,P);S++}else{R++}}}for(;S<Q.terms.length;S++){var N=Q.terms[S];N.c+=K.numchunks;K.terms.push(N)}K.numchunks=K.chunks.length;L()})}function q(K,M,L){M.GetIndex(function(S){if(typeof S=="undefined"){L();return}K.chunks=K.chunks.concat(S.chunks);for(var R=0,T=0;R<K.terms.length&&T<S.terms.length;){var P=K.terms[R];var Q=S.terms[T];var U=P.s||P.t;var V=Q.s||Q.t;if(U==V&&P.t==Q.t){if(typeof P.c=="number"){P.c=[P.c]}var N=Q.c;if(typeof Q.c=="number"){N=[Q.c]}$.each(N,function(X,W){P.c.push(W+K.numchunks)});P.$=(P.$===1&&Q.$===1)?1:0;R++;T++}else{if(U.toLowerCase()>V.toLowerCase()||(U.toLowerCase()==V.toLowerCase()&&P.t.toLowerCase()>Q.t.toLowerCase())){Q.c+=K.numchunks;K.terms.splice(R,0,Q);T++}else{R++}}}for(;T<S.terms.length;T++){var O=S.terms[T];O.c+=K.numchunks;K.terms.push(O)}K.numchunks=K.chunks.length;L()})}};(function(){MadCap.WebHelp.HelpSystem.LoadHelpSystem=MadCap.Utilities.Memoize(function(c){var a=$.Deferred();var b=new MadCap.WebHelp.HelpSystem(null,null,c,null,null);b.Load(function(){a.resolve(b)});return a.promise()})})();MadCap.WebHelp.TocFile=function(h,s){var o=this;var j=h;var r=s;var k=false;var n=null;var l=new Array();var q=null;var p=null;var m=new Array();(function(){})();this.Init=function(u){if(k){if(u!=null){u()}return}if(u!=null){l.push(u)}var t=null;if(s==MadCap.WebHelp.TocFile.TocType.Toc){t="Toc.xml"}else{if(s==MadCap.WebHelp.TocFile.TocType.BrowseSequence){t="BrowseSequences.xml"}}this.LoadToc(j.GetPath()+"Data/"+t,v);function v(w){k=true;n=w.documentElement;i()}};this.LoadToc=function(v,t){if(r==MadCap.WebHelp.TocFile.TocType.Toc&&j.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(j.GetPath()+"Service/Service.asmx/GetToc",true,u,null)}else{if(r==MadCap.WebHelp.TocFile.TocType.BrowseSequence&&j.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(j.GetPath()+"Service/Service.asmx/GetBrowseSequences",true,u,null)}else{var w=(v.indexOf("/")==-1)?j.GetPath()+"Data/"+v:v;MadCap.Utilities.Xhr.Load(w,false,u,null,null)}}function u(y,x){if(!y||!y.documentElement){if(t!=null){t(y)}return}if(t!=null){t(y)}}};this.LoadChunk=function(v,w,t){var x=(w.indexOf("/")==-1)?j.GetPath()+"Data/"+w:w;MadCap.Utilities.Xhr.Load(w,true,u,null,null);function u(E,y){if(!E||!E.documentElement){if(t!=null){t(v)}return}v.removeAttribute("Chunk");var D=E.documentElement;for(var A=0,C=D.childNodes.length;A<C;A++){var z=D.childNodes[A];if(z.nodeType!=1){continue}var B=null;if(typeof(E.importNode)=="function"){B=E.importNode(z,true)}else{B=z.cloneNode(true)}v.appendChild(B)}if(t!=null){t(v)}}};this.LoadMerge=function(x,u){var t=MadCap.Dom.GetAttributeInt(x,"MergeHint",-1);if(t==-1){u(x,false,null,null);return}x.removeAttribute("MergeHint");var w=f(x);var z=w.GetSubsystem(t);var y=MadCap.Dom.GetAttributeBool(x,"ReplaceMergeNode",false);if(!y){x.setAttribute("ownerHelpSystemIndex",m.length)}m[m.length]=z;var B=z.GetPath()+"Data/"+(r==MadCap.WebHelp.TocFile.TocType.Toc?"Toc.xml":"BrowseSequences.xml");var A=MadCap.Utilities.Xhr.Load(B,true,v);function v(N,C){if(!N||!N.documentElement){if(u!=null){u(x,false,null,null)}return}var M=N.documentElement;var E=null;var I=true;var F=null;var J=null;var L=x.ownerDocument;for(var G=0,K=M.childNodes.length;G<K;G++){var D=M.childNodes[G];if(D.nodeType!=1){continue}var H=null;if(typeof(L.importNode)=="function"){H=L.importNode(D,true)}else{H=D.cloneNode(true)}if(y){H.setAttribute("ownerHelpSystemIndex",m.length-1);if(I){I=false;x.parentNode.replaceChild(H,x);F=H;J=F}else{E.parentNode.insertBefore(H,E.nextSibling);J=H}E=H}else{x.appendChild(H)}}if(u!=null){u(x,y,F,J)}}};this.AdvanceTopic=function(v,x,u,t){this.GetTocNode(x,u,w);function w(A){if(A==null){t(null);return}var y=null;e(v,A,z);function z(D){var B=null;if(D!=null){B=MadCap.Dom.GetAttribute(D,"Link");B=B.substring("/".length);var C=new MadCap.Utilities.Url(B);var F=null;if(r==MadCap.WebHelp.TocFile.TocType.Toc){F="TocPath"}else{if(r==MadCap.WebHelp.TocFile.TocType.BrowseSequence){F="BrowseSequencePath"}}var H=g(D,false);var E=C.ToQuery(F+"="+encodeURIComponent(H));B=E.FullPath;var G=f(D);B=G.GetPath()+B;t(B)}else{t(B)}}}};this.GetRootNode=function(t){this.Init(u);function u(){t(n)}};this.GetTocNode=function(y,v,w){this.Init(x);function x(){q=y;p=v;var G=(y=="")?new Array(0):y.split("|");var D=-1;if(G.length>0){var B=G[G.length-1];if(MadCap.String.StartsWith(B,"_____")){D=parseInt(B.substring("_____".length));G.splice(G.length-1,1)}}var H=n;for(var A=0,C=G.length;A<C;A++){if(t(H)){return}if(u(H)){return}H=b(H,decodeURIComponent(G[A]))}if(H==null){w(null);return}if(t(H)){return}if(u(H)){return}if(D>=0){if(D==0){z=H}else{z=$(H).children("TocEntry")[D-1]}}else{var E=f(H);var F=v.ToRelative(new MadCap.Utilities.Url(E.GetPath()));var z=c(H,F.FullPath.toLowerCase(),true);if(!z){z=c(H,F.PlainPath.toLowerCase(),false)}}q=null;p=null;w(z)}function t(A){var z=MadCap.Dom.GetAttribute(A,"Chunk");if(z!=null){o.LoadChunk(A,z,function(B){o.GetTocNode(q,p,w)});return true}return false}function u(A){var z=$(A).attr("MergeHint")||-1;if(z>=0){o.LoadMerge(A,function(B){o.GetTocNode(q,p,w)});return true}return false}};this.GetEntrySequenceIndex=function(w,t,u){this.GetTocNode(w,t,v);function v(y){var x=-1;if(y!=null){x=a(y)}u(x)}};this.GetIndexTotalForEntry=function(w,t,u){this.GetTocNode(w,t,v);function v(y){var z=-1;if(y!=null){var x=y;while(x.parentNode!=n){x=x.parentNode}z=MadCap.Dom.GetAttributeInt(x,"DescendantCount",-1)}u(z)}};function i(){for(var t=0,u=l.length;t<u;t++){l[t]()}}function b(w,v){var t=null;for(var u=0;u<w.childNodes.length;u++){if(w.childNodes[u].nodeName=="TocEntry"&&MadCap.Dom.GetAttribute(w.childNodes[u],"Title")==v){t=w.childNodes[u];break}}return t}function c(B,t,x){var y=null;var u=MadCap.Dom.GetAttribute(B,"Link");if(u!=null){u=u.substring("/".length);u=u.replace(/%20/g," ");u=u.toLowerCase()}if(u==t){y=B}else{for(var A=0;A<B.childNodes.length;A++){var v=B.childNodes[A];if(v.nodeType!=1){continue}var w=MadCap.Dom.GetAttribute(v,"Link");if(w==null){continue}w=w.substring("/".length);w=w.replace(/%20/g," ");w=w.toLowerCase();if(!x){var z=w.indexOf("#");if(z!=-1){w=w.substring(0,z)}var C=w.indexOf("?");if(C!=-1){w=w.substring(0,C)}}if(w==t){y=v;break}}}return y}function e(x,A,y){if(x=="previous"){w(A)}else{if(x=="next"){v(A)}}function z(F){var G=null;if(F!=null){var C=MadCap.Dom.GetAttribute(F,"Link");if(C==null){e(x,F,y);return}var D=new MadCap.Utilities.Url(C);var B=D.Extension.toLowerCase();var E=j.GetMasterHelpSystem();if(E.UseCustomTopicFileExtension){if(B!=E.CustomTopicFileExtension){e(x,F,y);return}}else{if(B!="htm"&&B!="html"){e(x,F,y);return}}G=F}y(G)}function w(F){function C(H){var G=d(H,"TocEntry");if(G==null){E=H}else{E=G;if(t(G,C)){return}if(u(G,D)){return}}z(E)}function D(J,I,G,H){if(I){C(H)}else{C(J)}}var E=null;for(var B=F.previousSibling;B!=null;B=B.previousSibling){if(B.nodeName=="TocEntry"){E=B;break}}if(E!=null){if(t(E,C)){return}if(u(E,D)){return}C(E);return}else{if(F.parentNode.nodeType==1){E=F.parentNode}}z(E)}function v(E){function C(H){var G=$(H).children("TocEntry")[0];for(var F=H;F!=null&&G==null;F=F.parentNode){G=$(F).next("TocEntry")[0]}z(G)}function D(I,H,F,G){if(H){z(F);return}C(I)}var B=null;if(t(E,C)){return}if(u(E,D)){return}C(E)}function t(D,C){var B=MadCap.Dom.GetAttribute(D,"Chunk");if(B!=null){o.LoadChunk(D,B,C);return true}return false}function u(D,C){var B=$(D).attr("MergeHint")||-1;if(B>=0){o.LoadMerge(D,C);return true}return false}}function d(w,v){var t=$(w).children(v+":last")[0];if(t!=null){var u=d(t,v);if(u!=null){return u}return t}return null}function f(w){var u=null;var t=w;while(true){if(t==t.ownerDocument.documentElement){u=j;break}var v=MadCap.Dom.GetAttributeInt(t,"ownerHelpSystemIndex",-1);if(v>=0){u=m[v];break}t=t.parentNode}return u}function g(w){var x="";var v=-1;var t=$(w).children("TocEntry")[0];if(t!=null){x=encodeURIComponent(MadCap.Dom.GetAttribute(w,"Title"));v=0}else{v=$(w).index()+1}if(x.length>0){x+="|"}x+=("_____"+v);for(var u=w.parentNode;u!=null&&u.parentNode.nodeType==1;u=u.parentNode){if(x==null){x=""}if(x.length>0){x="|"+x}x=encodeURIComponent(MadCap.Dom.GetAttribute(u,"Title"))+x}return x}function a(z){if(z.parentNode==z.ownerDocument.documentElement){return 0}var y=0;var w=MadCap.Dom.GetAttribute(z,"Link");if(w!=null){y++}for(var t=z.previousSibling;t!=null;t=t.previousSibling){if(t.nodeType!=1){continue}var u=MadCap.Dom.GetAttributeInt(t,"DescendantCount",0);y+=u;var w=MadCap.Dom.GetAttribute(t,"Link");if(w!=null){var x=new MadCap.Utilities.Url(w);var v=x.Extension.toLowerCase();if(v=="htm"||v=="html"){y++}}}return y+a(z.parentNode)}};MadCap.WebHelp.TocFile.TocType={Toc:0,BrowseSequence:1};MadCap.WebHelp.AliasFile=function(i,c,h){var g=null;var d=c;var f=null;var e=null;(function(){})();this.Load=function(j){MadCap.Utilities.Xhr.Load(i,true,function k(l){if(l){g=l.documentElement}j()})};this.GetIDs=function(){var j=new Array();a();e.ForEach(function(k,l){j[j.length]=k;return true});return j};this.GetNames=function(){var j=new Array();a();f.ForEach(function(k,l){j[j.length]=k;return true});return j};this.LookupID=function(k){var j=false;var o=null;var n=null;if(k){if(typeof(k)=="string"&&k.indexOf(".")!=-1){var m=k.indexOf("|");if(m!=-1){o=k.substring(0,m);n=k.substring(m+1)}else{o=k}j=true}else{var l=b(k);if(l!=null){j=true;o=l.Topic;n=l.Skin}}}else{j=true}if(o){o=d.ContentFolder+o}return{Found:j,Topic:o,Skin:n}};function b(j){var k=null;a();if(f!=null){if(typeof(j)=="string"){k=f.GetItem(j);if(k==null){k=e.GetItem(j)}}else{if(typeof(j)=="number"){k=e.GetItem(j.toString())}}}return k}function a(){if(f==null){if(g){f=new MadCap.Utilities.Dictionary(true);e=new MadCap.Utilities.Dictionary();var l=g.getElementsByTagName("Map");for(var k=0;k<l.length;k++){var p=l[k].getAttribute("Link");var o=l[k].getAttribute("Skin");var j={Topic:p,Skin:o};var m=l[k].getAttribute("Name");if(m!=null){f.Add(m,j)}var n=l[k].getAttribute("ResolvedId");if(n!=null){e.Add(n,j)}}}}}};MadCap.WebHelp.IndexEntry=function(b,e){var d=MadCap.Dom.GetChildNodeByTagName(b,"Links",0).childNodes;var g=d.length;var f=0;this.Term=MadCap.Dom.GetAttribute(b,"Term");this.IndexLinks=new Array();this.Level=e;this.GeneratedReferenceType=MadCap.Dom.GetAttribute(b,"GeneratedReferenceType");for(var a=0;a<g;a++){var c=d[a];if(c.nodeType!=1){continue}this.IndexLinks[f]=new MadCap.WebHelp.IndexLink(c);f++}};MadCap.WebHelp.IndexLink=function(a){this.Title=MadCap.Dom.GetAttribute(a,"Title");this.Link=MadCap.Dom.GetAttribute(a,"Link")};

//    Syntax:
//    function MadCap.OpenHelp(id, skinName, searchQuery, firstPick)
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    MadCap.OpenHelp('FILE_NEW', null, null, null);
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    MadCap.OpenHelp('FILE_NEW', 'BlueSkin', null, null);
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    MadCap.OpenHelp(1, null, null, null);
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    MadCap.OpenHelp(1, 'BlueSkin', null, null);
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    MadCap.OpenHelp('Company/Employees.htm', null, null, null);
//
//    In the following example, both the default topic and skin will be used:
//    MadCap.OpenHelp(null, null, null, null);
//
//    In the following example, the default topic will be used with "BlueSkin":
//    MadCap.OpenHelp(null, 'BlueSkin', null, null);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', false);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', true);

(function ()
{
var helpSystemName = "Default.htm";

    MadCap.OpenHelp = function (id, skinName, searchQuery, firstPick, pathToHelpSystem)
    {
        var cshFileName = helpSystemName.substring(0, helpSystemName.lastIndexOf(".")) + ".js";
        var webHelpPath = null;
        var webHelpFile = null;
        var cshFileUrl = new MadCap.Utilities.Url(helpSystemName);

        if (pathToHelpSystem == null)
        {
            var scriptNodes = document.getElementsByTagName("script");
            var found = false;

            for (var i = 0; i < scriptNodes.length; i++)
            {
                var src = scriptNodes[i].src;
                var srcUrl = new MadCap.Utilities.Url(MadCap.String.Trim(src));

                if (srcUrl.NameWithExtension.toLowerCase() == cshFileName.toLowerCase())
                {
                    var locUrl = new MadCap.Utilities.Url(document.location.href).ToFolder();

                    webHelpPath = locUrl.AddFile(srcUrl);
                    webHelpPath = webHelpPath.ToFolder();

                    found = true;

                    break;
                }
            }

            if (!found)
                throw "CSH failed: could not find MadCap CSH script in page.";
        }
        else
        {
            webHelpPath = new MadCap.Utilities.Url(pathToHelpSystem);
        }

        webHelpFile = webHelpPath.AddFile(cshFileUrl);

        var webHelpPath = webHelpFile.ToFolder().FullPath;
        var helpSystemFile = webHelpPath + "Data/HelpSystem.xml";
        var helpSystem = new MadCap.WebHelp.HelpSystem(null, null, helpSystemFile, null, null);

        helpSystem.Load(function ()
        {
            helpSystem.LookupCSHID(id, function (idInfo)
            {
                function OnGetSkinComplete()
                {
                    var cshString = webHelpFile.FullPath;

                    if (id)
                        cshString += "#cshid=" + id;

                    if (skinName)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "skinName=" + skinName;
                    }

                    if (searchQuery)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "searchQuery=" + searchQuery;

                        if (firstPick)
                            cshString += "&firstPick=true";
                    }

                    var win = window.open(cshString, "_MCWebHelpCSH", browserOptions + size);

                    // Bug 32051: Windows 7 64-bit is returning null from the call to window.open().
                    if (win != null)
                        win.focus();
                }

                skinName = skinName || idInfo.Skin;

                // Browser setup options

                var browserOptions = "";
                var size = "";

                if (skinName)
                {
                    var skin = helpSystem.GetSkin(skinName);

                    if (skin)
                    {
                        var useDefault = MadCap.String.ToBool(skin.UseDefaultBrowserSetup, true);

                        if (!useDefault)
                        {
                            var toolbar = "no";
                            var menu = "no";
                            var locationBar = "no";
                            var statusBar = "no";
                            var resizable = "no";
                            var setup = skin.BrowserSetup;

                            if (setup)
                            {
                                toolbar = (setup.indexOf("Toolbar") > -1) ? "yes" : "no";
                                menu = (setup.indexOf("Menu") > -1) ? "yes" : "no";
                                locationBar = (setup.indexOf("LocationBar") > -1) ? "yes" : "no";
                                statusBar = (setup.indexOf("StatusBar") > -1) ? "yes" : "no";
                                resizable = (setup.indexOf("Resizable") > -1) ? "yes" : "no";
                            }

                            browserOptions = "toolbar=" + toolbar + ", menubar=" + menu + ", location=" + locationBar + ", status=" + statusBar + ", resizable=" + resizable;
                        }

                        var windowSize = LoadSize(skin);

                        if (windowSize)
                            size = ", top=" + windowSize.topPx + ", left=" + windowSize.leftPx + ", width=" + windowSize.widthPx + ", height=" + windowSize.heightPx;
                    }

                    OnGetSkinComplete();
                }
                else
                {
                    OnGetSkinComplete();
                }
            });
        });
    }

    function LoadSize(skin)
    {
        var useDefaultSize = MadCap.String.ToBool(skin.UseBrowserDefaultSize, true);

        if (useDefaultSize)
            return null;

        var topPx = MadCap.String.ToInt(skin.Top, 0);
        var leftPx = MadCap.String.ToInt(skin.Left, 0);
        var bottomPx = MadCap.String.ToInt(skin.Bottom, 0);
        var rightPx = MadCap.String.ToInt(skin.Right, 0);
        var widthPx = MadCap.String.ToInt(skin.Width, 800);
        var heightPx = MadCap.String.ToInt(skin.Height, 600);

        var anchors = skin.Anchors;

        if (anchors)
        {
            var aTop = (anchors.indexOf("Top") > -1) ? true : false;
            var aLeft = (anchors.indexOf("Left") > -1) ? true : false;
            var aBottom = (anchors.indexOf("Bottom") > -1) ? true : false;
            var aRight = (anchors.indexOf("Right") > -1) ? true : false;
            var aWidth = (anchors.indexOf("Width") > -1) ? true : false;
            var aHeight = (anchors.indexOf("Height") > -1) ? true : false;
        }

        if (aLeft && aRight)
            widthPx = screen.width - (leftPx + rightPx);
        else if (!aLeft && aRight)
            leftPx = screen.width - (widthPx + rightPx);
        else if (aWidth)
            leftPx = (screen.width / 2) - (widthPx / 2);

        if (aTop && aBottom)
            heightPx = screen.height - (topPx + bottomPx);
        else if (!aTop && aBottom)
            topPx = screen.height - (heightPx + bottomPx);
        else if (aHeight)
            topPx = (screen.height / 2) - (heightPx / 2);

        //

        var windowSize = {};
        windowSize.topPx = topPx;
        windowSize.leftPx = leftPx;
        windowSize.widthPx = widthPx;
        windowSize.heightPx = heightPx;

        return windowSize;
    }
})();
